import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ChangeDetectionStrategy, HostListener, ViewChild, forwardRef, Directive, ViewContainerRef, ViewEncapsulation, NgModule, createComponent } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i3 from 'lucide-angular';
import { LucideAngularModule, icons } from 'lucide-angular';
import hljs from 'highlight.js';
import * as i1$1 from '@ng-bootstrap/ng-bootstrap';
import * as XLSX from 'xlsx';
import { Subject, of, Subscription, Observable } from 'rxjs';
import { debounceTime, distinctUntilChanged, switchMap, tap, map, catchError, takeUntil } from 'rxjs/operators';
import * as i1$2 from '@angular/common/http';
import { HttpParams } from '@angular/common/http';
import jsPDF from 'jspdf';
import 'jspdf-autotable';
import { NgSelectModule } from '@ng-select/ng-select';
import * as CryptoJS from 'crypto-js';

class AuthService {
    constructor() {
        this.userRoles = [];
        this.loadUserRoles();
    }
    loadUserRoles() {
        const storedUser = localStorage.getItem('user');
        if (!storedUser) {
            throw new Error('User not found in localStorage');
        }
        const { role } = JSON.parse(storedUser);
        if (!role || !Array.isArray(role)) {
            throw new Error('Roles not found or invalid in localStorage');
        }
        this.userRoles = role.map((r) => r.toString());
    }
    hasPermission(requiredPermissions) {
        if (this.userRoles.length === 0) {
            throw new Error('No roles found for the user');
        }
        return requiredPermissions.every(permission => this.userRoles.includes(permission));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AuthService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AuthService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AuthService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class AccordionArgentaComponent {
    constructor(authService) {
        this.authService = authService;
        this.title = 'Accordion Title'; // Título do accordion
        this.isOpen = false; // Estado inicial do accordion
        this.permissions = []; // Permissões necessárias para exibir o accordion
        this.toggleEvent = new EventEmitter(); // Evento emitido ao abrir/fechar o accordion
    }
    ngOnInit() {
        this.validatePermissions();
    }
    ngOnChanges(changes) {
        if (changes['permissions']) {
            this.validatePermissions();
        }
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true; // Se não forem passadas permissões, o accordion será exibido por padrão
        }
        try {
            return this.authService.hasPermission(this.permissions); // Verifica se o usuário tem as permissões
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return false; // Se ocorrer um erro ou as permissões não forem válidas, o accordion não será exibido
        }
    }
    toggle() {
        this.isOpen = !this.isOpen;
        this.toggleEvent.emit(this.isOpen); // Emite o estado atual (aberto ou fechado)
    }
    validatePermissions() {
        if (!Array.isArray(this.permissions)) {
            throw new Error(`Invalid permissions: ${this.permissions}. It should be an array of strings.`);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AccordionArgentaComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AccordionArgentaComponent, selector: "argenta-accordion", inputs: { title: "title", isOpen: "isOpen", permissions: "permissions" }, outputs: { toggleEvent: "toggleEvent" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"hasPermission()\">\n  <div class=\"accordion\">\n    <div class=\"accordion-header\" (click)=\"toggle()\" [class.open]=\"isOpen\">\n      <h3>{{ title }}</h3>\n      <!-- \u00CDcone da seta -->\n      <span class=\"accordion-icon\">\u25BC</span>\n    </div>\n    <div class=\"accordion-content\" [class.open]=\"isOpen\">\n      <ng-content></ng-content> <!-- Conte\u00FAdo do accordion -->\n    </div>\n  </div>\n</ng-container>\n", styles: ["@charset \"UTF-8\";.accordion{border:1px solid #ccc;border-radius:8px;margin-bottom:15px;font-family:var(--font-family);transition:max-height .4s ease;overflow:hidden}.accordion .accordion-header{background-color:var(--primary-color);color:var(--text-color);cursor:pointer;padding:10px;display:flex;justify-content:space-between;align-items:center;font-size:1.2rem}.accordion .accordion-header h3{margin:0;font-size:1rem;font-weight:700}.accordion .accordion-header .accordion-icon{font-size:1.2rem;transition:transform .4s ease;transform:rotate(0)}.accordion .accordion-header.open .accordion-icon{transform:rotate(180deg)}.accordion .accordion-content{max-height:0;overflow:hidden;padding:0 10px;background-color:#fff;font-size:.9rem;transition:max-height .4s ease,padding .4s ease}.accordion .accordion-content.open{max-height:500px;padding:10px;border-bottom-left-radius:8px;border-bottom-right-radius:8px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AccordionArgentaComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-accordion', template: "<ng-container *ngIf=\"hasPermission()\">\n  <div class=\"accordion\">\n    <div class=\"accordion-header\" (click)=\"toggle()\" [class.open]=\"isOpen\">\n      <h3>{{ title }}</h3>\n      <!-- \u00CDcone da seta -->\n      <span class=\"accordion-icon\">\u25BC</span>\n    </div>\n    <div class=\"accordion-content\" [class.open]=\"isOpen\">\n      <ng-content></ng-content> <!-- Conte\u00FAdo do accordion -->\n    </div>\n  </div>\n</ng-container>\n", styles: ["@charset \"UTF-8\";.accordion{border:1px solid #ccc;border-radius:8px;margin-bottom:15px;font-family:var(--font-family);transition:max-height .4s ease;overflow:hidden}.accordion .accordion-header{background-color:var(--primary-color);color:var(--text-color);cursor:pointer;padding:10px;display:flex;justify-content:space-between;align-items:center;font-size:1.2rem}.accordion .accordion-header h3{margin:0;font-size:1rem;font-weight:700}.accordion .accordion-header .accordion-icon{font-size:1.2rem;transition:transform .4s ease;transform:rotate(0)}.accordion .accordion-header.open .accordion-icon{transform:rotate(180deg)}.accordion .accordion-content{max-height:0;overflow:hidden;padding:0 10px;background-color:#fff;font-size:.9rem;transition:max-height .4s ease,padding .4s ease}.accordion .accordion-content.open{max-height:500px;padding:10px;border-bottom-left-radius:8px;border-bottom-right-radius:8px}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { title: [{
                type: Input
            }], isOpen: [{
                type: Input
            }], permissions: [{
                type: Input
            }], toggleEvent: [{
                type: Output
            }] } });

class AlertComponent {
    constructor() {
        this.alerts = [];
        this.closeTimeouts = {}; // Armazena os temporizadores para cada alerta
    }
    ngOnInit() {
        // Inicia o temporizador de fechamento para cada alerta quando a página é carregada
        this.alerts.forEach(alert => {
            this.closeTimeouts[alert.message] = setTimeout(() => {
                this.closeAlert(alert);
            }, 6000); // Fecha após 8 segundos
        });
    }
    ngAfterViewInit() {
        // Adiciona a classe 'show' após um curto atraso para acionar a animação
        setTimeout(() => {
            this.alerts.forEach(alert => {
                const element = document.getElementById(`alert-${alert.message}`);
                if (element) {
                    element.classList.add('show');
                }
            });
        }, 10); // Pequeno atraso para garantir que o elemento esteja no DOM
    }
    closeAlert(alert) {
        const element = document.getElementById(`alert-${alert.message}`);
        if (element) {
            element.classList.remove('show');
            setTimeout(() => {
                this.alerts = this.alerts.filter(a => a !== alert);
            }, 500); // Duração da animação de saída
        }
        else {
            this.alerts = this.alerts.filter(a => a !== alert);
        }
    }
    getAlertClass(alert) {
        return {
            'alert-container': true,
            'alert-dismissible': true,
            [`alert-${alert.type}`]: true
        };
    }
    getAlertIconClass(alert) {
        switch (alert.type) {
            case 'success':
                return 'success-icon'; // Classe para o ícone de sucesso
            case 'info':
                return 'info-icon'; // Classe para o ícone de informação
            case 'warning':
                return 'warning-icon'; // Classe para o ícone de aviso
            case 'danger':
                return 'danger-icon'; // Classe para o ícone de erro
            default:
                return '';
        }
    }
    onMouseEnter(alert) {
        // Cancela o temporizador quando o mouse entra no alerta
        if (this.closeTimeouts[alert.message]) {
            clearTimeout(this.closeTimeouts[alert.message]);
            delete this.closeTimeouts[alert.message];
        }
    }
    onMouseLeave(alert) {
        // Inicia um novo temporizador para fechar o alerta após 2 segundos quando o mouse sai do alerta
        this.closeTimeouts[alert.message] = setTimeout(() => {
            this.closeAlert(alert);
        }, 2000); // Fechar após 2 segundos
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AlertComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AlertComponent, selector: "lib-alert", inputs: { alerts: "alerts" }, ngImport: i0, template: "<div *ngFor=\"let alert of alerts\" \n     [ngClass]=\"getAlertClass(alert)\" \n     role=\"alert\" \n     [id]=\"'alert-' + alert.message\"\n     (mouseenter)=\"onMouseEnter(alert)\" \n     (mouseleave)=\"onMouseLeave(alert)\">\n  <button type=\"button\" class=\"close\" (click)=\"closeAlert(alert)\" aria-label=\"Close\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n  <div class=\"alert-header\">\n    <span [ngClass]=\"getAlertIconClass(alert)\" class=\"alert-icon\"></span>\n    <strong>{{ alert.title }}</strong>\n  </div>\n  <div class=\"alert-body\">\n    {{ alert.message }}\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.alert-container{position:fixed;top:20px;right:20px;max-width:400px;margin:10px auto;padding:15px;border-radius:4px;background-color:#f8d7da;color:#721c24;word-wrap:break-word;opacity:0;transform:translateY(-20px);transition:opacity .5s ease,transform .5s ease;display:flex;flex-direction:column;align-items:flex-start;z-index:9999}.alert-container.show{opacity:1;transform:translateY(0)}.alert-container .close{position:absolute;top:10px;right:10px;background:none;border:none;font-size:20px;color:#000;opacity:.5;cursor:pointer;outline:none}.alert-container .close:hover{opacity:1}.alert-container .alert-header{display:flex;align-items:center;margin-bottom:5px}.alert-container .alert-icon{margin-right:10px;font-size:20px}.alert-container .alert-body{margin-left:30px}.alert-container .alert-icon.success-icon:before{content:\"\\2714\\fe0f\"}.alert-container .alert-icon.info-icon:before{content:\"\\2139\\fe0f\"}.alert-container .alert-icon.warning-icon:before{content:\"\\26a0\\fe0f\"}.alert-container .alert-icon.danger-icon:before{content:\"\\274c\"}.alert-success{background-color:#d4edda;color:#155724}.alert-info{background-color:#d8f4f7;color:#0c5460}.alert-warning{background-color:#fff3cd;color:#856404}.alert-danger{background-color:#fdd9d7;color:#721c24}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AlertComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-alert', template: "<div *ngFor=\"let alert of alerts\" \n     [ngClass]=\"getAlertClass(alert)\" \n     role=\"alert\" \n     [id]=\"'alert-' + alert.message\"\n     (mouseenter)=\"onMouseEnter(alert)\" \n     (mouseleave)=\"onMouseLeave(alert)\">\n  <button type=\"button\" class=\"close\" (click)=\"closeAlert(alert)\" aria-label=\"Close\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n  <div class=\"alert-header\">\n    <span [ngClass]=\"getAlertIconClass(alert)\" class=\"alert-icon\"></span>\n    <strong>{{ alert.title }}</strong>\n  </div>\n  <div class=\"alert-body\">\n    {{ alert.message }}\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.alert-container{position:fixed;top:20px;right:20px;max-width:400px;margin:10px auto;padding:15px;border-radius:4px;background-color:#f8d7da;color:#721c24;word-wrap:break-word;opacity:0;transform:translateY(-20px);transition:opacity .5s ease,transform .5s ease;display:flex;flex-direction:column;align-items:flex-start;z-index:9999}.alert-container.show{opacity:1;transform:translateY(0)}.alert-container .close{position:absolute;top:10px;right:10px;background:none;border:none;font-size:20px;color:#000;opacity:.5;cursor:pointer;outline:none}.alert-container .close:hover{opacity:1}.alert-container .alert-header{display:flex;align-items:center;margin-bottom:5px}.alert-container .alert-icon{margin-right:10px;font-size:20px}.alert-container .alert-body{margin-left:30px}.alert-container .alert-icon.success-icon:before{content:\"\\2714\\fe0f\"}.alert-container .alert-icon.info-icon:before{content:\"\\2139\\fe0f\"}.alert-container .alert-icon.warning-icon:before{content:\"\\26a0\\fe0f\"}.alert-container .alert-icon.danger-icon:before{content:\"\\274c\"}.alert-success{background-color:#d4edda;color:#155724}.alert-info{background-color:#d8f4f7;color:#0c5460}.alert-warning{background-color:#fff3cd;color:#856404}.alert-danger{background-color:#fdd9d7;color:#721c24}\n"] }]
        }], propDecorators: { alerts: [{
                type: Input
            }] } });

class AppBackgroundComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AppBackgroundComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AppBackgroundComponent, selector: "argenta-app-background", ngImport: i0, template: `
    <div class="row row-car">
        <div class="card">
          <div class="card-content">
            <ng-content></ng-content>
          </div>
        </div>      
    </div>
  `, isInline: true, styles: [".card{border-radius:10px;padding:1rem;background-color:#fff;border:none}.row-car{margin-left:-.8rem;margin-right:-.8rem}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AppBackgroundComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-app-background', template: `
    <div class="row row-car">
        <div class="card">
          <div class="card-content">
            <ng-content></ng-content>
          </div>
        </div>      
    </div>
  `, styles: [".card{border-radius:10px;padding:1rem;background-color:#fff;border:none}.row-car{margin-left:-.8rem;margin-right:-.8rem}\n"] }]
        }] });

var ButtonClasses;
(function (ButtonClasses) {
    ButtonClasses["Primary"] = "btn-primary";
    ButtonClasses["Secondary"] = "btn-secondary";
    ButtonClasses["Success"] = "btn-success";
    ButtonClasses["Danger"] = "btn-danger";
    ButtonClasses["Warning"] = "btn-warning";
    ButtonClasses["Info"] = "btn-info";
    ButtonClasses["Light"] = "btn-light";
    ButtonClasses["Dark"] = "btn-dark";
    ButtonClasses["Link"] = "btn-link";
})(ButtonClasses || (ButtonClasses = {}));

class BadgeComponent {
    constructor() {
        this.label = "Mensagem";
        this.badgeContent = "+45";
        this.marginTop = 0;
        this.marginBottom = 0;
        this.marginLeft = 0;
        this.marginRight = 0;
        this.btnClass = ButtonClasses.Primary;
        this.buttonClick = new EventEmitter();
        this.isHovered = false;
        this.isClicked = false;
        this.isActive = false;
    }
    getDynamicStyles() {
        let backgroundColor = "";
        let textColor = getComputedStyle(document.documentElement)
            .getPropertyValue("--text-color")
            .trim();
        let borderColor = "";
        const getCSSVariable = (variable) => getComputedStyle(document.documentElement)
            .getPropertyValue(variable)
            .trim();
        switch (this.btnClass) {
            case ButtonClasses.Primary:
                backgroundColor = getCSSVariable("--primary-color");
                break;
            case ButtonClasses.Secondary:
                backgroundColor = getCSSVariable("--secondary-color");
                break;
            case ButtonClasses.Success:
                backgroundColor = getCSSVariable("--success-color");
                break;
            case ButtonClasses.Danger:
                backgroundColor = getCSSVariable("--danger-color");
                break;
            case ButtonClasses.Warning:
                backgroundColor = getCSSVariable("--warning-color");
                break;
            case ButtonClasses.Info:
                backgroundColor = getCSSVariable("--info-color");
                break;
            case ButtonClasses.Light:
                backgroundColor = getCSSVariable("--light-color");
                textColor = getCSSVariable("--primary-color");
                break;
            case ButtonClasses.Dark:
                backgroundColor = getCSSVariable("--dark-color");
                break;
            case ButtonClasses.Link:
                backgroundColor = "transparent";
                borderColor = getCSSVariable("--link-border-color");
                textColor = getCSSVariable("--primary-color");
                break;
            default:
                backgroundColor = getCSSVariable("--primary-color");
                break;
        }
        const hoverFilter = this.isHovered ? "brightness(80%)" : "none";
        const activeFilter = this.isClicked ? "brightness(60%)" : hoverFilter;
        return {
            "margin-top": `${this.marginTop}rem`,
            "margin-bottom": `${this.marginBottom}rem`,
            "margin-left": `${this.marginLeft}rem`,
            "margin-right": `${this.marginRight}rem`,
            "background-color": backgroundColor,
            color: textColor,
            border: borderColor ? `1px solid ${borderColor}` : "none",
            transition: "background-color 0.3s, border-color 0.3s, filter 0.3s",
            filter: activeFilter,
        };
    }
    onClick() {
        this.buttonClick.emit();
    }
    onMouseEnter() {
        this.isHovered = true;
    }
    onMouseLeave() {
        this.isHovered = false;
        this.isClicked = false;
    }
    onMouseDown() {
        this.isClicked = true;
    }
    onMouseUp() {
        this.isClicked = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BadgeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: BadgeComponent, selector: "sim-app-badge", inputs: { label: "label", badgeContent: "badgeContent", marginTop: "marginTop", marginBottom: "marginBottom", marginLeft: "marginLeft", marginRight: "marginRight", btnClass: "btnClass" }, outputs: { buttonClick: "buttonClick" }, host: { listeners: { "mouseenter": "onMouseEnter()", "mouseleave": "onMouseLeave()", "mousedown": "onMouseDown()", "mouseup": "onMouseUp()" } }, ngImport: i0, template: "<button\n  class=\"notification-button\"\n  [ngStyle]=\"getDynamicStyles()\"\n  (click)=\"onClick()\"\n  [class.hovered]=\"isHovered\"\n  [class.clicked]=\"isClicked\"\n  (mousedown)=\"onMouseDown()\"\n  (mouseup)=\"onMouseUp()\"\n  (mouseleave)=\"onMouseLeave()\"\n  (mouseenter)=\"onMouseEnter()\"\n>\n  {{ label }}\n  <span class=\"badge\">{{ badgeContent }}</span>\n</button>\n", styles: [".notification-button{position:relative;display:inline-block;width:155px;height:58px;padding:14px 29px 14px 36px;border-radius:6px;border:none;font-size:16px;font-weight:700;text-align:center;transition:opacity .3s}.badge{position:absolute;width:52px;height:32px;top:-15px;right:-20px;background-color:var(--danger-color);color:var(--text-color);border-radius:16px;display:flex;align-items:center;justify-content:center;font-weight:700;font-size:14px;font-family:var(--font-family)}.notification-button.hovered{opacity:.8}.notification-button.clicked{opacity:.6}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BadgeComponent, decorators: [{
            type: Component,
            args: [{ selector: "sim-app-badge", changeDetection: ChangeDetectionStrategy.OnPush, template: "<button\n  class=\"notification-button\"\n  [ngStyle]=\"getDynamicStyles()\"\n  (click)=\"onClick()\"\n  [class.hovered]=\"isHovered\"\n  [class.clicked]=\"isClicked\"\n  (mousedown)=\"onMouseDown()\"\n  (mouseup)=\"onMouseUp()\"\n  (mouseleave)=\"onMouseLeave()\"\n  (mouseenter)=\"onMouseEnter()\"\n>\n  {{ label }}\n  <span class=\"badge\">{{ badgeContent }}</span>\n</button>\n", styles: [".notification-button{position:relative;display:inline-block;width:155px;height:58px;padding:14px 29px 14px 36px;border-radius:6px;border:none;font-size:16px;font-weight:700;text-align:center;transition:opacity .3s}.badge{position:absolute;width:52px;height:32px;top:-15px;right:-20px;background-color:var(--danger-color);color:var(--text-color);border-radius:16px;display:flex;align-items:center;justify-content:center;font-weight:700;font-size:14px;font-family:var(--font-family)}.notification-button.hovered{opacity:.8}.notification-button.clicked{opacity:.6}\n"] }]
        }], propDecorators: { label: [{
                type: Input
            }], badgeContent: [{
                type: Input
            }], marginTop: [{
                type: Input
            }], marginBottom: [{
                type: Input
            }], marginLeft: [{
                type: Input
            }], marginRight: [{
                type: Input
            }], btnClass: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }], onMouseEnter: [{
                type: HostListener,
                args: ["mouseenter"]
            }], onMouseLeave: [{
                type: HostListener,
                args: ["mouseleave"]
            }], onMouseDown: [{
                type: HostListener,
                args: ["mousedown"]
            }], onMouseUp: [{
                type: HostListener,
                args: ["mouseup"]
            }] } });

class ButtonComponent {
    constructor(authService, cdr, renderer) {
        this.authService = authService;
        this.cdr = cdr;
        this.renderer = renderer;
        this.type = "button";
        this.label = "Submit";
        this.btnClass = ButtonClasses.Primary;
        this.fontSize = "1rem";
        this.disabled = false;
        this.autofocus = false;
        this.form = null;
        this.formaction = null;
        this.formenctype = null;
        this.formmethod = null;
        this.formnovalidate = false;
        this.formtarget = null;
        this.name = null;
        this.value = null;
        this.permissions = [];
        this.onButtonClick = new EventEmitter();
        this.isHovered = false;
        this.isActive = false;
        this.clicked = false;
    }
    ngOnInit() {
        this.validateInputs();
    }
    ngAfterViewInit() {
        this.addHoverEffect(); // Chama o método para aplicar o efeito de hover
    }
    ngOnChanges(changes) {
        if (changes) {
            this.validateInputs();
        }
    }
    validateInputs() {
        const validTypes = ["button", "submit", "reset"];
        const validClasses = Object.values(ButtonClasses);
        if (!validTypes.includes(this.type)) {
            throw new Error(`Invalid type: ${this.type}. Allowed values are: ${validTypes.join(", ")}`);
        }
        if (!validClasses.includes(this.btnClass)) {
            throw new Error(`Invalid btnClass: ${this.btnClass}. Allowed values are: ${validClasses.join(", ")}`);
        }
        if (typeof this.disabled !== "boolean") {
            throw new Error(`Invalid disabled value: ${this.disabled}. It should be a boolean.`);
        }
        if (typeof this.autofocus !== "boolean") {
            throw new Error(`Invalid autofocus value: ${this.autofocus}. It should be a boolean.`);
        }
        if (this.permissions && !Array.isArray(this.permissions)) {
            throw new Error(`Invalid permissions value: ${this.permissions}. It should be an array of strings.`);
        }
    }
    onClick(event) {
        this.clicked = true;
        this.onButtonClick.emit(event);
        setTimeout(() => {
            this.clicked = false;
            this.cdr.detectChanges();
        }, 80);
    }
    get dynamicStyles() {
        return this.calculateDynamicStyles();
    }
    calculateDynamicStyles() {
        let backgroundColor = "";
        let textColor = getComputedStyle(document.documentElement)
            .getPropertyValue("--text-color")
            .trim(); // Cor de texto padrão
        let borderColor = "";
        const getCSSVariable = (variable) => getComputedStyle(document.documentElement)
            .getPropertyValue(variable)
            .trim();
        if (this.clicked) {
            backgroundColor = "rgba(126, 126, 126, 0.25)"; // Cor temporária ao clicar
        }
        else {
            switch (this.btnClass) {
                case ButtonClasses.Primary:
                    backgroundColor = getCSSVariable("--primary-color");
                    break;
                case ButtonClasses.Secondary:
                    backgroundColor = getCSSVariable("--secondary-color");
                    break;
                case ButtonClasses.Success:
                    backgroundColor = getCSSVariable("--success-color");
                    break;
                case ButtonClasses.Danger:
                    backgroundColor = getCSSVariable("--danger-color");
                    break;
                case ButtonClasses.Warning:
                    backgroundColor = getCSSVariable("--warning-color");
                    break;
                case ButtonClasses.Info:
                    backgroundColor = getCSSVariable("--info-color");
                    break;
                case ButtonClasses.Light:
                    backgroundColor = getCSSVariable("--light-color");
                    textColor = getCSSVariable("--primary-color");
                    break;
                case ButtonClasses.Dark:
                    backgroundColor = getCSSVariable("--dark-color");
                    break;
                case ButtonClasses.Link:
                    backgroundColor = "transparent";
                    borderColor = getCSSVariable("--link-border-color");
                    textColor = getCSSVariable("--primary-color");
                    break;
                default:
                    backgroundColor = getCSSVariable("--primary-color");
                    break;
            }
        }
        const hoverFilter = this.isHovered ? "brightness(80%)" : "none";
        const activeFilter = this.isActive ? "brightness(60%)" : hoverFilter;
        return {
            "font-size": this.fontSize,
            "background-color": backgroundColor,
            color: textColor,
            border: borderColor ? `1px solid ${borderColor}` : "none",
            transition: "background-color 0.3s, border-color 0.3s, filter 0.3s",
            filter: activeFilter,
        };
    }
    addHoverEffect() {
        const buttonElement = this.buttonElement.nativeElement;
        if (buttonElement) {
            // Evento de mouseover para adicionar box-shadow
            this.renderer.listen(buttonElement, "mouseover", () => {
                const hoverColor = this.calculateHoverColor(); // Calcula a cor de hover
                this.renderer.setStyle(buttonElement, "box-shadow", `0 0 0 0.15rem ${hoverColor}`);
            });
            // Evento de mouseout para remover o box-shadow
            this.renderer.listen(buttonElement, "mouseout", () => {
                this.renderer.setStyle(buttonElement, "box-shadow", "none");
            });
        }
    }
    // Calcula a cor de hover com base na classe de botão
    calculateHoverColor() {
        switch (this.btnClass) {
            case ButtonClasses.Primary:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--primary-color")
                    .trim();
            case ButtonClasses.Secondary:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--secondary-color")
                    .trim();
            case ButtonClasses.Success:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--success-color")
                    .trim();
            case ButtonClasses.Danger:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--danger-color")
                    .trim();
            case ButtonClasses.Warning:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--warning-color")
                    .trim();
            case ButtonClasses.Info:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--info-color")
                    .trim();
            case ButtonClasses.Link:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("light-color")
                    .trim();
            case ButtonClasses.Light:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--light-color")
                    .trim();
            case ButtonClasses.Dark:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--dark-color")
                    .trim();
            default:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--primary-color")
                    .trim();
        }
    }
    // Calcula a cor de fundo original
    calculateOriginalColor() {
        switch (this.btnClass) {
            case ButtonClasses.Primary:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--primary-color")
                    .trim();
            case ButtonClasses.Secondary:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--secondary-color")
                    .trim();
            case ButtonClasses.Success:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--success-color")
                    .trim();
            case ButtonClasses.Danger:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--danger-color")
                    .trim();
            case ButtonClasses.Warning:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--warning-color")
                    .trim();
            case ButtonClasses.Info:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--info-color")
                    .trim();
            case ButtonClasses.Link:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("transparent")
                    .trim();
            case ButtonClasses.Light:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--light-color")
                    .trim();
            case ButtonClasses.Dark:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--dark-color")
                    .trim();
            default:
                return getComputedStyle(document.documentElement)
                    .getPropertyValue("--primary-color")
                    .trim();
        }
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error("Permission error:", error.message);
            }
            else {
                console.error("Unknown error occurred during permission check");
            }
            return true;
        }
    }
    onCancel(event) {
        console.log("Cancel button clicked", event);
        // Lógica para o cancelamento
    }
    onSave(event) {
        console.log("Save button clicked", event);
        // Lógica para salvar alterações
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ButtonComponent, deps: [{ token: AuthService }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ButtonComponent, selector: "argenta-custom-button", inputs: { type: "type", label: "label", btnClass: "btnClass", fontSize: "fontSize", disabled: "disabled", autofocus: "autofocus", form: "form", formaction: "formaction", formenctype: "formenctype", formmethod: "formmethod", formnovalidate: "formnovalidate", formtarget: "formtarget", name: "name", value: "value", permissions: "permissions" }, outputs: { onButtonClick: "onButtonClick" }, viewQueries: [{ propertyName: "buttonElement", first: true, predicate: ["buttonElement"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"hasPermission()\">\n  <button\n    #buttonElement\n    [type]=\"type\"\n    class=\"btn\"\n    [ngClass]=\"btnClass\"\n    [ngStyle]=\"dynamicStyles\"\n    (click)=\"onClick($event)\"\n    [disabled]=\"disabled\"\n    [attr.autofocus]=\"autofocus ? true : null\"\n    [attr.form]=\"form\"\n    [attr.formaction]=\"formaction\"\n    [attr.formenctype]=\"formenctype\"\n    [attr.formmethod]=\"formmethod\"\n    [attr.formnovalidate]=\"formnovalidate\"\n    [attr.formtarget]=\"formtarget\"\n    [attr.name]=\"name\"\n    [attr.value]=\"value\"\n    [attr.type]=\"type\"\n  >\n    {{ label }}\n  </button>\n</ng-container>\n", styles: [".btn{padding:.5rem 1rem;border-radius:.25rem;transition:background-color .3s,border-color .3s,filter .3s;font-family:var(--font-family);font-size:16px;font-weight:600;line-height:24px;letter-spacing:.005em;text-align:left;box-shadow:none}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-custom-button", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *ngIf=\"hasPermission()\">\n  <button\n    #buttonElement\n    [type]=\"type\"\n    class=\"btn\"\n    [ngClass]=\"btnClass\"\n    [ngStyle]=\"dynamicStyles\"\n    (click)=\"onClick($event)\"\n    [disabled]=\"disabled\"\n    [attr.autofocus]=\"autofocus ? true : null\"\n    [attr.form]=\"form\"\n    [attr.formaction]=\"formaction\"\n    [attr.formenctype]=\"formenctype\"\n    [attr.formmethod]=\"formmethod\"\n    [attr.formnovalidate]=\"formnovalidate\"\n    [attr.formtarget]=\"formtarget\"\n    [attr.name]=\"name\"\n    [attr.value]=\"value\"\n    [attr.type]=\"type\"\n  >\n    {{ label }}\n  </button>\n</ng-container>\n", styles: [".btn{padding:.5rem 1rem;border-radius:.25rem;transition:background-color .3s,border-color .3s,filter .3s;font-family:var(--font-family);font-size:16px;font-weight:600;line-height:24px;letter-spacing:.005em;text-align:left;box-shadow:none}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }]; }, propDecorators: { type: [{
                type: Input
            }], label: [{
                type: Input
            }], btnClass: [{
                type: Input
            }], fontSize: [{
                type: Input
            }], disabled: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], form: [{
                type: Input
            }], formaction: [{
                type: Input
            }], formenctype: [{
                type: Input
            }], formmethod: [{
                type: Input
            }], formnovalidate: [{
                type: Input
            }], formtarget: [{
                type: Input
            }], name: [{
                type: Input
            }], value: [{
                type: Input
            }], permissions: [{
                type: Input
            }], onButtonClick: [{
                type: Output
            }], buttonElement: [{
                type: ViewChild,
                args: ["buttonElement"]
            }] } });

class BasicRegistrationComponent {
    constructor(authService) {
        this.authService = authService;
        this.cancelLabel = 'Cancelar';
        this.saveLabel = 'Salvar';
        this.cancelPermissions = [];
        this.savePermissions = [];
        this.cancelClick = new EventEmitter();
        this.saveClick = new EventEmitter();
        this.ButtonClasses = ButtonClasses;
    }
    hasPermission(permissions) {
        if (!permissions || permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return true;
        }
    }
    handleCancel(event) {
        this.cancelClick.emit(event);
    }
    handleSave(event) {
        this.saveClick.emit(event);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BasicRegistrationComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: BasicRegistrationComponent, selector: "argenta-basic-registration", inputs: { cancelLabel: "cancelLabel", saveLabel: "saveLabel", cancelPermissions: "cancelPermissions", savePermissions: "savePermissions" }, outputs: { cancelClick: "cancelClick", saveClick: "saveClick" }, ngImport: i0, template: "<div class=\"row row-car\">\n  <div class=\"card\">\n    <div class=\"card-content\" style=\"margin-top: 2.5rem;\">\n      <ng-content></ng-content> <!-- Permite a inclus\u00E3o de conte\u00FAdo din\u00E2mico -->\n    </div>\n    <div class=\"card-footer\">\n      <div class=\"button-group\">\n        <argenta-custom-button\n          *ngIf=\"hasPermission(cancelPermissions)\"\n          [type]=\"'button'\"\n          [label]=\"cancelLabel\"\n          [btnClass]=\"ButtonClasses.Light\"\n          (onButtonClick)=\"handleCancel($event)\"\n          class=\"argenta-custom-button\">\n        </argenta-custom-button>\n        <argenta-custom-button\n          *ngIf=\"hasPermission(savePermissions)\"\n          [type]=\"'submit'\"\n          [label]=\"saveLabel\"\n          [btnClass]=\"ButtonClasses.Primary\"\n          (onButtonClick)=\"handleSave($event)\"\n          class=\"argenta-custom-button\">\n        </argenta-custom-button>\n      </div>\n    </div>\n  </div>      \n</div>\n", styles: ["@charset \"UTF-8\";.card{border-radius:10px;padding:1rem;background-color:#fff;border:none}.card-footer{display:flex;justify-content:flex-end;margin-top:1rem;padding-top:1rem;border-radius:.25rem}.button-group{display:flex;gap:1rem;height:3rem}.argenta-custom-button{height:100%}.row-car{margin-left:-.8rem;margin-right:-.8rem}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ButtonComponent, selector: "argenta-custom-button", inputs: ["type", "label", "btnClass", "fontSize", "disabled", "autofocus", "form", "formaction", "formenctype", "formmethod", "formnovalidate", "formtarget", "name", "value", "permissions"], outputs: ["onButtonClick"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BasicRegistrationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-basic-registration', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"row row-car\">\n  <div class=\"card\">\n    <div class=\"card-content\" style=\"margin-top: 2.5rem;\">\n      <ng-content></ng-content> <!-- Permite a inclus\u00E3o de conte\u00FAdo din\u00E2mico -->\n    </div>\n    <div class=\"card-footer\">\n      <div class=\"button-group\">\n        <argenta-custom-button\n          *ngIf=\"hasPermission(cancelPermissions)\"\n          [type]=\"'button'\"\n          [label]=\"cancelLabel\"\n          [btnClass]=\"ButtonClasses.Light\"\n          (onButtonClick)=\"handleCancel($event)\"\n          class=\"argenta-custom-button\">\n        </argenta-custom-button>\n        <argenta-custom-button\n          *ngIf=\"hasPermission(savePermissions)\"\n          [type]=\"'submit'\"\n          [label]=\"saveLabel\"\n          [btnClass]=\"ButtonClasses.Primary\"\n          (onButtonClick)=\"handleSave($event)\"\n          class=\"argenta-custom-button\">\n        </argenta-custom-button>\n      </div>\n    </div>\n  </div>      \n</div>\n", styles: ["@charset \"UTF-8\";.card{border-radius:10px;padding:1rem;background-color:#fff;border:none}.card-footer{display:flex;justify-content:flex-end;margin-top:1rem;padding-top:1rem;border-radius:.25rem}.button-group{display:flex;gap:1rem;height:3rem}.argenta-custom-button{height:100%}.row-car{margin-left:-.8rem;margin-right:-.8rem}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { cancelLabel: [{
                type: Input
            }], saveLabel: [{
                type: Input
            }], cancelPermissions: [{
                type: Input
            }], savePermissions: [{
                type: Input
            }], cancelClick: [{
                type: Output
            }], saveClick: [{
                type: Output
            }] } });

class CalendarArgentaComponent {
    constructor() {
        this.id = 'argenta-calendar';
        this.placeholder = 'Select a date';
        this.label = 'Select a date';
        this.minDate = null;
        this.maxDate = null;
        this.locale = 'pt';
        this.useTime = false; // Incluir ou não a hora
        this.initialDate = null; // Data inicial no modo de data única
        this.rangeMode = false; // Ativa o modo de intervalo de datas
        this.startDate = null; // Data de início do intervalo
        this.endDate = null; // Data de fim do intervalo
        this.closeButtonLabel = 'Fechar'; // Texto do botão de fechar
        this.rangeChange = new EventEmitter(); // Evento que emite data única ou intervalo
        this.currentYear = new Date().getFullYear();
        this.currentMonth = new Date().getMonth();
        this.selectedDate = null;
        this.selectedStartDate = null;
        this.selectedEndDate = null;
        this.isCalendarVisible = false;
        this.inputDate = '';
        this.invalidDate = false;
        this.isSelectingStart = true; // Controla se estamos selecionando a data inicial ou final
        this.startTime = '';
        this.endTime = '';
        this.selectedTime = '';
        this.locales = {
            en: {
                months: [
                    'January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'
                ],
                daysOfWeek: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
                invalidDateMessage: 'Invalid date. Please enter a date in the format dd/MM/yyyy',
                startTimeLabel: 'Start Time',
                endTimeLabel: 'End Time',
            },
            pt: {
                months: [
                    'Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Dezembro'
                ],
                daysOfWeek: ['Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sáb'],
                invalidDateMessage: 'Data inválida. Por favor, insira uma data no formato dd/MM/yyyy',
                startTimeLabel: 'Hora de Início',
                endTimeLabel: 'Hora de Fim',
            },
            es: {
                months: [
                    'Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'
                ],
                daysOfWeek: ['Do', 'Lu', 'Ma', 'Mi', 'Ju', 'Vi', 'Sá'],
                invalidDateMessage: 'Fecha inválida. Por favor, ingrese una fecha en el formato dd/MM/yyyy',
                startTimeLabel: 'Hora de Inicio',
                endTimeLabel: 'Hora de Fin',
            }
        };
    }
    ngOnInit() {
        if (this.rangeMode) {
            if (this.startDate) {
                this.selectedStartDate = this.parseDate(this.startDate);
                this.startTime = this.formatTimeForDisplay(this.selectedStartDate);
            }
            if (this.endDate) {
                this.selectedEndDate = this.parseDate(this.endDate);
                this.endTime = this.formatTimeForDisplay(this.selectedEndDate);
            }
            this.updateInputForRange(); // Atualiza o input no modo range com horas
        }
        else {
            if (this.initialDate) {
                this.updateCalendar(this.initialDate); // Atualiza o input único com a data inicial
                this.selectedTime = this.formatTimeForDisplay(this.selectedDate);
            }
        }
    }
    ngOnChanges(changes) {
        if (changes['initialDate'] && changes['initialDate'].currentValue) {
            this.updateCalendar(changes['initialDate'].currentValue);
        }
    }
    // Atualiza o calendário para exibir a data única e a hora
    updateCalendar(dateString) {
        const parsedDate = this.parseDate(dateString);
        if (parsedDate && this.validateDate(dateString)) {
            this.selectedDate = parsedDate;
            this.currentYear = parsedDate.getFullYear();
            this.currentMonth = parsedDate.getMonth();
            this.inputDate = this.formatDateForDisplay(parsedDate); // Inclui a hora no input principal
            this.emitSingleOrRange(); // Emite data única ou intervalo
            this.invalidDate = false;
        }
        else {
            this.invalidDate = true;
        }
    }
    onInputChange(event) {
        const inputValue = event.target.value;
        this.inputDate = this.applyDateMask(inputValue);
        if (this.rangeMode) {
            const dateParts = this.inputDate.split(' - ');
            if (dateParts.length === 2) {
                const [startDate, endDate] = dateParts;
                // Valida as duas partes do intervalo
                if (this.validateDate(startDate) && this.validateDate(endDate)) {
                    this.invalidDate = false;
                    const parsedStartDate = this.parseDate(startDate);
                    const parsedEndDate = this.parseDate(endDate);
                    if (parsedStartDate && parsedEndDate) {
                        this.selectedStartDate = parsedStartDate;
                        this.selectedEndDate = parsedEndDate;
                        this.emitSingleOrRange(); // Emite o intervalo atualizado
                    }
                }
                else {
                    this.invalidDate = true;
                }
            }
        }
        else {
            // Valida data única
            if ((this.useTime && this.inputDate.length === 16) || (!this.useTime && this.inputDate.length === 10)) {
                if (this.validateDate(this.inputDate)) {
                    this.invalidDate = false;
                    const parsedDate = this.parseDate(this.inputDate);
                    if (parsedDate) {
                        this.selectedDate = parsedDate;
                        this.emitSingleOrRange(); // Emite a data única atualizada
                    }
                }
                else {
                    this.invalidDate = true;
                }
            }
        }
    }
    // Atualiza o input no modo intervalo
    updateInputForRange() {
        if (this.selectedStartDate && this.selectedEndDate) {
            const formattedStart = this.formatDateForDisplay(this.selectedStartDate);
            const formattedEnd = this.formatDateForDisplay(this.selectedEndDate);
            this.inputDate = `${formattedStart} - ${formattedEnd}`;
        }
        else if (this.selectedStartDate) {
            this.inputDate = this.formatDateForDisplay(this.selectedStartDate);
        }
    }
    /// Emite data única ou intervalo, incluindo horas
    emitSingleOrRange() {
        if (this.rangeMode) {
            const formattedStart = this.selectedStartDate ? this.formatDateForDisplay(this.selectedStartDate) : '';
            const formattedEnd = this.selectedEndDate ? this.formatDateForDisplay(this.selectedEndDate) : '';
            this.inputDate = `${formattedStart} - ${formattedEnd}`; // Atualiza o input principal com o range e horas
            this.rangeChange.emit({ start: formattedStart, end: formattedEnd });
        }
        else {
            const formattedDate = this.selectedDate ? this.formatDateForDisplay(this.selectedDate) : '';
            this.inputDate = formattedDate; // Atualiza o input principal com a data única e hora
            this.rangeChange.emit({ start: formattedDate, end: '' });
        }
    }
    // Função para tratar mudanças nas horas
    onTimeChange(type) {
        if (type === 'start') {
            if (this.selectedStartDate) {
                const [hours, minutes] = this.startTime ? this.startTime.split(':') : ['00', '00'];
                this.selectedStartDate.setHours(+hours, +minutes);
            }
        }
        else if (type === 'end') {
            if (this.selectedEndDate) {
                const [hours, minutes] = this.endTime ? this.endTime.split(':') : ['00', '00'];
                this.selectedEndDate.setHours(+hours, +minutes);
            }
        }
        else if (type === 'single') {
            if (this.selectedDate) {
                const [hours, minutes] = this.selectedTime ? this.selectedTime.split(':') : ['00', '00'];
                this.selectedDate.setHours(+hours, +minutes);
            }
        }
        this.emitSingleOrRange(); // Atualiza o valor no input principal
    }
    // Função para formatação da hora no input de hora
    formatTimeForDisplay(date) {
        if (!date)
            return '';
        const hours = date.getHours().toString().padStart(2, '0');
        const minutes = date.getMinutes().toString().padStart(2, '0');
        return `${hours}:${minutes}`;
    }
    // Método para selecionar uma data no calendário
    selectDate(day) {
        const date = new Date(this.currentYear, this.currentMonth, day);
        if (this.rangeMode) {
            // Lógica para rangeMode
            if (this.isSelectingStart) {
                this.selectedStartDate = date;
                if (this.startTime) {
                    const [hours, minutes] = this.startTime.split(':');
                    this.selectedStartDate.setHours(+hours, +minutes);
                }
                else {
                    this.selectedStartDate.setHours(0, 0);
                    this.startTime = '00:00';
                }
                this.isSelectingStart = false;
            }
            else {
                this.selectedEndDate = date;
                if (this.endTime) {
                    const [hours, minutes] = this.endTime.split(':');
                    this.selectedEndDate.setHours(+hours, +minutes);
                }
                else {
                    this.selectedEndDate.setHours(0, 0);
                    this.endTime = '00:00';
                }
                this.isSelectingStart = true;
                this.emitSingleOrRange();
            }
            this.updateInputForRange();
            // O calendário só será fechado ao clicar no botão "Fechar"
        }
        else {
            // Lógica para quando não está em rangeMode
            this.selectedDate = date;
            if (this.selectedTime) {
                const [hours, minutes] = this.selectedTime.split(':');
                this.selectedDate.setHours(+hours, +minutes);
            }
            else {
                this.selectedDate.setHours(0, 0);
                this.selectedTime = '00:00';
            }
            this.inputDate = this.formatDateForDisplay(date);
            this.emitSingleOrRange();
            // **Fechar o calendário apenas se `useTime` for false**
            if (!this.useTime) {
                this.isCalendarVisible = false; // Fecha o calendário automaticamente se `useTime` for false
            }
            // Se `useTime` for true, o calendário permanece aberto para inserir a hora
        }
    }
    applyDateMask(inputValue) {
        // Remove qualquer caractere que não seja numérico
        let digitsOnly = inputValue.replace(/\D/g, '');
        if (this.rangeMode) {
            const maxLength = this.useTime ? 28 : 17; // Ajusta o comprimento máximo para intervalo com ou sem tempo
            // Certifica-se de que a entrada não excede o comprimento permitido
            if (digitsOnly.length > maxLength) {
                digitsOnly = digitsOnly.substring(0, maxLength);
            }
            // Primeiro intervalo (start date)
            let day1 = digitsOnly.substring(0, 2);
            let month1 = digitsOnly.substring(2, 4);
            let year1 = digitsOnly.substring(4, 8);
            let hour1 = digitsOnly.substring(8, 10);
            let minute1 = digitsOnly.substring(10, 12);
            // Cria a data formatada para a primeira parte (start date)
            let maskedDate = `${day1}/${month1}/${year1}`;
            if (this.useTime && hour1 && minute1) {
                maskedDate += ` ${hour1}:${minute1}`;
            }
            // Adiciona o separador ' - ' se houver dados para o segundo intervalo
            if (digitsOnly.length > 12) {
                maskedDate += ' - ';
            }
            // Segundo intervalo (end date)
            let day2 = digitsOnly.substring(12, 14);
            let month2 = digitsOnly.substring(14, 16);
            let year2 = digitsOnly.substring(16, 20);
            let hour2 = digitsOnly.substring(20, 22);
            let minute2 = digitsOnly.substring(22, 24);
            let endDatePart = `${day2}/${month2}/${year2}`;
            if (this.useTime && hour2 && minute2) {
                endDatePart += ` ${hour2}:${minute2}`;
            }
            // Adiciona a segunda parte (end date) ao input, se aplicável
            if (digitsOnly.length > 12) {
                maskedDate += endDatePart;
            }
            return maskedDate;
        }
        else {
            const maxLength = this.useTime ? 16 : 10;
            if (digitsOnly.length > maxLength) {
                digitsOnly = digitsOnly.substring(0, maxLength);
            }
            let day = digitsOnly.substring(0, 2);
            let month = digitsOnly.substring(2, 4);
            let year = digitsOnly.substring(4, 8);
            let hour = digitsOnly.substring(8, 10);
            let minute = digitsOnly.substring(10, 12);
            let maskedDate = `${day}/${month}/${year}`;
            if (this.useTime && hour && minute) {
                maskedDate += ` ${hour}:${minute}`;
            }
            return maskedDate;
        }
    }
    // Validação da data
    validateDate(inputValue) {
        const [datePart, timePart] = inputValue.split(' ');
        const [dayStr, monthStr, yearStr] = datePart.split('/');
        const day = Number(dayStr);
        const month = Number(monthStr);
        const year = Number(yearStr);
        if (month < 1 || month > 12 || yearStr.length !== 4 || isNaN(year)) {
            return false;
        }
        const lastDayOfMonth = new Date(year, month, 0).getDate();
        if (day < 1 || day > lastDayOfMonth) {
            return false;
        }
        if (this.useTime && timePart) {
            const [hourStr, minuteStr] = timePart.split(':');
            const hour = Number(hourStr);
            const minute = Number(minuteStr);
            if (hour < 0 || hour > 23 || minute < 0 || minute > 59 || isNaN(hour) || isNaN(minute)) {
                return false;
            }
        }
        return true;
    }
    handleKeyPress(event) {
        const charCode = event.key.charCodeAt(0);
        // Permitir apenas números e barra "/"
        if ((charCode < 48 || charCode > 57) && charCode !== 47) {
            event.preventDefault(); // Bloqueia a inserção de caracteres não permitidos
        }
        // Limita o tamanho da entrada conforme o tipo de dado (com ou sem hora)
        if (this.inputDate.replace(/\D/g, '').length >= (this.useTime ? 12 : 8)) {
            event.preventDefault(); // Limita o número de caracteres permitidos
        }
    }
    // Fecha o calendário
    closeCalendar() {
        this.isCalendarVisible = false;
    }
    // Alterna a visibilidade do calendário
    toggleCalendar() {
        this.isCalendarVisible = !this.isCalendarVisible;
    }
    // Formata a data e hora para exibição no input principal
    formatDateForDisplay(date) {
        const day = date.getDate().toString().padStart(2, '0');
        const month = (date.getMonth() + 1).toString().padStart(2, '0');
        const year = date.getFullYear();
        let formattedDate = `${day}/${month}/${year}`;
        if (this.useTime) {
            const hours = date.getHours().toString().padStart(2, '0');
            const minutes = date.getMinutes().toString().padStart(2, '0');
            formattedDate += ` ${hours}:${minutes}`;
        }
        return formattedDate;
    }
    // Formata a data para emitir no evento
    formatDateForEmit(date) {
        const day = date.getDate().toString().padStart(2, '0');
        const month = (date.getMonth() + 1).toString().padStart(2, '0');
        const year = date.getFullYear();
        let formattedDate = `${day}/${month}/${year}`;
        if (this.useTime) {
            const hours = date.getHours().toString().padStart(2, '0');
            const minutes = date.getMinutes().toString().padStart(2, '0');
            formattedDate += ` - ${hours}:${minutes}`;
        }
        return formattedDate;
    }
    // Função para parsing de string para Date
    parseDate(dateStr) {
        const [datePart, timePart] = dateStr.split(' ');
        const [day, month, year] = datePart.split('/').map(Number);
        if (!day || !month || !year) {
            return null;
        }
        const date = new Date(year, month - 1, day);
        if (this.useTime && timePart) {
            const [hour, minute] = timePart.split(':').map(Number);
            date.setHours(hour || 0, minute || 0);
        }
        return date;
    }
    // Gera a lista de dias no mês atual
    get daysInMonth() {
        const firstDayOfMonth = new Date(this.currentYear, this.currentMonth, 1).getDay();
        const totalDaysInMonth = new Date(this.currentYear, this.currentMonth + 1, 0).getDate();
        const daysArray = Array.from({ length: totalDaysInMonth }, (_, i) => i + 1);
        const leadingEmptyDays = Array(firstDayOfMonth).fill(null); // Dias vazios antes do primeiro dia do mês
        return [...leadingEmptyDays, ...daysArray];
    }
    // Verifica se um dia está selecionado
    isSelected(day) {
        if (!this.selectedDate)
            return false;
        const selectedDay = this.selectedDate.getDate();
        const selectedMonth = this.selectedDate.getMonth();
        const selectedYear = this.selectedDate.getFullYear();
        return selectedDay === day && selectedMonth === this.currentMonth && selectedYear === this.currentYear;
    }
    // Verifica se o dia é hoje
    isToday(day) {
        const today = new Date();
        return today.getFullYear() === this.currentYear && today.getMonth() === this.currentMonth && today.getDate() === day;
    }
    // Verifica se a data está desabilitada
    isDateDisabled(day) {
        const date = new Date(this.currentYear, this.currentMonth, day);
        if (this.minDate && date < this.minDate)
            return true;
        if (this.maxDate && date > this.maxDate)
            return true;
        return false;
    }
    // Verifica se um dia está no intervalo selecionado
    isInRange(day) {
        if (!this.selectedStartDate || !this.selectedEndDate)
            return false;
        const date = new Date(this.currentYear, this.currentMonth, day);
        return date >= this.selectedStartDate && date <= this.selectedEndDate;
    }
    // Avança para o próximo mês
    nextMonth() {
        if (this.currentMonth === 11) {
            this.currentMonth = 0;
            this.currentYear++;
        }
        else {
            this.currentMonth++;
        }
    }
    // Retrocede para o mês anterior
    prevMonth() {
        if (this.currentMonth === 0) {
            this.currentMonth = 11;
            this.currentYear--;
        }
        else {
            this.currentMonth--;
        }
    }
    // Retorna a lista de meses de acordo com o locale
    get months() {
        return this.locales[this.locale]?.months || this.locales['en'].months;
    }
    // Retorna a lista de dias da semana de acordo com o locale
    get daysOfWeek() {
        return this.locales[this.locale]?.daysOfWeek || this.locales['en'].daysOfWeek;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CalendarArgentaComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CalendarArgentaComponent, selector: "argenta-calendar", inputs: { id: "id", placeholder: "placeholder", label: "label", minDate: "minDate", maxDate: "maxDate", locale: "locale", useTime: "useTime", initialDate: "initialDate", rangeMode: "rangeMode", startDate: "startDate", endDate: "endDate", closeButtonLabel: "closeButtonLabel" }, outputs: { rangeChange: "rangeChange" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label [for]=\"id\" [ngClass]=\"'label-styles'\">{{ label }}</label>\n  <div class=\"input-wrapper\">\n    <input\n      id=\"{{ id }}\"\n      type=\"text\"\n      class=\"custom-input\"\n      [attr.placeholder]=\"rangeMode && useTime ? 'dd/MM/yyyy HH:mm - dd/MM/yyyy HH:mm' : \n      rangeMode && !useTime ? 'dd/MM/yyyy - dd/MM/yyyy' :(!rangeMode && useTime ? 'dd/MM/yyyy HH:mm' : 'dd/MM/yyyy')\"\n      [value]=\"inputDate\"\n      (input)=\"onInputChange($event)\"\n      (keypress)=\"handleKeyPress($event)\"\n      (click)=\"toggleCalendar()\"\n    />\n    <lucide-icon name=\"calendar\" class=\"calendar-icon\"></lucide-icon>\n  </div>\n\n  <div *ngIf=\"invalidDate\" class=\"error-message\">\n    {{ locales[locale].invalidDateMessage }}\n    <span *ngIf=\"useTime\"> HH:mm.</span>\n  </div>\n\n  <div class=\"calendar-wrapper\">\n    <div class=\"calendar-container\" [ngClass]=\"{ open: isCalendarVisible }\">\n      <div class=\"calendar\">\n        <div class=\"calendar-header\">\n          <button (click)=\"prevMonth()\">&#8249;</button>\n          <span>{{ months[currentMonth] }} {{ currentYear }}</span>\n          <button (click)=\"nextMonth()\">&#8250;</button>\n        </div>\n\n        <div class=\"calendar-body\">\n          <div class=\"calendar-day-names\">\n            <span *ngFor=\"let day of daysOfWeek\">{{ day }}</span>\n          </div>\n\n          <div class=\"calendar-days\">\n            <span\n              *ngFor=\"let day of daysInMonth; let i = index\"\n              [class.today]=\"isToday(day)\"\n              [class.selected]=\"isSelected(day)\"\n              [class.in-range]=\"isInRange(day)\"\n              [class.disabled]=\"isDateDisabled(day)\"\n              (click)=\"day ? selectDate(day) : null\"\n            >\n              {{ day ? day : \"\" }}\n            </span>\n          </div>\n        </div>\n\n        <!-- Inputs para inser\u00E7\u00E3o das horas -->\n        <div *ngIf=\"useTime\" class=\"time-inputs\">\n          <!-- Campo de hora de in\u00EDcio -->\n          <div *ngIf=\"rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.startTimeLabel || 'Hora de In\u00EDcio' }}</label> <!-- Usando tradu\u00E7\u00E3o -->\n            <input type=\"time\" [(ngModel)]=\"startTime\" (change)=\"onTimeChange('start')\" />\n          </div>\n\n          <!-- Campo de hora de fim -->\n          <div *ngIf=\"rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.endTimeLabel || 'Hora de Fim' }}</label> <!-- Usando tradu\u00E7\u00E3o -->\n            <input type=\"time\" [(ngModel)]=\"endTime\" (change)=\"onTimeChange('end')\" />\n          </div>\n\n          <!-- Campo de hora \u00FAnica (se n\u00E3o for range) -->\n          <div *ngIf=\"!rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.startTimeLabel || 'Hora' }}</label> <!-- Usando o label de in\u00EDcio -->\n            <input type=\"time\" [(ngModel)]=\"selectedTime\" (change)=\"onTimeChange('single')\" />\n          </div>\n        </div>\n\n        <!-- Bot\u00E3o de fechar o calend\u00E1rio -->\n        <button class=\"close-button\" (click)=\"closeCalendar()\">{{ closeButtonLabel }}</button>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.calendar-container{overflow:hidden;max-height:0;transition:max-height .4s ease;position:absolute;top:100%;left:0;z-index:9999;background-color:#fff;box-shadow:0 4px 12px #0000001a;width:auto;max-width:none}.calendar-wrapper{position:relative}@media (max-width: 300px){.calendar-container{width:100vw;left:0}}.calendar-container.open{max-height:500px}.calendar{display:inline-block;border:1px solid #ccc;border-radius:8px;padding:10px;width:450px;font-family:var(--font-family);transition:max-height .4s ease;background-color:#fdfdfd}.calendar .calendar-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px;font-weight:700}.calendar .calendar-header button{background-color:var(--primary-color);color:var(--text-color);border:none;padding:8px 12px;cursor:pointer;border-radius:8px;font-size:1.2rem;transition:background-color .2s}.calendar .calendar-header button:hover{background-color:var(--secondary-color)}.calendar .calendar-header span{font-size:1.4rem;color:var(--primary-color);text-align:center;flex-grow:1}.calendar .calendar-body{display:grid;grid-template-columns:repeat(7,1fr);gap:7px}.calendar .calendar-body .calendar-day-names{display:contents}.calendar .calendar-body .calendar-day-names span{text-align:center;font-weight:700;margin-bottom:5px;font-size:.9rem}.calendar .calendar-body .calendar-day-names span:nth-child(1){color:#ff8080}.calendar .calendar-body .calendar-day-names span:nth-child(7){color:#555}.calendar .calendar-body .calendar-days{display:contents}.calendar .calendar-body .calendar-days span{display:flex;justify-content:center;align-items:center;margin:1px;padding:10px;height:45px;width:45px;cursor:pointer;border-radius:50%;transition:background-color .2s,color .2s ease}.calendar .calendar-body .calendar-days span.today{background-color:var(--secondary-color);color:var(--text-color)}.calendar .calendar-body .calendar-days span.selected{background-color:var(--primary-color);color:var(--text-color)}.calendar .calendar-body .calendar-days span.disabled{background-color:#e9ecef;color:#999;cursor:not-allowed}.calendar .calendar-body .calendar-days span:hover:not(.disabled){background-color:var(--secondary-color);color:var(--text-color)}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;height:46px;padding:.5rem .75rem;border:1px solid #ccc;border-radius:4px;width:100%;box-sizing:border-box}.custom-input:focus{outline:none;border-color:#ccc}.custom-input::placeholder{font-size:14px;color:#d3d3d3}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.error-message{position:relative;background-color:#ff8080;color:#fff;padding:10px;border-radius:8px;font-size:.9rem;max-width:250px;margin-top:5px}.error-message:after{content:\"\";position:absolute;top:100%;left:20px;border-width:10px;border-style:solid;border-color:#ff8080 transparent transparent transparent}.input-wrapper{position:relative;display:inline-block;width:100%}.input-wrapper .custom-input{width:100%;padding-right:40px;box-sizing:border-box}.input-wrapper .calendar-icon{position:absolute;top:50%;right:10px;transform:translateY(-50%);pointer-events:none;color:#b8b8b8}.calendar-days{display:contents}.calendar-days span{display:flex;justify-content:center;align-items:center;margin:1px;padding:10px;height:45px;width:45px;cursor:pointer;border-radius:50%;transition:background-color .2s,color .2s ease}.calendar-days span.today{background-color:var(--secondary-color);color:var(--text-color);text-decoration:underline}.calendar-days span.selected{background-color:var(--primary-color);color:var(--text-color)}.calendar-days span.in-range{background-color:#fd9;color:#000}.calendar-days span.disabled{background-color:#e9ecef;color:#999;cursor:not-allowed}.calendar-days span:hover:not(.disabled){background-color:var(--secondary-color);color:var(--text-color)}.calendar-body{position:relative}.close-button{float:right;margin-top:10px;background-color:#fff3cd;color:#383838;border:none;padding:6px 12px;cursor:pointer;border-radius:20px;font-size:12px;font-weight:500;transition:all .2s ease}.close-button:hover{background-color:#e9ebec;box-shadow:0 2px 4px #eeebeb26}.close-button:active{transform:translateY(1px)}.time-inputs{display:flex;justify-content:space-between;margin-top:10px}.time-input{display:flex;flex-direction:column;width:45%}.time-input label{font-size:.9rem;margin-bottom:5px}.time-input input{padding:8px;font-size:.9rem;border:1px solid #ccc;border-radius:4px}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CalendarArgentaComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-calendar', template: "<div class=\"form-group\">\n  <label [for]=\"id\" [ngClass]=\"'label-styles'\">{{ label }}</label>\n  <div class=\"input-wrapper\">\n    <input\n      id=\"{{ id }}\"\n      type=\"text\"\n      class=\"custom-input\"\n      [attr.placeholder]=\"rangeMode && useTime ? 'dd/MM/yyyy HH:mm - dd/MM/yyyy HH:mm' : \n      rangeMode && !useTime ? 'dd/MM/yyyy - dd/MM/yyyy' :(!rangeMode && useTime ? 'dd/MM/yyyy HH:mm' : 'dd/MM/yyyy')\"\n      [value]=\"inputDate\"\n      (input)=\"onInputChange($event)\"\n      (keypress)=\"handleKeyPress($event)\"\n      (click)=\"toggleCalendar()\"\n    />\n    <lucide-icon name=\"calendar\" class=\"calendar-icon\"></lucide-icon>\n  </div>\n\n  <div *ngIf=\"invalidDate\" class=\"error-message\">\n    {{ locales[locale].invalidDateMessage }}\n    <span *ngIf=\"useTime\"> HH:mm.</span>\n  </div>\n\n  <div class=\"calendar-wrapper\">\n    <div class=\"calendar-container\" [ngClass]=\"{ open: isCalendarVisible }\">\n      <div class=\"calendar\">\n        <div class=\"calendar-header\">\n          <button (click)=\"prevMonth()\">&#8249;</button>\n          <span>{{ months[currentMonth] }} {{ currentYear }}</span>\n          <button (click)=\"nextMonth()\">&#8250;</button>\n        </div>\n\n        <div class=\"calendar-body\">\n          <div class=\"calendar-day-names\">\n            <span *ngFor=\"let day of daysOfWeek\">{{ day }}</span>\n          </div>\n\n          <div class=\"calendar-days\">\n            <span\n              *ngFor=\"let day of daysInMonth; let i = index\"\n              [class.today]=\"isToday(day)\"\n              [class.selected]=\"isSelected(day)\"\n              [class.in-range]=\"isInRange(day)\"\n              [class.disabled]=\"isDateDisabled(day)\"\n              (click)=\"day ? selectDate(day) : null\"\n            >\n              {{ day ? day : \"\" }}\n            </span>\n          </div>\n        </div>\n\n        <!-- Inputs para inser\u00E7\u00E3o das horas -->\n        <div *ngIf=\"useTime\" class=\"time-inputs\">\n          <!-- Campo de hora de in\u00EDcio -->\n          <div *ngIf=\"rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.startTimeLabel || 'Hora de In\u00EDcio' }}</label> <!-- Usando tradu\u00E7\u00E3o -->\n            <input type=\"time\" [(ngModel)]=\"startTime\" (change)=\"onTimeChange('start')\" />\n          </div>\n\n          <!-- Campo de hora de fim -->\n          <div *ngIf=\"rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.endTimeLabel || 'Hora de Fim' }}</label> <!-- Usando tradu\u00E7\u00E3o -->\n            <input type=\"time\" [(ngModel)]=\"endTime\" (change)=\"onTimeChange('end')\" />\n          </div>\n\n          <!-- Campo de hora \u00FAnica (se n\u00E3o for range) -->\n          <div *ngIf=\"!rangeMode\" class=\"time-input\">\n            <label>{{ locales[locale]?.startTimeLabel || 'Hora' }}</label> <!-- Usando o label de in\u00EDcio -->\n            <input type=\"time\" [(ngModel)]=\"selectedTime\" (change)=\"onTimeChange('single')\" />\n          </div>\n        </div>\n\n        <!-- Bot\u00E3o de fechar o calend\u00E1rio -->\n        <button class=\"close-button\" (click)=\"closeCalendar()\">{{ closeButtonLabel }}</button>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.calendar-container{overflow:hidden;max-height:0;transition:max-height .4s ease;position:absolute;top:100%;left:0;z-index:9999;background-color:#fff;box-shadow:0 4px 12px #0000001a;width:auto;max-width:none}.calendar-wrapper{position:relative}@media (max-width: 300px){.calendar-container{width:100vw;left:0}}.calendar-container.open{max-height:500px}.calendar{display:inline-block;border:1px solid #ccc;border-radius:8px;padding:10px;width:450px;font-family:var(--font-family);transition:max-height .4s ease;background-color:#fdfdfd}.calendar .calendar-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px;font-weight:700}.calendar .calendar-header button{background-color:var(--primary-color);color:var(--text-color);border:none;padding:8px 12px;cursor:pointer;border-radius:8px;font-size:1.2rem;transition:background-color .2s}.calendar .calendar-header button:hover{background-color:var(--secondary-color)}.calendar .calendar-header span{font-size:1.4rem;color:var(--primary-color);text-align:center;flex-grow:1}.calendar .calendar-body{display:grid;grid-template-columns:repeat(7,1fr);gap:7px}.calendar .calendar-body .calendar-day-names{display:contents}.calendar .calendar-body .calendar-day-names span{text-align:center;font-weight:700;margin-bottom:5px;font-size:.9rem}.calendar .calendar-body .calendar-day-names span:nth-child(1){color:#ff8080}.calendar .calendar-body .calendar-day-names span:nth-child(7){color:#555}.calendar .calendar-body .calendar-days{display:contents}.calendar .calendar-body .calendar-days span{display:flex;justify-content:center;align-items:center;margin:1px;padding:10px;height:45px;width:45px;cursor:pointer;border-radius:50%;transition:background-color .2s,color .2s ease}.calendar .calendar-body .calendar-days span.today{background-color:var(--secondary-color);color:var(--text-color)}.calendar .calendar-body .calendar-days span.selected{background-color:var(--primary-color);color:var(--text-color)}.calendar .calendar-body .calendar-days span.disabled{background-color:#e9ecef;color:#999;cursor:not-allowed}.calendar .calendar-body .calendar-days span:hover:not(.disabled){background-color:var(--secondary-color);color:var(--text-color)}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;height:46px;padding:.5rem .75rem;border:1px solid #ccc;border-radius:4px;width:100%;box-sizing:border-box}.custom-input:focus{outline:none;border-color:#ccc}.custom-input::placeholder{font-size:14px;color:#d3d3d3}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.error-message{position:relative;background-color:#ff8080;color:#fff;padding:10px;border-radius:8px;font-size:.9rem;max-width:250px;margin-top:5px}.error-message:after{content:\"\";position:absolute;top:100%;left:20px;border-width:10px;border-style:solid;border-color:#ff8080 transparent transparent transparent}.input-wrapper{position:relative;display:inline-block;width:100%}.input-wrapper .custom-input{width:100%;padding-right:40px;box-sizing:border-box}.input-wrapper .calendar-icon{position:absolute;top:50%;right:10px;transform:translateY(-50%);pointer-events:none;color:#b8b8b8}.calendar-days{display:contents}.calendar-days span{display:flex;justify-content:center;align-items:center;margin:1px;padding:10px;height:45px;width:45px;cursor:pointer;border-radius:50%;transition:background-color .2s,color .2s ease}.calendar-days span.today{background-color:var(--secondary-color);color:var(--text-color);text-decoration:underline}.calendar-days span.selected{background-color:var(--primary-color);color:var(--text-color)}.calendar-days span.in-range{background-color:#fd9;color:#000}.calendar-days span.disabled{background-color:#e9ecef;color:#999;cursor:not-allowed}.calendar-days span:hover:not(.disabled){background-color:var(--secondary-color);color:var(--text-color)}.calendar-body{position:relative}.close-button{float:right;margin-top:10px;background-color:#fff3cd;color:#383838;border:none;padding:6px 12px;cursor:pointer;border-radius:20px;font-size:12px;font-weight:500;transition:all .2s ease}.close-button:hover{background-color:#e9ebec;box-shadow:0 2px 4px #eeebeb26}.close-button:active{transform:translateY(1px)}.time-inputs{display:flex;justify-content:space-between;margin-top:10px}.time-input{display:flex;flex-direction:column;width:45%}.time-input label{font-size:.9rem;margin-bottom:5px}.time-input input{padding:8px;font-size:.9rem;border:1px solid #ccc;border-radius:4px}\n"] }]
        }], propDecorators: { id: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], label: [{
                type: Input
            }], minDate: [{
                type: Input
            }], maxDate: [{
                type: Input
            }], locale: [{
                type: Input
            }], useTime: [{
                type: Input
            }], initialDate: [{
                type: Input
            }], rangeMode: [{
                type: Input
            }], startDate: [{
                type: Input
            }], endDate: [{
                type: Input
            }], closeButtonLabel: [{
                type: Input
            }], rangeChange: [{
                type: Output
            }] } });

class CardInfoComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.title = "Title";
        this.titleCard = "Title";
        this.subTitleCard = "sub-title";
        this.cardClass = ButtonClasses.Primary;
        this.iconCard = "check";
        this.clicked = false;
        this.onCardClick = new EventEmitter();
    }
    ngOnInit() { }
    get dynamicStyles() {
        return this.calculateDynamicStyles();
    }
    onClick(event) {
        this.clicked = true;
        this.onCardClick.emit(event);
        setTimeout(() => {
            this.clicked = false;
            this.cdr.detectChanges();
        }, 80);
    }
    calculateDynamicStyles() {
        let backgroundColor = "";
        let textColor = getComputedStyle(document.documentElement)
            .getPropertyValue("--text-color")
            .trim();
        let borderColor = "";
        const getCSSVariable = (variable) => getComputedStyle(document.documentElement)
            .getPropertyValue(variable)
            .trim();
        switch (this.cardClass) {
            case ButtonClasses.Primary:
                backgroundColor = getCSSVariable("--primary-color");
                break;
            case ButtonClasses.Secondary:
                backgroundColor = getCSSVariable("--secondary-color");
                break;
            case ButtonClasses.Success:
                backgroundColor = getCSSVariable("--success-color");
                break;
            case ButtonClasses.Danger:
                backgroundColor = getCSSVariable("--danger-color");
                break;
            case ButtonClasses.Warning:
                backgroundColor = getCSSVariable("--warning-color");
                break;
            case ButtonClasses.Info:
                backgroundColor = getCSSVariable("--info-color");
                break;
            case ButtonClasses.Light:
                backgroundColor = getCSSVariable("--light-color");
                textColor = getCSSVariable("--primary-color");
                break;
            case ButtonClasses.Dark:
                backgroundColor = getCSSVariable("--dark-color");
                break;
            case ButtonClasses.Link:
                backgroundColor = "transparent";
                borderColor = getCSSVariable("--link-border-color");
                textColor = getCSSVariable("--primary-color");
                break;
            default:
                backgroundColor = getCSSVariable("--primary-color");
                break;
        }
        return {
            "background-color": backgroundColor,
            color: textColor,
            border: borderColor ? `1px solid ${borderColor}` : "none",
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CardInfoComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CardInfoComponent, selector: "argenta-card-info", inputs: { title: "title", titleCard: "titleCard", subTitleCard: "subTitleCard", cardClass: "cardClass", iconCard: "iconCard" }, outputs: { onCardClick: "onCardClick" }, ngImport: i0, template: "<div\n  class=\"card order-card\"\n  (click)=\"onClick($event)\"\n  [ngClass]=\"cardClass\"\n  [ngStyle]=\"dynamicStyles\"\n  title=\"{{title}}\"\n>\n  <div class=\"card-body\">\n    <h2 class=\"text-white\">{{titleCard}}</h2>\n    <h3 class=\"text-white\">{{subTitleCard}}</h3>\n    <lucide-icon class=\"icon-card\" name=\"{{iconCard}}\" [size]=\"100\"></lucide-icon>\n  </div>\n</div>\n", styles: [".cards-container{display:grid;grid-template-columns:repeat(auto-fit,minmax(240px,1fr));gap:10px}.card{width:100%;height:120px;padding:10px;border-radius:10px;position:relative;overflow:hidden;transition:transform .2s ease-in-out}.card-body{display:flex;flex-direction:column;align-items:flex-start;justify-content:center;text-align:left;padding:5px;position:relative}.card-body h2{font-size:1.5rem!important}.card-body h3{font-size:1.25rem!important}.card:hover{transform:scale(1.05)}.icon-card{position:absolute;bottom:-20px;right:30px;max-width:80px;max-height:80px;color:#fff;opacity:.5}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CardInfoComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-card-info", template: "<div\n  class=\"card order-card\"\n  (click)=\"onClick($event)\"\n  [ngClass]=\"cardClass\"\n  [ngStyle]=\"dynamicStyles\"\n  title=\"{{title}}\"\n>\n  <div class=\"card-body\">\n    <h2 class=\"text-white\">{{titleCard}}</h2>\n    <h3 class=\"text-white\">{{subTitleCard}}</h3>\n    <lucide-icon class=\"icon-card\" name=\"{{iconCard}}\" [size]=\"100\"></lucide-icon>\n  </div>\n</div>\n", styles: [".cards-container{display:grid;grid-template-columns:repeat(auto-fit,minmax(240px,1fr));gap:10px}.card{width:100%;height:120px;padding:10px;border-radius:10px;position:relative;overflow:hidden;transition:transform .2s ease-in-out}.card-body{display:flex;flex-direction:column;align-items:flex-start;justify-content:center;text-align:left;padding:5px;position:relative}.card-body h2{font-size:1.5rem!important}.card-body h3{font-size:1.25rem!important}.card:hover{transform:scale(1.05)}.icon-card{position:absolute;bottom:-20px;right:30px;max-width:80px;max-height:80px;color:#fff;opacity:.5}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { title: [{
                type: Input
            }], titleCard: [{
                type: Input
            }], subTitleCard: [{
                type: Input
            }], cardClass: [{
                type: Input
            }], iconCard: [{
                type: Input
            }], onCardClick: [{
                type: Output
            }] } });

class CardComponent {
    constructor() {
        this.cardTitle = 'Default Title';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CardComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CardComponent, selector: "sim-app-card", inputs: { cardTitle: "cardTitle" }, ngImport: i0, template: `
    <div class="card mb-3">
      <div class="card-header">
        <h3>{{ cardTitle }}</h3>
      </div>
      <div class="card-body">
        <ng-content></ng-content>
      </div>
    </div>
  `, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'sim-app-card',
                    template: `
    <div class="card mb-3">
      <div class="card-header">
        <h3>{{ cardTitle }}</h3>
      </div>
      <div class="card-body">
        <ng-content></ng-content>
      </div>
    </div>
  `
                }]
        }], propDecorators: { cardTitle: [{
                type: Input
            }] } });

class CheckboxComponent {
    constructor() {
        this.id = 'defaultCheckbox';
        this.checked = false;
        this.disabled = false;
        this.label = 'Check me out';
        this.marginTop = 0;
        this.marginBottom = 0;
        this.marginLeft = 0;
        this.marginRight = 0;
        this.checkedChange = new EventEmitter();
        this.onChangeFn = () => { };
        this.onTouchedFn = () => { };
    }
    onChange(event) {
        const input = event.target;
        this.checked = input.checked;
        this.onChangeFn(this.checked);
        this.checkedChange.emit(this.checked);
    }
    writeValue(value) {
        this.checked = value;
    }
    registerOnChange(fn) {
        this.onChangeFn = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedFn = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CheckboxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CheckboxComponent, selector: "sim-app-checkbox", inputs: { id: "id", checked: "checked", disabled: "disabled", label: "label", marginTop: "marginTop", marginBottom: "marginBottom", marginLeft: "marginLeft", marginRight: "marginRight" }, outputs: { checkedChange: "checkedChange" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => CheckboxComponent),
                multi: true
            }
        ], ngImport: i0, template: `
    <div
      class="form-group form-check"
      [ngStyle]="{
        'margin-top': marginTop + 'rem',
        'margin-bottom': marginBottom + 'rem',
        'margin-left': marginLeft + 'rem',
        'margin-right': marginRight + 'rem'
      }">
      <input
        type="checkbox"
        class="form-check-input"
        [id]="id"
        [checked]="checked"
        [disabled]="disabled"
        (change)="onChange($event)"
      />
      <label class="form-check-label" [for]="id">{{ label }}</label>
    </div>
  `, isInline: true, styles: [".form-check-input{font-family:Arial,sans-serif;color:#333;font-size:1rem}.form-check-label{font-family:Arial,sans-serif;color:#333;font-size:1rem;font-weight:700}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CheckboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sim-app-checkbox', template: `
    <div
      class="form-group form-check"
      [ngStyle]="{
        'margin-top': marginTop + 'rem',
        'margin-bottom': marginBottom + 'rem',
        'margin-left': marginLeft + 'rem',
        'margin-right': marginRight + 'rem'
      }">
      <input
        type="checkbox"
        class="form-check-input"
        [id]="id"
        [checked]="checked"
        [disabled]="disabled"
        (change)="onChange($event)"
      />
      <label class="form-check-label" [for]="id">{{ label }}</label>
    </div>
  `, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => CheckboxComponent),
                            multi: true
                        }
                    ], changeDetection: ChangeDetectionStrategy.OnPush, styles: [".form-check-input{font-family:Arial,sans-serif;color:#333;font-size:1rem}.form-check-label{font-family:Arial,sans-serif;color:#333;font-size:1rem;font-weight:700}\n"] }]
        }], propDecorators: { id: [{
                type: Input
            }], checked: [{
                type: Input
            }], disabled: [{
                type: Input
            }], label: [{
                type: Input
            }], marginTop: [{
                type: Input
            }], marginBottom: [{
                type: Input
            }], marginLeft: [{
                type: Input
            }], marginRight: [{
                type: Input
            }], checkedChange: [{
                type: Output
            }] } });

class CodeHighlightComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.code = ''; // Definindo um valor padrão
        this.language = 'typescript';
        this.highlightedCode = '';
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.highlightCode();
            this.cdr.detectChanges();
        });
    }
    highlightCode() {
        const code = hljs.highlight(this.language, this.code).value;
        this.highlightedCode = code;
    }
    copyCode() {
        const codeElement = this.codeElement.nativeElement;
        navigator.clipboard.writeText(codeElement.innerText).then(() => {
            alert('Code copied to clipboard!');
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CodeHighlightComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CodeHighlightComponent, selector: "app-code-highlight", inputs: { code: "code", language: "language" }, viewQueries: [{ propertyName: "codeElement", first: true, predicate: ["codeElement"], descendants: true }], ngImport: i0, template: `
    <div class="code-container">
      <pre><code #codeElement [innerHTML]="highlightedCode"></code></pre>
      <button (click)="copyCode()">Copy</button>
    </div>
  `, isInline: true, styles: [".code-container{position:relative}pre{background-color:#2d2d2d;color:#f8f8f2;padding:1rem;border-radius:5px;overflow-x:auto}button{position:absolute;top:10px;right:10px;background-color:#f8f8f2;border:none;padding:.5rem 1rem;cursor:pointer;border-radius:5px;box-shadow:0 2px 4px #0003;transition:background-color .3s,transform .2s,box-shadow .2s}button:hover{background-color:#e0e0e0;box-shadow:0 4px 8px #0000004d}button:active{background-color:#d0d0d0;transform:scale(.98)}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CodeHighlightComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-code-highlight', template: `
    <div class="code-container">
      <pre><code #codeElement [innerHTML]="highlightedCode"></code></pre>
      <button (click)="copyCode()">Copy</button>
    </div>
  `, styles: [".code-container{position:relative}pre{background-color:#2d2d2d;color:#f8f8f2;padding:1rem;border-radius:5px;overflow-x:auto}button{position:absolute;top:10px;right:10px;background-color:#f8f8f2;border:none;padding:.5rem 1rem;cursor:pointer;border-radius:5px;box-shadow:0 2px 4px #0003;transition:background-color .3s,transform .2s,box-shadow .2s}button:hover{background-color:#e0e0e0;box-shadow:0 4px 8px #0000004d}button:active{background-color:#d0d0d0;transform:scale(.98)}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { code: [{
                type: Input
            }], language: [{
                type: Input
            }], codeElement: [{
                type: ViewChild,
                args: ['codeElement']
            }] } });

class AutofocusDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        this.elementRef.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AutofocusDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: AutofocusDirective, selector: "[appAutofocus]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AutofocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[appAutofocus]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class ConfirmationComponent {
    constructor(activeModal) {
        this.activeModal = activeModal;
        this.title = 'Confirmação';
        this.message = 'Você tem certeza que deseja continuar?';
        this.confirmButtonText = 'Sim';
        this.cancelButtonText = 'Não';
    }
    confirm() {
        this.activeModal.close('confirm');
    }
    cancel() {
        this.activeModal.dismiss('cancel');
    }
    ngOnDestroy() {
        // Clear any subscriptions if there were any
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConfirmationComponent, deps: [{ token: i1$1.NgbActiveModal }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ConfirmationComponent, selector: "app-confirmation", inputs: { title: "title", message: "message", confirmButtonText: "confirmButtonText", cancelButtonText: "cancelButtonText" }, ngImport: i0, template: "<div class=\"modal-header\">\n  <h5 class=\"modal-title\" id=\"confirmationModalLabel\">{{ title }}</h5>\n</div>\n<div class=\"modal-body\">\n  <p>{{ message }}</p>\n</div>\n<div class=\"modal-footer d-flex justify-content-end\">\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"cancel()\">{{ cancelButtonText }}</button>\n  <button type=\"button\" class=\"btn btn-primary ms-2\" (click)=\"confirm()\" appAutofocus>{{ confirmButtonText }}</button>\n</div>\n", styles: ["@charset \"UTF-8\";.modal-header{border-bottom:none}.modal-footer{border-top:none;padding-top:0;padding-bottom:15px;display:flex;justify-content:flex-end}.modal-title{font-family:var(--font-family);color:#151920;font-size:19px}.modal-body{text-align:left}.modal-body p{color:#15192080;font-family:var(--font-family);font-size:14px}.btn-primary{font-family:var(--font-family);background-color:var(--primary-color);border:1px solid var(--primary-color);border-radius:8px;width:130px;height:42px;color:var(--text-color);transition:opacity .3s,transform .1s}.btn-primary:hover{opacity:.8}.btn-primary:active{transform:scale(.98);background-color:var(--primary-color);border:1px solid var(--primary-color)}.btn-secondary{font-family:var(--font-family);background-color:transparent;border-radius:8px;width:96px;height:42px;border:1px solid rgba(21,25,32,.5019607843);color:#15192080;transition:opacity .3s,transform .1s;margin-right:8px}.btn-secondary:hover{opacity:.8}.btn-secondary:active{transform:scale(.98)}.ms-2{margin-left:8px}\n"], dependencies: [{ kind: "directive", type: AutofocusDirective, selector: "[appAutofocus]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConfirmationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-confirmation', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"modal-header\">\n  <h5 class=\"modal-title\" id=\"confirmationModalLabel\">{{ title }}</h5>\n</div>\n<div class=\"modal-body\">\n  <p>{{ message }}</p>\n</div>\n<div class=\"modal-footer d-flex justify-content-end\">\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"cancel()\">{{ cancelButtonText }}</button>\n  <button type=\"button\" class=\"btn btn-primary ms-2\" (click)=\"confirm()\" appAutofocus>{{ confirmButtonText }}</button>\n</div>\n", styles: ["@charset \"UTF-8\";.modal-header{border-bottom:none}.modal-footer{border-top:none;padding-top:0;padding-bottom:15px;display:flex;justify-content:flex-end}.modal-title{font-family:var(--font-family);color:#151920;font-size:19px}.modal-body{text-align:left}.modal-body p{color:#15192080;font-family:var(--font-family);font-size:14px}.btn-primary{font-family:var(--font-family);background-color:var(--primary-color);border:1px solid var(--primary-color);border-radius:8px;width:130px;height:42px;color:var(--text-color);transition:opacity .3s,transform .1s}.btn-primary:hover{opacity:.8}.btn-primary:active{transform:scale(.98);background-color:var(--primary-color);border:1px solid var(--primary-color)}.btn-secondary{font-family:var(--font-family);background-color:transparent;border-radius:8px;width:96px;height:42px;border:1px solid rgba(21,25,32,.5019607843);color:#15192080;transition:opacity .3s,transform .1s;margin-right:8px}.btn-secondary:hover{opacity:.8}.btn-secondary:active{transform:scale(.98)}.ms-2{margin-left:8px}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$1.NgbActiveModal }]; }, propDecorators: { title: [{
                type: Input
            }], message: [{
                type: Input
            }], confirmButtonText: [{
                type: Input
            }], cancelButtonText: [{
                type: Input
            }] } });

class CsvImporterComponent {
    constructor() {
        this.config = {
            acceptedFileTypes: [".xlsx", ".xls", ".csv"],
            detectHeaders: true,
            delimiter: ";",
            onImport: () => { },
        };
    }
    handleFileInput(event) {
        const file = event.target.files[0];
        if (file) {
            const reader = new FileReader();
            // Detecta se o arquivo é CSV
            if (file.name.endsWith(".csv")) {
                reader.onload = (e) => {
                    const csvData = e.target.result;
                    const delimiter = this.config.delimiter ?? ";"; // Usa delimitador configurado ou padrão
                    const jsonData = this.parseCSV(csvData, delimiter);
                    this.processData(jsonData);
                };
                reader.readAsText(file);
            }
            else {
                // Processa arquivos Excel (XLSX/XLS)
                reader.onload = (e) => {
                    const data = new Uint8Array(e.target.result);
                    const workbook = XLSX.read(data, { type: "array" });
                    const sheetName = workbook.SheetNames[0];
                    const worksheet = workbook.Sheets[sheetName];
                    const jsonData = XLSX.utils.sheet_to_json(worksheet, {
                        header: 1,
                        defval: "",
                    });
                    this.processData(jsonData);
                };
                reader.readAsArrayBuffer(file);
            }
        }
    }
    parseCSV(csvData, delimiter = ";") {
        return csvData
            .split("\n")
            .map((row) => row.split(delimiter).map((cell) => cell.trim()));
    }
    processData(jsonData) {
        const headers = this.getHeaders(jsonData);
        const dataRows = jsonData.slice(headers ? 1 : 0);
        const formattedData = this.formatData(dataRows, headers);
        this.config.onImport(formattedData);
    }
    getHeaders(data) {
        if (this.config.customHeaders) {
            return this.config.customHeaders;
        }
        if (this.config.detectHeaders && data.length > 0) {
            return data[0].map((header, index) => this.normalizeHeader(header || `col_${index}`));
        }
        return null; // Nenhum cabeçalho detectado
    }
    formatData(dataRows, headers) {
        if (!headers) {
            return dataRows; // Retorna dados brutos se não houver cabeçalhos
        }
        return dataRows.map((row) => {
            const record = {};
            headers.forEach((header, index) => {
                record[header] = row[index] ?? "";
            });
            return record;
        });
    }
    normalizeHeader(header) {
        return String(header)
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "")
            .replace(/\s+/g, "_")
            .toLowerCase();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CsvImporterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CsvImporterComponent, selector: "argenta-csv-importer", inputs: { config: "config" }, ngImport: i0, template: "<div class=\"excel-importer\">\n  <input\n    type=\"file\"\n    (change)=\"handleFileInput($event)\"\n    [accept]=\"config.acceptedFileTypes?.join(',')\"\n    style=\"display: none\"\n    #fileInput\n  />\n  <button (click)=\"fileInput.click()\">Importar Arquivo</button>\n</div>\n", styles: [".excel-importer button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer}.excel-importer button:hover{background-color:var(--secondary-color)}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CsvImporterComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-csv-importer", template: "<div class=\"excel-importer\">\n  <input\n    type=\"file\"\n    (change)=\"handleFileInput($event)\"\n    [accept]=\"config.acceptedFileTypes?.join(',')\"\n    style=\"display: none\"\n    #fileInput\n  />\n  <button (click)=\"fileInput.click()\">Importar Arquivo</button>\n</div>\n", styles: [".excel-importer button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer}.excel-importer button:hover{background-color:var(--secondary-color)}\n"] }]
        }], propDecorators: { config: [{
                type: Input
            }] } });

class CustomPaginationComponent {
    constructor() {
        this.totalItems = 0;
        this.itemsPerPage = 10;
        this.currentPage = 1;
        this.showPageInfo = true; // Mostrar ou esconder a informação da página
        this.pageChange = new EventEmitter();
        this.maxSize = 5; // Número máximo de botões de página visíveis
        this.destroy$ = new Subject();
    }
    get totalPages() {
        return Math.ceil(this.totalItems / this.itemsPerPage);
    }
    changePage(page) {
        if (page >= 1 && page <= this.totalPages) {
            this.currentPage = page;
            this.pageChange.emit(this.currentPage);
        }
    }
    get pages() {
        const pages = [];
        const half = Math.floor(this.maxSize / 2);
        let start = Math.max(this.currentPage - half, 1);
        let end = start + this.maxSize - 1;
        if (end > this.totalPages) {
            end = this.totalPages;
            start = Math.max(end - this.maxSize + 1, 1);
        }
        for (let i = start; i <= end; i++) {
            pages.push(i);
        }
        return pages;
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomPaginationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomPaginationComponent, selector: "custom-pagination", inputs: { totalItems: "totalItems", itemsPerPage: "itemsPerPage", currentPage: "currentPage", showPageInfo: "showPageInfo" }, outputs: { pageChange: "pageChange" }, ngImport: i0, template: "<nav *ngIf=\"totalPages > 0\">\n  <ul class=\"pagination\">\n    <li class=\"page-item\" [class.disabled]=\"currentPage === 1\">\n      <a class=\"page-link\" (click)=\"changePage(1)\">&laquo;&laquo;</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === 1\">\n      <a class=\"page-link\" (click)=\"changePage(currentPage - 1)\">&laquo;</a>\n    </li>\n    <li class=\"page-item\" *ngFor=\"let page of pages\" [class.active]=\"page === currentPage\">\n      <a class=\"page-link\" (click)=\"changePage(page)\">{{ page }}</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === totalPages\">\n      <a class=\"page-link\" (click)=\"changePage(currentPage + 1)\">&raquo;</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === totalPages\">\n      <a class=\"page-link\" (click)=\"changePage(totalPages)\">&raquo;&raquo;</a>\n    </li>\n  </ul>\n</nav>\n", styles: ["@charset \"UTF-8\";.pagination{display:flex;list-style:none;padding:0;margin:1rem 0;justify-content:center;align-items:center}.page-item{margin:0 .25rem}.page-item.disabled .page-link{cursor:not-allowed;opacity:.5}.page-item.active .page-link{background-color:var(--primary-color);color:var(--text-color)}.page-item .page-link{padding:.5rem .75rem;border:1px solid #dee2e6;border-radius:.25rem;text-decoration:none;color:var(--primary-color);cursor:pointer;transition:background-color .2s}.page-item .page-link:hover{background-color:#e5e5e5;color:var(--primary-color)}.page-info{margin-left:1rem;font-size:1rem;color:var(--primary-color);font-weight:700}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomPaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'custom-pagination', template: "<nav *ngIf=\"totalPages > 0\">\n  <ul class=\"pagination\">\n    <li class=\"page-item\" [class.disabled]=\"currentPage === 1\">\n      <a class=\"page-link\" (click)=\"changePage(1)\">&laquo;&laquo;</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === 1\">\n      <a class=\"page-link\" (click)=\"changePage(currentPage - 1)\">&laquo;</a>\n    </li>\n    <li class=\"page-item\" *ngFor=\"let page of pages\" [class.active]=\"page === currentPage\">\n      <a class=\"page-link\" (click)=\"changePage(page)\">{{ page }}</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === totalPages\">\n      <a class=\"page-link\" (click)=\"changePage(currentPage + 1)\">&raquo;</a>\n    </li>\n    <li class=\"page-item\" [class.disabled]=\"currentPage === totalPages\">\n      <a class=\"page-link\" (click)=\"changePage(totalPages)\">&raquo;&raquo;</a>\n    </li>\n  </ul>\n</nav>\n", styles: ["@charset \"UTF-8\";.pagination{display:flex;list-style:none;padding:0;margin:1rem 0;justify-content:center;align-items:center}.page-item{margin:0 .25rem}.page-item.disabled .page-link{cursor:not-allowed;opacity:.5}.page-item.active .page-link{background-color:var(--primary-color);color:var(--text-color)}.page-item .page-link{padding:.5rem .75rem;border:1px solid #dee2e6;border-radius:.25rem;text-decoration:none;color:var(--primary-color);cursor:pointer;transition:background-color .2s}.page-item .page-link:hover{background-color:#e5e5e5;color:var(--primary-color)}.page-info{margin-left:1rem;font-size:1rem;color:var(--primary-color);font-weight:700}\n"] }]
        }], propDecorators: { totalItems: [{
                type: Input
            }], itemsPerPage: [{
                type: Input
            }], currentPage: [{
                type: Input
            }], showPageInfo: [{
                type: Input
            }], pageChange: [{
                type: Output
            }] } });

class CustomSwitchComponent {
    constructor(authService) {
        this.authService = authService;
        this.checked = false;
        this.label = '';
        this.permissions = [];
        this.switchChange = new EventEmitter();
    }
    toggleSwitch() {
        this.checked = !this.checked;
        this.switchChange.emit(this.checked);
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomSwitchComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomSwitchComponent, selector: "argenta-custom-switch", inputs: { checked: "checked", label: "label", permissions: "permissions" }, outputs: { switchChange: "switchChange" }, ngImport: i0, template: "<ng-container *ngIf=\"hasPermission()\">\n  <div class=\"form-check form-switch\">\n    <input \n      class=\"form-check-input\" \n      type=\"checkbox\" \n      [checked]=\"checked\" \n      (change)=\"toggleSwitch()\" \n      id=\"flexSwitchCheckDefault\" \n    />\n    <label class=\"form-check-label\" for=\"flexSwitchCheckDefault\">\n      {{ label }}\n    </label>\n  </div>\n</ng-container>\n", styles: ["@charset \"UTF-8\";.form-check{display:flex;align-items:center}.form-check-input{width:60px;height:34px;margin-right:10px;cursor:pointer;position:relative;appearance:none;background-color:#e5e5e5;border:2px solid var(--primary-color);border-radius:34px;outline:none;transition:background-color .3s,border-color .3s}.form-check-input:focus{outline:none;box-shadow:none}.form-check-input:checked{background-color:var(--primary-color);border-color:var(--primary-color)}.form-check-input:before{content:\"\";position:absolute;width:26px;height:26px;background-color:var(--primary-color);border-radius:50%;top:3px;left:3px;transition:transform .3s,background-color .3s}.form-check-input:checked:before{transform:translate(26px);background-color:#fff}.form-check-label{color:var(--primary-color);font-family:var(--font-family);font-size:16px;font-weight:600;height:24px;line-height:24px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomSwitchComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-custom-switch', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *ngIf=\"hasPermission()\">\n  <div class=\"form-check form-switch\">\n    <input \n      class=\"form-check-input\" \n      type=\"checkbox\" \n      [checked]=\"checked\" \n      (change)=\"toggleSwitch()\" \n      id=\"flexSwitchCheckDefault\" \n    />\n    <label class=\"form-check-label\" for=\"flexSwitchCheckDefault\">\n      {{ label }}\n    </label>\n  </div>\n</ng-container>\n", styles: ["@charset \"UTF-8\";.form-check{display:flex;align-items:center}.form-check-input{width:60px;height:34px;margin-right:10px;cursor:pointer;position:relative;appearance:none;background-color:#e5e5e5;border:2px solid var(--primary-color);border-radius:34px;outline:none;transition:background-color .3s,border-color .3s}.form-check-input:focus{outline:none;box-shadow:none}.form-check-input:checked{background-color:var(--primary-color);border-color:var(--primary-color)}.form-check-input:before{content:\"\";position:absolute;width:26px;height:26px;background-color:var(--primary-color);border-radius:50%;top:3px;left:3px;transition:transform .3s,background-color .3s}.form-check-input:checked:before{transform:translate(26px);background-color:#fff}.form-check-label{color:var(--primary-color);font-family:var(--font-family);font-size:16px;font-weight:600;height:24px;line-height:24px}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { checked: [{
                type: Input
            }], label: [{
                type: Input
            }], permissions: [{
                type: Input
            }], switchChange: [{
                type: Output
            }] } });

class DataExcelExporterComponent {
    constructor() {
        this.data = [];
    }
    async exportToExcel() {
        let sheetConfig = this.config;
        if (!this.config || (!this.data.length && !sheetConfig.multipleSheets)) {
            console.warn("Nenhuma configuração ou dados fornecidos.");
            return;
        }
        const workbook = XLSX.utils.book_new();
        // Verifica se múltiplas planilhas estão configuradas
        if (sheetConfig.multipleSheets) {
            sheetConfig.multipleSheets.forEach((sheetConfig) => {
                const worksheet = XLSX.utils.aoa_to_sheet([]);
                // Adiciona o título, se houver
                let startRow = 0;
                if (sheetConfig.title) {
                    XLSX.utils.sheet_add_aoa(worksheet, [[sheetConfig.title]], {
                        origin: "A1",
                    });
                    // Define larguras personalizadas do título
                    if (sheetConfig.titleWidths) {
                        worksheet["!cols"] = sheetConfig.titleWidths.map((width) => ({
                            wch: width,
                        }));
                    }
                    // Mescla o título
                    if (sheetConfig.tableHeaders) {
                        worksheet["!merges"] = worksheet["!merges"] || [];
                        worksheet["!merges"].push({
                            s: { r: 0, c: 0 },
                            e: { r: 0, c: sheetConfig.tableHeaders.length - 1 },
                        });
                    }
                    startRow = 1;
                }
                // Adiciona cabeçalhos
                if (sheetConfig.tableHeaders) {
                    XLSX.utils.sheet_add_aoa(worksheet, [sheetConfig.tableHeaders], {
                        origin: `A${startRow + 1}`,
                    });
                }
                // Adiciona dados
                if (sheetConfig.data) {
                    XLSX.utils.sheet_add_json(worksheet, sheetConfig.data, {
                        origin: `A${startRow + 2}`,
                        skipHeader: true,
                    });
                }
                // Define larguras das colunas
                if (sheetConfig.columnWidths) {
                    worksheet["!cols"] = sheetConfig.columnWidths.map((width) => ({
                        wch: width,
                    }));
                }
                // Adiciona a planilha ao workbook
                XLSX.utils.book_append_sheet(workbook, worksheet, sheetConfig.sheetName);
            });
        }
        else {
            // Caso não haja múltiplas planilhas, processa a planilha única
            const worksheet = XLSX.utils.aoa_to_sheet([]);
            // Adiciona título, se houver
            let startRow = 0;
            if (sheetConfig.title) {
                XLSX.utils.sheet_add_aoa(worksheet, [[sheetConfig.title]], {
                    origin: "A1",
                });
                // Define larguras do título
                if (sheetConfig.titleWidths) {
                    worksheet["!cols"] = sheetConfig.titleWidths.map((width) => ({
                        wch: width,
                    }));
                }
                // Mescla o título
                if (sheetConfig.tableHeaders) {
                    worksheet["!merges"] = worksheet["!merges"] || [];
                    worksheet["!merges"].push({
                        s: { r: 0, c: 0 },
                        e: { r: 0, c: sheetConfig.tableHeaders.length - 1 },
                    });
                }
                startRow = 1;
            }
            // Adiciona cabeçalhos
            if (sheetConfig.tableHeaders) {
                XLSX.utils.sheet_add_aoa(worksheet, [sheetConfig.tableHeaders], {
                    origin: `A${startRow + 1}`,
                });
            }
            // Adiciona dados
            XLSX.utils.sheet_add_json(worksheet, this.data, {
                origin: `A${startRow + 2}`,
                skipHeader: true,
            });
            // Define larguras das colunas
            if (sheetConfig.columnWidths) {
                worksheet["!cols"] = sheetConfig.columnWidths.map((width) => ({
                    wch: width,
                }));
            }
            // Adiciona a planilha ao workbook
            XLSX.utils.book_append_sheet(workbook, worksheet, sheetConfig.sheetName);
        }
        // Salva o arquivo Excel
        XLSX.writeFile(workbook, sheetConfig.fileName);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataExcelExporterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DataExcelExporterComponent, selector: "argenta-excel-exporter", inputs: { config: "config", data: "data" }, ngImport: i0, template: `
    <button (click)="exportToExcel()">{{ config.buttonLabel ?? '' }}</button>
  `, isInline: true, styles: ["button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer}button:hover{background-color:var(--secondary-color)}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataExcelExporterComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-excel-exporter", template: `
    <button (click)="exportToExcel()">{{ config.buttonLabel ?? '' }}</button>
  `, styles: ["button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer}button:hover{background-color:var(--secondary-color)}\n"] }]
        }], propDecorators: { config: [{
                type: Input
            }], data: [{
                type: Input
            }] } });

class DataExcelImporterComponent {
    constructor() {
        this.excelData = new EventEmitter(); // Evento para enviar dados processados
        // Configurações padrão
        this.config = {
            acceptedFileTypes: [".xlsx", ".xls", ".csv"],
            onImport: (data) => this.defaultImportHandler(data),
            excludeRows: [],
            excludeColumns: [],
            hasHeader: true,
            headerRowIndex: 1,
            titleRowIndex: 1,
        };
        // Controle do modal e inputs de configuração
        this.userConfig = { ...this.config };
        this.excludeRowsInput = ""; // Para capturar linhas a excluir
        this.excludeColumnsInput = ""; // Para capturar colunas a excluir
        this.showConfigModal = false;
        this.buttonLabel = "Importar Dados";
    }
    // Abre o modal de configurações
    openModal() {
        this.showConfigModal = true;
    }
    // Fecha o modal de configurações
    closeModal() {
        this.showConfigModal = false;
    }
    // Salva as configurações ajustadas no modal
    saveConfig() {
        this.config = {
            ...this.userConfig,
            titleRowIndex: (this.userConfig.titleRowIndex ?? 1) - 1,
            headerRowIndex: (this.userConfig.headerRowIndex ?? 2) - 1,
            excludeRows: this.excludeRowsInput
                .split(",")
                .map((row) => parseInt(row.trim(), 10) - 1),
            excludeColumns: this.excludeColumnsInput
                .split(",")
                .map((col) => this.columnLetterToIndex(col.trim())), // Converte letras para índices
        };
        this.closeModal();
    }
    // Valida que as linhas informadas sejam pelo menos 1
    validateRowInput(field) {
        if (field === "headerRow" && this.userConfig.headerRowIndex < 1) {
            this.userConfig.headerRowIndex = 1;
        }
        if (field === "titleRow" && this.userConfig.titleRowIndex < 1) {
            this.userConfig.titleRowIndex = 1;
        }
    }
    // Processa o arquivo selecionado
    handleFileInput(event) {
        const file = event.target.files[0];
        if (file) {
            const fileType = file.name.split(".").pop()?.toLowerCase();
            if (fileType === "csv") {
                this.processCSVFile(file); // Processa o CSV de forma isolada
            }
            else {
                this.processExcelFile(file); // Mantém o fluxo atual para Excel
            }
            event.target.value = ""; // Reseta o input para permitir reimportação
        }
    }
    processExcelFile(file) {
        const reader = new FileReader();
        reader.onload = (e) => {
            const data = new Uint8Array(e.target.result);
            const workbook = XLSX.read(data, { type: "array" });
            const sheetName = workbook.SheetNames[0];
            const worksheet = workbook.Sheets[sheetName];
            const titleRowIndex = this.config.titleRowIndex ?? 0;
            const headerRowIndex = this.config.headerRowIndex ?? titleRowIndex + 1;
            if (worksheet["!ref"]) {
                worksheet["!ref"] = this.adjustRange(worksheet["!ref"], headerRowIndex + 1);
            }
            else {
                console.error("Intervalo da planilha ('!ref') não encontrado.");
                return;
            }
            const jsonData = XLSX.utils.sheet_to_json(worksheet, {
                header: 1,
                defval: "",
                blankrows: false,
            });
            this.processData(jsonData);
        };
        reader.readAsArrayBuffer(file); // Lê o Excel como array buffer
    }
    processCSVFile(file) {
        if (this.userConfig.hasHeader) {
            if (this.config?.headerRowIndex !== undefined) {
                this.config.headerRowIndex =
                    this.config.headerRowIndex === 0 ? 1 : this.config.headerRowIndex + 1;
            }
            const sum = (this.config.excludeRows ?? []).reduce((acc, value) => acc + value, 0) +
                1;
            this.config.excludeRows = [sum];
        }
        const reader = new FileReader();
        reader.onload = (e) => {
            const csvData = e.target.result;
            // Converte CSV em JSON usando XLSX
            const workbook = XLSX.read(csvData, { type: "string" });
            const sheetName = workbook.SheetNames[0];
            const worksheet = workbook.Sheets[sheetName];
            const jsonData = XLSX.utils.sheet_to_json(worksheet, {
                header: 1,
                defval: "",
                blankrows: false,
            });
            this.processData(jsonData);
        };
        reader.readAsText(file); // Lê o CSV como texto
    }
    processData(jsonData) {
        const titleRowIndex = this.config.titleRowIndex ?? 0;
        const headerRowIndex = this.config.headerRowIndex ?? titleRowIndex + 1;
        const headers = jsonData[0];
        if (!headers) {
            console.error("Cabeçalhos não encontrados. Verifique o headerRowIndex.");
            return;
        }
        const normalizedHeaders = headers.map((header, index) => this.normalizeHeader(header || `col_${index}`));
        const dataRows = jsonData.slice(1); // Remove a linha de cabeçalho
        // Filtra as linhas baseando-se no índice informado pelo usuário (1-based)
        const filteredRows = dataRows.filter((_, index) => !this.config.excludeRows?.includes(index + headerRowIndex + 1));
        const formattedData = filteredRows.map((row) => {
            const record = {};
            normalizedHeaders.forEach((header, index) => {
                record[header] = row[index] ?? "";
            });
            return record;
        });
        const finalData = this.filterColumns(formattedData);
        this.config.onImport(finalData); // Chama o callback com os dados processados
        this.excelData.emit(finalData); // Emite os dados processados para o cliente
    }
    // Ajusta o intervalo da planilha com base na linha do cabeçalho
    adjustRange(range, startRow) {
        const [start, end] = range.split(":");
        const startCol = start.replace(/[0-9]/g, "");
        const endCol = end.replace(/[0-9]/g, "");
        const endRow = end.replace(/[A-Za-z]/g, "");
        return `${startCol}${startRow}:${endCol}${endRow}`;
    }
    // Normaliza os cabeçalhos removendo acentos e espaços
    normalizeHeader(header) {
        return header
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "")
            .replace(/\s+/g, "_")
            .toLowerCase();
    }
    // Filtra as colunas configuradas para exclusão
    filterColumns(data) {
        const { excludeColumns } = this.config;
        return data.map((row) => {
            const filteredRow = {};
            Object.keys(row).forEach((key, index) => {
                if (!excludeColumns?.includes(index)) {
                    filteredRow[key] = row[key];
                }
            });
            return filteredRow;
        });
    }
    // Converte letra da coluna para índice (A -> 0, B -> 1, etc.)
    columnLetterToIndex(letter) {
        let index = 0;
        for (let i = 0; i < letter.length; i++) {
            index = index * 26 + (letter.charCodeAt(i) - "A".charCodeAt(0) + 1);
        }
        return index - 1;
    }
    // Callback padrão para manipular dados importados
    defaultImportHandler(data) { }
    transformToUppercase() {
        this.excludeColumnsInput = this.excludeColumnsInput.toUpperCase();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataExcelImporterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DataExcelImporterComponent, selector: "argenta-excel-importer", outputs: { excelData: "excelData" }, ngImport: i0, template: "<div class=\"excel-importer\">\n  <input\n    type=\"file\"\n    (change)=\"handleFileInput($event)\"\n    [accept]=\"config.acceptedFileTypes?.join(',')\"\n    style=\"display: none\"\n    #fileInput\n  />\n  <button (click)=\"fileInput.click()\">{{ buttonLabel }}</button>\n  <lucide-icon\n    name=\"settings\"\n    [size]=\"24\"\n    [strokeWidth]=\"2.25\"\n    class=\"settings-icon\"\n    (click)=\"openModal()\"\n  ></lucide-icon>\n</div>\n\n<div class=\"modal-container\" *ngIf=\"showConfigModal\">\n  <div class=\"modal-content\">\n    <h4 class=\"titulo\">Configura\u00E7\u00E3o de Importa\u00E7\u00E3o</h4>\n    <form (ngSubmit)=\"saveConfig()\">\n      <div class=\"form-group\">\n        <label for=\"acceptedFileTypes\">Tipos de Arquivo Permitidos</label>\n        <input\n          id=\"acceptedFileTypes\"\n          type=\"text\"\n          [(ngModel)]=\"userConfig.acceptedFileTypes\"\n          name=\"acceptedFileTypes\"\n          placeholder=\".xlsx, .xls\"\n        />\n      </div>\n      <div class=\"form-group\" style=\"display: none\">\n        <label for=\"titleRow\">Linha do T\u00EDtulo (se aplic\u00E1vel)</label>\n        <input\n          id=\"titleRow\"\n          type=\"number\"\n          [(ngModel)]=\"userConfig.titleRowIndex\"\n          name=\"titleRow\"\n          placeholder=\"Ex: 1\"\n          (change)=\"validateRowInput('titleRow')\"\n        />\n      </div>\n      <div class=\"form-group checkbox-group\">\n        <div class=\"row\">\n          <div class=\"col-md-8\">\n            <label for=\"hasHeader\">A planilha cont\u00E9m cabe\u00E7alho?</label>\n          </div>\n          <div class=\"col-md-4\">\n            <input\n              id=\"hasHeader\"\n              class=\"input-checkbox\"\n              type=\"checkbox\"\n              [(ngModel)]=\"userConfig.hasHeader\"\n              name=\"hasHeader\"\n            />\n          </div>\n        </div>\n      </div>\n\n      <!-- Exibe a linha do cabe\u00E7alho apenas se o checkbox estiver marcado -->\n      <div class=\"form-group\" *ngIf=\"userConfig.hasHeader\">\n        <label for=\"headerRow\">Linha do Cabe\u00E7alho</label>\n        <input\n          id=\"headerRow\"\n          type=\"number\"\n          [(ngModel)]=\"userConfig.headerRowIndex\"\n          name=\"headerRow\"\n          placeholder=\"Ex: 2\"\n          (change)=\"validateRowInput('headerRow')\"\n        />\n      </div>\n\n      <div class=\"form-group\">\n        <label for=\"excludeRows\">Linhas a Excluir</label>\n        <input\n          id=\"excludeRows\"\n          type=\"text\"\n          [(ngModel)]=\"excludeRowsInput\"\n          name=\"excludeRows\"\n          placeholder=\"Ex: 1, 3\"\n        />\n      </div>\n      <div class=\"form-group\">\n        <label for=\"excludeColumns\">Colunas a Excluir</label>\n        <input\n          id=\"excludeColumns\"\n          type=\"text\"\n          [(ngModel)]=\"excludeColumnsInput\"\n          name=\"excludeColumns\"\n          placeholder=\"Ex: A, C\"\n          (input)=\"transformToUppercase()\"\n        />\n      </div>\n      <button type=\"submit\">Salvar Configura\u00E7\u00F5es</button>\n      <button type=\"button\" (click)=\"closeModal()\">Fechar</button>\n    </form>\n  </div>\n</div>\n", styles: [".excel-importer{display:flex;align-items:center;gap:10px}.excel-importer button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer;display:flex;align-items:center}.excel-importer button:hover{background-color:var(--secondary-color)}.excel-importer .settings-icon{color:var(--text-color);background-color:var(--primary-color);border-radius:50%;padding:5px;cursor:pointer;transition:background-color .3s,color .3s}.excel-importer .settings-icon:hover{background-color:var(--secondary-color);color:#fff}.modal-container{position:fixed;top:0;left:0;width:100%;height:100%;background-color:#00000080;display:flex;justify-content:center;align-items:center}.modal-content{background:#fff;padding:20px;border-radius:5px;width:400px}.modal-content h2{margin-bottom:20px}.modal-content .form-group{margin-bottom:15px}.modal-content .form-group label{display:block;margin-bottom:5px}.modal-content .form-group input{width:100%;padding:8px;border:1px solid #ccc;border-radius:4px}.modal-content button{margin-right:10px;padding:8px 15px;border:none;cursor:pointer}.modal-content button:first-of-type{background-color:var(--primary-color);color:#fff}.modal-content button:last-of-type{background-color:#ccc}input#excludeColumns{text-transform:uppercase}.small-label{font-size:.7rem;color:#555}.input-checkbox{margin-left:-5rem}.titulo{margin-bottom:2rem}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataExcelImporterComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-excel-importer", template: "<div class=\"excel-importer\">\n  <input\n    type=\"file\"\n    (change)=\"handleFileInput($event)\"\n    [accept]=\"config.acceptedFileTypes?.join(',')\"\n    style=\"display: none\"\n    #fileInput\n  />\n  <button (click)=\"fileInput.click()\">{{ buttonLabel }}</button>\n  <lucide-icon\n    name=\"settings\"\n    [size]=\"24\"\n    [strokeWidth]=\"2.25\"\n    class=\"settings-icon\"\n    (click)=\"openModal()\"\n  ></lucide-icon>\n</div>\n\n<div class=\"modal-container\" *ngIf=\"showConfigModal\">\n  <div class=\"modal-content\">\n    <h4 class=\"titulo\">Configura\u00E7\u00E3o de Importa\u00E7\u00E3o</h4>\n    <form (ngSubmit)=\"saveConfig()\">\n      <div class=\"form-group\">\n        <label for=\"acceptedFileTypes\">Tipos de Arquivo Permitidos</label>\n        <input\n          id=\"acceptedFileTypes\"\n          type=\"text\"\n          [(ngModel)]=\"userConfig.acceptedFileTypes\"\n          name=\"acceptedFileTypes\"\n          placeholder=\".xlsx, .xls\"\n        />\n      </div>\n      <div class=\"form-group\" style=\"display: none\">\n        <label for=\"titleRow\">Linha do T\u00EDtulo (se aplic\u00E1vel)</label>\n        <input\n          id=\"titleRow\"\n          type=\"number\"\n          [(ngModel)]=\"userConfig.titleRowIndex\"\n          name=\"titleRow\"\n          placeholder=\"Ex: 1\"\n          (change)=\"validateRowInput('titleRow')\"\n        />\n      </div>\n      <div class=\"form-group checkbox-group\">\n        <div class=\"row\">\n          <div class=\"col-md-8\">\n            <label for=\"hasHeader\">A planilha cont\u00E9m cabe\u00E7alho?</label>\n          </div>\n          <div class=\"col-md-4\">\n            <input\n              id=\"hasHeader\"\n              class=\"input-checkbox\"\n              type=\"checkbox\"\n              [(ngModel)]=\"userConfig.hasHeader\"\n              name=\"hasHeader\"\n            />\n          </div>\n        </div>\n      </div>\n\n      <!-- Exibe a linha do cabe\u00E7alho apenas se o checkbox estiver marcado -->\n      <div class=\"form-group\" *ngIf=\"userConfig.hasHeader\">\n        <label for=\"headerRow\">Linha do Cabe\u00E7alho</label>\n        <input\n          id=\"headerRow\"\n          type=\"number\"\n          [(ngModel)]=\"userConfig.headerRowIndex\"\n          name=\"headerRow\"\n          placeholder=\"Ex: 2\"\n          (change)=\"validateRowInput('headerRow')\"\n        />\n      </div>\n\n      <div class=\"form-group\">\n        <label for=\"excludeRows\">Linhas a Excluir</label>\n        <input\n          id=\"excludeRows\"\n          type=\"text\"\n          [(ngModel)]=\"excludeRowsInput\"\n          name=\"excludeRows\"\n          placeholder=\"Ex: 1, 3\"\n        />\n      </div>\n      <div class=\"form-group\">\n        <label for=\"excludeColumns\">Colunas a Excluir</label>\n        <input\n          id=\"excludeColumns\"\n          type=\"text\"\n          [(ngModel)]=\"excludeColumnsInput\"\n          name=\"excludeColumns\"\n          placeholder=\"Ex: A, C\"\n          (input)=\"transformToUppercase()\"\n        />\n      </div>\n      <button type=\"submit\">Salvar Configura\u00E7\u00F5es</button>\n      <button type=\"button\" (click)=\"closeModal()\">Fechar</button>\n    </form>\n  </div>\n</div>\n", styles: [".excel-importer{display:flex;align-items:center;gap:10px}.excel-importer button{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);padding:10px 20px;border:none;cursor:pointer;display:flex;align-items:center}.excel-importer button:hover{background-color:var(--secondary-color)}.excel-importer .settings-icon{color:var(--text-color);background-color:var(--primary-color);border-radius:50%;padding:5px;cursor:pointer;transition:background-color .3s,color .3s}.excel-importer .settings-icon:hover{background-color:var(--secondary-color);color:#fff}.modal-container{position:fixed;top:0;left:0;width:100%;height:100%;background-color:#00000080;display:flex;justify-content:center;align-items:center}.modal-content{background:#fff;padding:20px;border-radius:5px;width:400px}.modal-content h2{margin-bottom:20px}.modal-content .form-group{margin-bottom:15px}.modal-content .form-group label{display:block;margin-bottom:5px}.modal-content .form-group input{width:100%;padding:8px;border:1px solid #ccc;border-radius:4px}.modal-content button{margin-right:10px;padding:8px 15px;border:none;cursor:pointer}.modal-content button:first-of-type{background-color:var(--primary-color);color:#fff}.modal-content button:last-of-type{background-color:#ccc}input#excludeColumns{text-transform:uppercase}.small-label{font-size:.7rem;color:#555}.input-checkbox{margin-left:-5rem}.titulo{margin-bottom:2rem}\n"] }]
        }], propDecorators: { excelData: [{
                type: Output
            }] } });

class DragDropListComponent {
    constructor() {
        this.nonSelectedList = [];
        this.nonSelectedButtonClick = new EventEmitter();
        this.nonSelectedInputChanged = new EventEmitter();
        this.selectedList = [];
        this.selectedButtonClick = new EventEmitter();
        this.selectedInputChanged = new EventEmitter();
        this.nonSelectedListInputSubject = new Subject();
        this.selectedListInputSubject = new Subject();
        this.ButtonClasses = ButtonClasses; // Adicione a enumeração ao componente
        this.draggedItem = null;
        this.nonSelectedListInputSubject.pipe(debounceTime(2000)).subscribe((value) => {
            this.nonSelectedInputChanged.emit(value);
        });
        this.selectedListInputSubject.pipe(debounceTime(2000)).subscribe((value) => {
            this.selectedInputChanged.emit(value);
        });
    }
    onDragStart(item) {
        this.draggedItem = item;
    }
    onDragOver(event) {
        event.preventDefault();
    }
    onDrop(list, event) {
        event.preventDefault();
        if (this.draggedItem) {
            const index = list.indexOf(this.draggedItem);
            if (index === -1) {
                this.removeItem(this.draggedItem);
                list.push(this.draggedItem);
            }
            this.draggedItem = null;
        }
    }
    removeItem(item) {
        [this.nonSelectedList, this.selectedList].forEach((list) => {
            const index = list.indexOf(item);
            if (index !== -1) {
                list.splice(index, 1);
            }
        });
    }
    nonSelectedListInputChange(event) {
        this.nonSelectedListInputSubject.next(event.target.value);
    }
    selectedListInputChange(event) {
        this.selectedListInputSubject.next(event.target.value);
    }
    selButtonClick() {
        this.selectedButtonClick.emit();
    }
    nonSelButtonClick() {
        this.nonSelectedButtonClick.emit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DragDropListComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DragDropListComponent, selector: "argenta-drag-drop-list", inputs: { nonSelectedTitle: "nonSelectedTitle", nonSelectedList: "nonSelectedList", nonSelectedButtonLabel: "nonSelectedButtonLabel", selectedTitle: "selectedTitle", selectedList: "selectedList", selectedButtonLabel: "selectedButtonLabel" }, outputs: { nonSelectedButtonClick: "nonSelectedButtonClick", nonSelectedInputChanged: "nonSelectedInputChanged", selectedButtonClick: "selectedButtonClick", selectedInputChanged: "selectedInputChanged" }, ngImport: i0, template: "<!-- Cont\u00EAiner externo para dar a apar\u00EAncia de grupo -->\n<div class=\"group-container\">\n  <div class=\"container\">\n    <!-- Lista 1 com input -->\n    <div\n      class=\"list\"\n      (dragover)=\"onDragOver($event)\"\n      (drop)=\"onDrop(nonSelectedList, $event)\"\n    >\n      <div class=\"row\">\n        <h6 class=\"col-md-8\">{{ nonSelectedTitle }}</h6>\n        <div *ngIf=\"nonSelectedButtonLabel\" class=\"col-md-4 align-end\">\n          <argenta-custom-button\n            label=\"{{ nonSelectedButtonLabel }}\"\n            (onButtonClick)=\"nonSelButtonClick()\"\n            class=\"align-end\"\n            [btnClass]=\"ButtonClasses.Primary\"\n          >\n          </argenta-custom-button>\n        </div>\n      </div>\n      <input\n        type=\"text\"\n        class=\"list-input\"\n        (input)=\"nonSelectedListInputChange($event)\"\n      />\n      <div\n        *ngFor=\"let item of nonSelectedList\"\n        class=\"item-card\"\n        draggable=\"true\"\n        (dragstart)=\"onDragStart(item)\"\n      >\n        {{ item.descricao }}\n      </div>\n    </div>\n\n    <!-- Lista 2 com input -->\n    <div\n      class=\"list\"\n      (dragover)=\"onDragOver($event)\"\n      (drop)=\"onDrop(selectedList, $event)\"\n    >\n      <div class=\"row\">\n        <h6 class=\"col-md-8\">{{ selectedTitle }}</h6>\n        <div *ngIf=\"selectedButtonLabel\" class=\"col-md-4 align-end\">\n          <argenta-custom-button\n            label=\"{{ selectedButtonLabel }}\"\n            (onButtonClick)=\"selButtonClick()\"\n            class=\"align-end\"\n            [btnClass]=\"ButtonClasses.Primary\"\n          >\n          </argenta-custom-button>\n        </div>\n      </div>\n      <input\n        type=\"text\"\n        class=\"list-input\"\n        (input)=\"selectedListInputChange($event)\"\n      />\n      <div\n        *ngFor=\"let item of selectedList\"\n        class=\"item-card\"\n        draggable=\"true\"\n        (dragstart)=\"onDragStart(item)\"\n      >\n        {{ item.descricao }}\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.group-container{display:flex;justify-content:center;padding:20px;background-color:#fff;border-radius:12px;box-shadow:0 4px 8px #0000001a;width:80%;margin:auto}.container{display:flex;gap:20px;width:100%}.list{flex:1;padding:10px;background-color:#f0f0f0;border-radius:8px;display:flex;flex-direction:column;align-items:flex-start;gap:10px}.list-input{width:100%;height:40px;margin-bottom:15px;border-radius:4px;border:1px solid #ccc;outline:none;font-size:1rem;resize:none}.item-card{width:100%;padding:15px;background-color:#fff;border-radius:8px;box-shadow:0 2px 5px #0003;cursor:move;display:flex;align-items:center;justify-content:center;text-align:center;font-family:var(--font-family);font-weight:500;font-size:1.1rem;color:#333}.row{display:flex;justify-content:space-between;align-items:center;width:100%;max-height:50px;height:50px}.align-end{display:flex;justify-content:flex-end}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ButtonComponent, selector: "argenta-custom-button", inputs: ["type", "label", "btnClass", "fontSize", "disabled", "autofocus", "form", "formaction", "formenctype", "formmethod", "formnovalidate", "formtarget", "name", "value", "permissions"], outputs: ["onButtonClick"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DragDropListComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-drag-drop-list", template: "<!-- Cont\u00EAiner externo para dar a apar\u00EAncia de grupo -->\n<div class=\"group-container\">\n  <div class=\"container\">\n    <!-- Lista 1 com input -->\n    <div\n      class=\"list\"\n      (dragover)=\"onDragOver($event)\"\n      (drop)=\"onDrop(nonSelectedList, $event)\"\n    >\n      <div class=\"row\">\n        <h6 class=\"col-md-8\">{{ nonSelectedTitle }}</h6>\n        <div *ngIf=\"nonSelectedButtonLabel\" class=\"col-md-4 align-end\">\n          <argenta-custom-button\n            label=\"{{ nonSelectedButtonLabel }}\"\n            (onButtonClick)=\"nonSelButtonClick()\"\n            class=\"align-end\"\n            [btnClass]=\"ButtonClasses.Primary\"\n          >\n          </argenta-custom-button>\n        </div>\n      </div>\n      <input\n        type=\"text\"\n        class=\"list-input\"\n        (input)=\"nonSelectedListInputChange($event)\"\n      />\n      <div\n        *ngFor=\"let item of nonSelectedList\"\n        class=\"item-card\"\n        draggable=\"true\"\n        (dragstart)=\"onDragStart(item)\"\n      >\n        {{ item.descricao }}\n      </div>\n    </div>\n\n    <!-- Lista 2 com input -->\n    <div\n      class=\"list\"\n      (dragover)=\"onDragOver($event)\"\n      (drop)=\"onDrop(selectedList, $event)\"\n    >\n      <div class=\"row\">\n        <h6 class=\"col-md-8\">{{ selectedTitle }}</h6>\n        <div *ngIf=\"selectedButtonLabel\" class=\"col-md-4 align-end\">\n          <argenta-custom-button\n            label=\"{{ selectedButtonLabel }}\"\n            (onButtonClick)=\"selButtonClick()\"\n            class=\"align-end\"\n            [btnClass]=\"ButtonClasses.Primary\"\n          >\n          </argenta-custom-button>\n        </div>\n      </div>\n      <input\n        type=\"text\"\n        class=\"list-input\"\n        (input)=\"selectedListInputChange($event)\"\n      />\n      <div\n        *ngFor=\"let item of selectedList\"\n        class=\"item-card\"\n        draggable=\"true\"\n        (dragstart)=\"onDragStart(item)\"\n      >\n        {{ item.descricao }}\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.group-container{display:flex;justify-content:center;padding:20px;background-color:#fff;border-radius:12px;box-shadow:0 4px 8px #0000001a;width:80%;margin:auto}.container{display:flex;gap:20px;width:100%}.list{flex:1;padding:10px;background-color:#f0f0f0;border-radius:8px;display:flex;flex-direction:column;align-items:flex-start;gap:10px}.list-input{width:100%;height:40px;margin-bottom:15px;border-radius:4px;border:1px solid #ccc;outline:none;font-size:1rem;resize:none}.item-card{width:100%;padding:15px;background-color:#fff;border-radius:8px;box-shadow:0 2px 5px #0003;cursor:move;display:flex;align-items:center;justify-content:center;text-align:center;font-family:var(--font-family);font-weight:500;font-size:1.1rem;color:#333}.row{display:flex;justify-content:space-between;align-items:center;width:100%;max-height:50px;height:50px}.align-end{display:flex;justify-content:flex-end}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { nonSelectedTitle: [{
                type: Input
            }], nonSelectedList: [{
                type: Input
            }], nonSelectedButtonLabel: [{
                type: Input
            }], nonSelectedButtonClick: [{
                type: Output
            }], nonSelectedInputChanged: [{
                type: Output
            }], selectedTitle: [{
                type: Input
            }], selectedList: [{
                type: Input
            }], selectedButtonLabel: [{
                type: Input
            }], selectedButtonClick: [{
                type: Output
            }], selectedInputChanged: [{
                type: Output
            }] } });

class DynamicModalComponent {
    constructor() {
        this.modalTitle = "Modal Title";
        this.modalSizeClass = "";
        this.modalId = "dynamicModal"; // ID único para cada modal
    }
    openModal() {
        const modalElement = document.getElementById(this.modalId);
        if (modalElement) {
            modalElement.classList.add("show");
            modalElement.setAttribute("aria-hidden", "false");
            modalElement.style.display = "block";
            document.body.classList.add("modal-open");
            // Adiciona o backdrop manualmente se não existir
            if (!document.querySelector(`.modal-backdrop[data-modal-id="${this.modalId}"]`)) {
                const backdrop = document.createElement("div");
                backdrop.className = "modal-backdrop fade show";
                backdrop.setAttribute("data-modal-id", this.modalId);
                document.body.appendChild(backdrop);
            }
        }
    }
    closeModal() {
        const modalElement = document.getElementById(this.modalId);
        if (modalElement) {
            modalElement.classList.remove("show");
            modalElement.setAttribute("aria-hidden", "true");
            modalElement.style.display = "none";
            document.body.classList.remove("modal-open");
            document
                .querySelector(`.modal-backdrop[data-modal-id="${this.modalId}"]`)
                ?.remove();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DynamicModalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DynamicModalComponent, selector: "argenta-dynamic-modal", inputs: { modalTitle: "modalTitle", modalSizeClass: "modalSizeClass", modalId: "modalId" }, ngImport: i0, template: "<div\n  class=\"modal fade\"\n  [id]=\"modalId\"\n  tabindex=\"-1\"\n  [attr.aria-labelledby]=\"modalId + 'Label'\"\n  aria-hidden=\"true\"\n>\n  <div class=\"modal-dialog\" [ngClass]=\"modalSizeClass\">\n    <div class=\"modal-content\">\n      <div class=\"modal-header custom-header\">\n        <h5 class=\"modal-title custom-modal-title\" [id]=\"modalId + 'Label'\">\n          {{ modalTitle }}\n        </h5>\n        <button\n          type=\"button\"\n          class=\"custom-close-button\"\n          (click)=\"closeModal()\"\n          aria-label=\"Close\"\n        >\n          &times;\n        </button>\n      </div>\n      <div class=\"modal-body custom-body\">\n        <ng-content select=\"[modal-body]\"></ng-content>\n      </div>\n      <div class=\"modal-footer custom-footer\">\n        <ng-content select=\"[modal-footer]\"></ng-content>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: [".custom-header{background-color:var(--primary-color)!important;color:var(--text-color)!important;font-size:1.25rem!important;font-family:var(--font-family)!important;padding:1rem;position:relative}.custom-header .custom-close-button{position:absolute;right:1rem;background:none;border:none;font-size:2.5rem;color:var(--text-color);cursor:pointer}.custom-header .custom-close-button:hover{color:var(--danger-color)}.custom-modal-title{color:var(--text-color)!important;font-size:1.8rem!important;font-family:var(--font-family)!important}.custom-body{background-color:#fff;padding:1rem}.custom-footer{background-color:#fff;padding:.75rem;display:flex;justify-content:flex-end;gap:.5rem}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DynamicModalComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-dynamic-modal", template: "<div\n  class=\"modal fade\"\n  [id]=\"modalId\"\n  tabindex=\"-1\"\n  [attr.aria-labelledby]=\"modalId + 'Label'\"\n  aria-hidden=\"true\"\n>\n  <div class=\"modal-dialog\" [ngClass]=\"modalSizeClass\">\n    <div class=\"modal-content\">\n      <div class=\"modal-header custom-header\">\n        <h5 class=\"modal-title custom-modal-title\" [id]=\"modalId + 'Label'\">\n          {{ modalTitle }}\n        </h5>\n        <button\n          type=\"button\"\n          class=\"custom-close-button\"\n          (click)=\"closeModal()\"\n          aria-label=\"Close\"\n        >\n          &times;\n        </button>\n      </div>\n      <div class=\"modal-body custom-body\">\n        <ng-content select=\"[modal-body]\"></ng-content>\n      </div>\n      <div class=\"modal-footer custom-footer\">\n        <ng-content select=\"[modal-footer]\"></ng-content>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: [".custom-header{background-color:var(--primary-color)!important;color:var(--text-color)!important;font-size:1.25rem!important;font-family:var(--font-family)!important;padding:1rem;position:relative}.custom-header .custom-close-button{position:absolute;right:1rem;background:none;border:none;font-size:2.5rem;color:var(--text-color);cursor:pointer}.custom-header .custom-close-button:hover{color:var(--danger-color)}.custom-modal-title{color:var(--text-color)!important;font-size:1.8rem!important;font-family:var(--font-family)!important}.custom-body{background-color:#fff;padding:1rem}.custom-footer{background-color:#fff;padding:.75rem;display:flex;justify-content:flex-end;gap:.5rem}\n"] }]
        }], propDecorators: { modalTitle: [{
                type: Input
            }], modalSizeClass: [{
                type: Input
            }], modalId: [{
                type: Input
            }] } });

class DynamicTableComponent {
    constructor() {
        this.itemsPerPageOptions = [10, 20, 50];
        this.showPageInfo = true;
        this.currentPage = 1;
        this.itemsPerPage = 10;
    }
    get totalItems() {
        return this.config.totalItems ?? this.config.data.length;
    }
    get paginatedData() {
        if (!this.config.pagination) {
            // Retorna todos os dados se a paginação estiver desativada
            return this.config.data;
        }
        const itemsPerPage = this.config.itemsPerPage || this.itemsPerPage;
        const startIndex = (this.currentPage - 1) * itemsPerPage;
        return this.config.data.slice(startIndex, startIndex + itemsPerPage);
    }
    ngOnInit() {
        if (!this.config || !this.config.columns || !this.config.data) {
            throw new Error("DynamicTableComponent: Configuração inválida.");
        }
        // Define valores padrão se não especificados
        this.config.showHeader = this.config.showHeader ?? true; // Exibe o cabeçalho por padrão
        this.config.pagination = this.config.pagination ?? true; // Ativa paginação por padrão
        this.itemsPerPage = this.config.itemsPerPage || 10;
    }
    onPageChange(newPage) {
        this.currentPage = newPage;
    }
    onItemsPerPageChange(event) {
        const target = event.target;
        this.itemsPerPage = +target.value;
        this.currentPage = 1; // Reinicia a paginação ao alterar os itens por página
    }
    // Getter para garantir que totalItems nunca seja undefined
    get safeTotalItems() {
        return this.totalItems || 0;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DynamicTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DynamicTableComponent, selector: "argenta-dynamic-table", inputs: { config: "config", itemsPerPageOptions: "itemsPerPageOptions", showPageInfo: "showPageInfo" }, ngImport: i0, template: "<table class=\"table\" [ngClass]=\"{ nested: config.isNested }\">\n  <thead *ngIf=\"config.showHeader\">\n    <tr>\n      <th *ngFor=\"let column of config.columns\">{{ column.header }}</th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr *ngFor=\"let row of paginatedData\">\n      <td *ngFor=\"let column of config.columns\">\n        <ng-container [ngSwitch]=\"column.type\">\n          <span *ngSwitchCase=\"'text'\">{{ row[column.key] }}</span>\n          <ng-container *ngSwitchCase=\"'template'\">\n            <ng-container\n              *ngTemplateOutlet=\"\n                column.template || null;\n                context: { $implicit: row }\n              \"\n            ></ng-container>\n          </ng-container>\n        </ng-container>\n      </td>\n    </tr>\n  </tbody>\n</table>\n\n<div\n  class=\"text-center pagination-controls\"\n  [ngClass]=\"{ nested: config.isNested }\"\n  *ngIf=\"config.pagination\"\n>\n  <custom-pagination\n    [totalItems]=\"safeTotalItems\"\n    [itemsPerPage]=\"itemsPerPage\"\n    [currentPage]=\"currentPage\"\n    [showPageInfo]=\"showPageInfo\"\n    (pageChange)=\"onPageChange($event)\"\n  >\n  </custom-pagination>\n</div>\n", styles: ["@charset \"UTF-8\";.table{width:100%;border-collapse:collapse;border-spacing:0}.table{width:100%;border-collapse:separate;border-spacing:0;overflow:hidden}.table thead th{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);font-size:14px;font-weight:600;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center;line-height:2.5}.table thead th:first-child{border-top-left-radius:10px}.table thead th:last-child{border-top-right-radius:10px}.table.nested thead th{font-size:.7rem;padding:7px;line-height:.8}.table tbody td{font-family:var(--font-family);font-size:14px;color:#737b7b;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center}.table tbody td:first-child{text-align:left;padding-left:1.4rem}.table.nested tbody td:first-child{padding-left:1rem}.table tbody tr:hover{background-color:#f5f5f5!important;transition:background-color .3s ease}.table.nested tbody tr:hover{background-color:#f0f0f0!important}.pagination-controls{display:flex;justify-content:center;align-items:center;margin-top:1rem}.pagination-controls.nested{font-size:.7rem;transform:scale(.7);margin-top:.5rem}.data-table-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:1rem}.left-section{display:flex;align-items:center}.items-per-page-label{font-family:var(--font-family);font-size:14px;color:#666;margin-right:.5rem}.custom-select{font-family:var(--font-family);font-size:14px;padding:.375rem 1.75rem .375rem .75rem;border:1px solid #ccc;border-radius:.25rem;appearance:none;background:#fff url('data:image/svg+xml;charset=US-ASCII,<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 5\"><path fill=\"#666\" d=\"M2 0L0 2h4L2 0zM2 5l2-2H0l2 2z\"/></svg>') no-repeat right .75rem center/8px 10px}.custom-select:focus{border-color:#80bdff;outline:none;box-shadow:0 0 0 .2rem #007bff40}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: CustomPaginationComponent, selector: "custom-pagination", inputs: ["totalItems", "itemsPerPage", "currentPage", "showPageInfo"], outputs: ["pageChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DynamicTableComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-dynamic-table", template: "<table class=\"table\" [ngClass]=\"{ nested: config.isNested }\">\n  <thead *ngIf=\"config.showHeader\">\n    <tr>\n      <th *ngFor=\"let column of config.columns\">{{ column.header }}</th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr *ngFor=\"let row of paginatedData\">\n      <td *ngFor=\"let column of config.columns\">\n        <ng-container [ngSwitch]=\"column.type\">\n          <span *ngSwitchCase=\"'text'\">{{ row[column.key] }}</span>\n          <ng-container *ngSwitchCase=\"'template'\">\n            <ng-container\n              *ngTemplateOutlet=\"\n                column.template || null;\n                context: { $implicit: row }\n              \"\n            ></ng-container>\n          </ng-container>\n        </ng-container>\n      </td>\n    </tr>\n  </tbody>\n</table>\n\n<div\n  class=\"text-center pagination-controls\"\n  [ngClass]=\"{ nested: config.isNested }\"\n  *ngIf=\"config.pagination\"\n>\n  <custom-pagination\n    [totalItems]=\"safeTotalItems\"\n    [itemsPerPage]=\"itemsPerPage\"\n    [currentPage]=\"currentPage\"\n    [showPageInfo]=\"showPageInfo\"\n    (pageChange)=\"onPageChange($event)\"\n  >\n  </custom-pagination>\n</div>\n", styles: ["@charset \"UTF-8\";.table{width:100%;border-collapse:collapse;border-spacing:0}.table{width:100%;border-collapse:separate;border-spacing:0;overflow:hidden}.table thead th{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);font-size:14px;font-weight:600;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center;line-height:2.5}.table thead th:first-child{border-top-left-radius:10px}.table thead th:last-child{border-top-right-radius:10px}.table.nested thead th{font-size:.7rem;padding:7px;line-height:.8}.table tbody td{font-family:var(--font-family);font-size:14px;color:#737b7b;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center}.table tbody td:first-child{text-align:left;padding-left:1.4rem}.table.nested tbody td:first-child{padding-left:1rem}.table tbody tr:hover{background-color:#f5f5f5!important;transition:background-color .3s ease}.table.nested tbody tr:hover{background-color:#f0f0f0!important}.pagination-controls{display:flex;justify-content:center;align-items:center;margin-top:1rem}.pagination-controls.nested{font-size:.7rem;transform:scale(.7);margin-top:.5rem}.data-table-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:1rem}.left-section{display:flex;align-items:center}.items-per-page-label{font-family:var(--font-family);font-size:14px;color:#666;margin-right:.5rem}.custom-select{font-family:var(--font-family);font-size:14px;padding:.375rem 1.75rem .375rem .75rem;border:1px solid #ccc;border-radius:.25rem;appearance:none;background:#fff url('data:image/svg+xml;charset=US-ASCII,<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 5\"><path fill=\"#666\" d=\"M2 0L0 2h4L2 0zM2 5l2-2H0l2 2z\"/></svg>') no-repeat right .75rem center/8px 10px}.custom-select:focus{border-color:#80bdff;outline:none;box-shadow:0 0 0 .2rem #007bff40}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { config: [{
                type: Input
            }], itemsPerPageOptions: [{
                type: Input
            }], showPageInfo: [{
                type: Input
            }] } });

class FileUploadComponent {
    constructor(authService) {
        this.authService = authService;
        this.accept = '.pdf, .doc, .docx, .xls, .xlsx, .ppt, .pptx, .txt, .jpg, .jpeg, .png, .gif, .bmp, .svg, .webp, .zip, .rar, .csv';
        this.multiple = false;
        this.maxFileSize = 2 * 1024 * 1024; // 2MB
        this.labelText = 'Select Files to Upload'; // Dynamic label text
        this.fileUploaded = new EventEmitter(); // Emits selected files
        this.destroy$ = new Subject();
    }
    onFileChange(event) {
        const input = event.target;
        if (input.files) {
            const files = Array.from(input.files);
            if (this.validateFiles(files)) {
                this.fileUploaded.emit(files); // Emit files for external handling
            }
            else {
                console.warn('One or more files exceed the maximum allowed size of 2MB.');
            }
        }
    }
    validateFiles(files) {
        return files.every(file => file.size <= this.maxFileSize);
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return true;
        }
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FileUploadComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FileUploadComponent, selector: "argenta-file-upload", inputs: { accept: "accept", multiple: "multiple", maxFileSize: "maxFileSize", labelText: "labelText", permissions: "permissions" }, outputs: { fileUploaded: "fileUploaded" }, ngImport: i0, template: "<div *ngIf=\"hasPermission()\" class=\"file-upload-container\">\n  <label for=\"fileUpload\" class=\"form-label\">{{ labelText }}</label> \n  <input\n    type=\"file\"\n    id=\"fileUpload\"\n    class=\"form-control\"\n    [accept]=\"accept\"\n    [multiple]=\"multiple\"\n    (change)=\"onFileChange($event)\" \n  />\n</div>\n", styles: [".file-upload-container{margin-top:10px;font-family:var(--font-family)}.file-upload-container .form-label{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem;color:#333}.file-upload-container .form-control[type=file]{padding:10px;border-radius:5px;border:1px solid #ced4da;font-family:var(--font-family);color:#333;font-size:.9rem}.file-upload-container .form-control[type=file]::file-selector-button{padding:.5rem 1rem;margin-right:10px;border:1px solid #ced4da;border-radius:5px;background-color:#f8f9fa;color:#000;cursor:pointer;transition:background-color .2s}.file-upload-container .form-control[type=file]::file-selector-button:hover{background-color:#e2e6ea}.file-upload-container .form-text{color:#6c757d;font-size:.875rem}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FileUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-file-upload', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div *ngIf=\"hasPermission()\" class=\"file-upload-container\">\n  <label for=\"fileUpload\" class=\"form-label\">{{ labelText }}</label> \n  <input\n    type=\"file\"\n    id=\"fileUpload\"\n    class=\"form-control\"\n    [accept]=\"accept\"\n    [multiple]=\"multiple\"\n    (change)=\"onFileChange($event)\" \n  />\n</div>\n", styles: [".file-upload-container{margin-top:10px;font-family:var(--font-family)}.file-upload-container .form-label{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem;color:#333}.file-upload-container .form-control[type=file]{padding:10px;border-radius:5px;border:1px solid #ced4da;font-family:var(--font-family);color:#333;font-size:.9rem}.file-upload-container .form-control[type=file]::file-selector-button{padding:.5rem 1rem;margin-right:10px;border:1px solid #ced4da;border-radius:5px;background-color:#f8f9fa;color:#000;cursor:pointer;transition:background-color .2s}.file-upload-container .form-control[type=file]::file-selector-button:hover{background-color:#e2e6ea}.file-upload-container .form-text{color:#6c757d;font-size:.875rem}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { accept: [{
                type: Input
            }], multiple: [{
                type: Input
            }], maxFileSize: [{
                type: Input
            }], labelText: [{
                type: Input
            }], permissions: [{
                type: Input
            }], fileUploaded: [{
                type: Output
            }] } });

class ImageUploadComponent {
    constructor(authService) {
        this.authService = authService;
        this.imagePreview = null;
        this.base64Output = new EventEmitter();
    }
    onFileSelected(event) {
        const input = event.target;
        if (input.files && input.files.length > 0) {
            const file = input.files[0];
            const reader = new FileReader();
            reader.onload = () => {
                this.imagePreview = reader.result;
                this.base64Output.emit(reader.result);
            };
            reader.readAsDataURL(file);
        }
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ImageUploadComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ImageUploadComponent, selector: "argenta-image-upload", inputs: { imagePreview: "imagePreview", label: "label", permissions: "permissions" }, outputs: { base64Output: "base64Output" }, ngImport: i0, template: "<div *ngIf=\"hasPermission()\" class=\"image-uploader\">\n  <div *ngIf=\"imagePreview\">\n    <img [src]=\"imagePreview\" />\n  </div>\n  <label for=\"fileInput\" class=\"custom-file-label\">\n    {{ label }} <i-lucide name=\"import\" [size]=\"20\" color=\"black\"></i-lucide>\n  </label>\n  <input\n    type=\"file\"\n    id=\"fileInput\"\n    (change)=\"onFileSelected($event)\"\n    accept=\"image/*\"\n    hidden\n  />\n</div>\n", styles: [".image-uploader{display:flex;flex-direction:column;align-items:center;gap:10px}.image-uploader input{border:1px solid #ccc;padding:8px;cursor:pointer}.image-uploader img{max-width:300px;max-height:300px;border-radius:10px;box-shadow:0 0 10px #0000001a}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ImageUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-image-upload', template: "<div *ngIf=\"hasPermission()\" class=\"image-uploader\">\n  <div *ngIf=\"imagePreview\">\n    <img [src]=\"imagePreview\" />\n  </div>\n  <label for=\"fileInput\" class=\"custom-file-label\">\n    {{ label }} <i-lucide name=\"import\" [size]=\"20\" color=\"black\"></i-lucide>\n  </label>\n  <input\n    type=\"file\"\n    id=\"fileInput\"\n    (change)=\"onFileSelected($event)\"\n    accept=\"image/*\"\n    hidden\n  />\n</div>\n", styles: [".image-uploader{display:flex;flex-direction:column;align-items:center;gap:10px}.image-uploader input{border:1px solid #ccc;padding:8px;cursor:pointer}.image-uploader img{max-width:300px;max-height:300px;border-radius:10px;box-shadow:0 0 10px #0000001a}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { imagePreview: [{
                type: Input
            }], label: [{
                type: Input
            }], permissions: [{
                type: Input
            }], base64Output: [{
                type: Output
            }] } });

class CepMaskDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.enabled = false; // Define como opcional e padrão desabilitado
    }
    onInputChange(event) {
        if (!this.enabled)
            return; // Não aplica a máscara se não estiver habilitada
        // Obtém o valor atual e remove todos os caracteres não numéricos
        let initialValue = this.el.nativeElement.value.replace(/\D/g, '');
        // Limita o número de caracteres a 8 para CEP
        if (initialValue.length > 8) {
            initialValue = initialValue.slice(0, 8);
        }
        // Aplica a máscara de CEP
        const formattedValue = this.formatCep(initialValue);
        // Atualiza o valor do input se necessário
        if (formattedValue !== this.el.nativeElement.value) {
            this.renderer.setProperty(this.el.nativeElement, 'value', formattedValue);
            // Dispara um evento de input para atualizar o modelo
            if (event.target.dispatchEvent) {
                const newEvent = new Event('input', { bubbles: true });
                event.target.dispatchEvent(newEvent);
            }
        }
    }
    formatCep(value) {
        // Aplica a formatação de CEP: 12345-678
        return value.replace(/(\d{5})(\d)/, '$1-$2');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CepMaskDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: CepMaskDirective, selector: "[cepMask]", inputs: { enabled: ["cepMask", "enabled"] }, host: { listeners: { "input": "onInputChange($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CepMaskDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[cepMask]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { enabled: [{
                type: Input,
                args: ['cepMask']
            }], onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class CnpjMaskDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.enabled = false; // Define como opcional e padrão desabilitado
    }
    onInputChange(event) {
        if (!this.enabled)
            return; // Não aplica a máscara se não estiver habilitada
        // Obtém o valor atual e remove todos os caracteres não numéricos
        let initialValue = this.el.nativeElement.value.replace(/\D/g, '');
        // Limita o número de caracteres a 14 para CNPJ
        if (initialValue.length > 14) {
            initialValue = initialValue.slice(0, 14);
        }
        // Aplica a máscara de CNPJ
        const formattedValue = this.formatCnpj(initialValue);
        // Atualiza o valor do input se necessário
        if (formattedValue !== this.el.nativeElement.value) {
            this.renderer.setProperty(this.el.nativeElement, 'value', formattedValue);
            // Dispara um evento de input para atualizar o modelo
            if (event.target.dispatchEvent) {
                const newEvent = new Event('input', { bubbles: true });
                event.target.dispatchEvent(newEvent);
            }
        }
    }
    formatCnpj(value) {
        // Aplica a formatação de CNPJ: 12.345.678/0001-00
        return value
            .replace(/(\d{2})(\d)/, '$1.$2')
            .replace(/(\d{3})(\d)/, '$1.$2')
            .replace(/(\d{3})(\d{4})(\d)/, '$1/$2-$3')
            .replace(/(\d{4})(\d{2})$/, '$1-$2');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CnpjMaskDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: CnpjMaskDirective, selector: "[cnpjMask]", inputs: { enabled: ["cnpjMask", "enabled"] }, host: { listeners: { "input": "onInputChange($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CnpjMaskDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[cnpjMask]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { enabled: [{
                type: Input,
                args: ['cnpjMask']
            }], onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class CpfMaskDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.enabled = false; // Define como opcional e padrão desabilitado
    }
    onInputChange(event) {
        if (!this.enabled)
            return;
        // Obtém o valor atual e remove todos os caracteres não numéricos
        let initialValue = this.el.nativeElement.value.replace(/\D/g, '');
        // Limita o número de caracteres a 11 para CPF
        if (initialValue.length > 11) {
            initialValue = initialValue.slice(0, 11);
        }
        // Aplica a máscara de CPF
        const formattedValue = this.formatCpf(initialValue);
        // Atualiza o valor do input se necessário
        if (formattedValue !== this.el.nativeElement.value) {
            this.renderer.setProperty(this.el.nativeElement, 'value', formattedValue);
            // Dispara um evento de input para atualizar o modelo
            if (event.target.dispatchEvent) {
                const newEvent = new Event('input', { bubbles: true });
                event.target.dispatchEvent(newEvent);
            }
        }
    }
    formatCpf(value) {
        // Aplica a formatação de CPF: 123.456.789-00
        return value
            .replace(/(\d{3})(\d)/, '$1.$2')
            .replace(/(\d{3})(\d)/, '$1.$2')
            .replace(/(\d{3})(\d{1,2})$/, '$1-$2');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CpfMaskDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: CpfMaskDirective, selector: "[cpfMask]", inputs: { enabled: ["cpfMask", "enabled"] }, host: { listeners: { "input": "onInputChange($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CpfMaskDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[cpfMask]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { enabled: [{
                type: Input,
                args: ['cpfMask']
            }], onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class InputComponent {
    constructor(authService) {
        this.authService = authService;
        this.label = "Default Label";
        this.placeholder = "";
        this.id = "inputId";
        this.type = "text";
        this.disabled = false;
        this.readonly = false;
        this.maxlength = null;
        this.minlength = null;
        this.required = false;
        this.pattern = null;
        this.autofocus = false;
        this.useCpfMask = false;
        this.useCnpjMask = false;
        this.useCepMask = false;
        this.onlyNumbers = false;
        this.onlyNumbersAndDecimals = false;
        this.validateInput = false;
        this.labelFontWeight = 400;
        this.useMoneyMask = false; // Para ativar/desativar a máscara de moeda
        this.currencyCode = "BRL"; // Código da moeda
        this.displayCurrencySymbol = true; // Exibir ou não o símbolo da moeda
        this.prependText = "";
        this.buttonText = null;
        this.useLatitudeMask = false;
        this.useLongitudeMask = false;
        this.inputEvent = new EventEmitter();
        this.changeEvent = new EventEmitter();
        this.focusEvent = new EventEmitter();
        this.blurEvent = new EventEmitter();
        this.keyupEvent = new EventEmitter();
        this.keydownEvent = new EventEmitter();
        this.keypressEvent = new EventEmitter();
        this.buttonClick = new EventEmitter();
        this.onChangeCallback = () => { };
        this.onTouchedCallback = () => { };
        this.ButtonClasses = ButtonClasses;
        this.value = "";
        this.showErrorModal = false;
        this.errorMessage = "";
        this.subscriptions = [];
    }
    getInputType() {
        return (this.onlyNumbers || this.onlyNumbersAndDecimals) ? "tel" : this.type;
    }
    onInput(event) {
        const inputElement = event.target;
        let inputValue = inputElement.value;
        if (this.useLatitudeMask || this.useLongitudeMask) {
            inputValue = inputValue.replace(/[^0-9.,-]/g, "");
            inputValue = inputValue.replace(/,/g, ".");
            const parts = inputValue.split(".");
        }
        else if (this.onlyNumbers &&
            !(this.useCpfMask ||
                this.useCnpjMask ||
                this.useCepMask ||
                this.useMoneyMask)) {
            inputValue = inputValue.replace(/\D/g, ""); // Remove todos os não numéricos
        }
        // Validação imediata para CPF, CNPJ ou CEP
        const numericValue = inputValue.replace(/\D/g, ""); // Remove todos os caracteres não numéricos
        if (this.validateInput) {
            if (this.useCpfMask &&
                numericValue.length === 11 &&
                !this.validateCpf(numericValue)) {
                this.clearAndShowValidationError("CPF inválido. Por favor, insira um CPF correto.");
            }
            else if (this.useCnpjMask &&
                numericValue.length === 14 &&
                !this.validateCnpj(numericValue)) {
                this.clearAndShowValidationError("CNPJ inválido. Por favor, insira um CNPJ correto.");
            }
            else if (this.useCepMask &&
                numericValue.length === 8 &&
                !this.validateCep(numericValue)) {
                this.clearAndShowValidationError("CEP inválido. Por favor, insira um CEP correto.");
            }
        }
        // Máscara de moeda
        if (this.useMoneyMask) {
            const numericValue = inputValue.replace(/\D/g, ""); // Remove todos os não numéricos
            const formattedValue = this.formatMoney(numericValue); // Formata como dinheiro ou número decimal
            inputElement.value = formattedValue;
            this.value = formattedValue;
        }
        else {
            this.value = inputValue;
        }
        // Atualiza o valor e emite o evento de mudança
        this.onChangeCallback(this.value);
        this.inputEvent.emit(event);
    }
    formatMoney(value) {
        if (!value)
            return ""; // Se o valor estiver vazio, retorna uma string vazia
        const numericValue = parseFloat(value) / 100;
        // Verifica se deve exibir o símbolo da moeda ou não
        if (this.displayCurrencySymbol) {
            // Formata como moeda
            return new Intl.NumberFormat("pt-BR", {
                style: "currency",
                currency: this.currencyCode,
            }).format(numericValue);
        }
        else {
            // Formata como número decimal, sem o símbolo da moeda
            return new Intl.NumberFormat("pt-BR", {
                style: "decimal",
                minimumFractionDigits: 2,
                maximumFractionDigits: 2,
            }).format(numericValue);
        }
    }
    onKeyDown(event) {
        if (this.useLatitudeMask || this.useLongitudeMask) {
            const allowedKeys = [
                "Backspace",
                "ArrowLeft",
                "ArrowRight",
                "Tab",
                "Delete",
                "Enter",
                "-",
                ".",
                ",",
            ];
            if (!allowedKeys.includes(event.key) && !/^\d$/.test(event.key)) {
                event.preventDefault();
            }
        }
        else if (this.onlyNumbers &&
            !/^\d$/.test(event.key) &&
            event.key !== "Backspace" &&
            event.key !== "ArrowLeft" &&
            event.key !== "ArrowRight") {
            event.preventDefault(); // Impede a entrada de caracteres não numéricos
        }
        const input = event.target;
        if (this.onlyNumbersAndDecimals &&
            !/^\d$/.test(event.key) &&
            (event.key !== "." || input.value.includes(".")) &&
            event.key !== "Backspace" &&
            event.key !== "Delete" &&
            event.key !== "Tab" && // Adiciona suporte ao Tab
            event.key !== "ArrowLeft" &&
            event.key !== "ArrowRight") {
            event.preventDefault();
        }
    }
    onChange(event) {
        const numericValue = this.value.replace(/\D/g, ""); // Remove todos os caracteres não numéricos
        // Validação também ocorre no blur para casos onde o input não está completo
        if (this.validateInput) {
            if (this.useCpfMask && !this.validateCpf(numericValue)) {
                this.clearAndShowValidationError("CPF inválido. Por favor, insira um CPF correto.");
            }
            else if (this.useCnpjMask && !this.validateCnpj(numericValue)) {
                this.clearAndShowValidationError("CNPJ inválido. Por favor, insira um CNPJ correto.");
            }
            else if (this.useCepMask && !this.validateCep(numericValue)) {
                this.clearAndShowValidationError("CEP inválido. Por favor, insira um CEP correto.");
            }
        }
        this.changeEvent.emit(event);
    }
    validateCpf(cpf) {
        if (cpf.length !== 11 || /^(\d)\1+$/.test(cpf))
            return false;
        let sum = 0, remainder;
        for (let i = 1; i <= 9; i++)
            sum += parseInt(cpf.substring(i - 1, i)) * (11 - i);
        remainder = (sum * 10) % 11;
        if (remainder === 10 || remainder === 11)
            remainder = 0;
        if (remainder !== parseInt(cpf.substring(9, 10)))
            return false;
        sum = 0;
        for (let i = 1; i <= 10; i++)
            sum += parseInt(cpf.substring(i - 1, i)) * (12 - i);
        remainder = (sum * 10) % 11;
        if (remainder === 10 || remainder === 11)
            remainder = 0;
        return remainder === parseInt(cpf.substring(10, 11));
    }
    validateCnpj(cnpj) {
        if (cnpj.length !== 14)
            return false;
        let length = cnpj.length - 2;
        let numbers = cnpj.substring(0, length);
        let digits = cnpj.substring(length);
        let sum = 0, pos = length - 7;
        for (let i = length; i >= 1; i--) {
            sum += parseInt(numbers.charAt(length - i)) * pos--;
            if (pos < 2)
                pos = 9;
        }
        let result = sum % 11 < 2 ? 0 : 11 - (sum % 11);
        if (result !== parseInt(digits.charAt(0)))
            return false;
        length = length + 1;
        numbers = cnpj.substring(0, length);
        sum = 0;
        pos = length - 7;
        for (let i = length; i >= 1; i--) {
            sum += parseInt(numbers.charAt(length - i)) * pos--;
            if (pos < 2)
                pos = 9;
        }
        result = sum % 11 < 2 ? 0 : 11 - (sum % 11);
        return result === parseInt(digits.charAt(1));
    }
    validateCep(cep) {
        return /^\d{8}$/.test(cep); // Valida apenas números, sem considerar a máscara
    }
    clearAndShowValidationError(message) {
        this.value = ""; // Limpa o valor do ngModel
        this.onChangeCallback(this.value); // Atualiza o ngModel com o valor limpo
        this.errorMessage = message;
        this.showErrorModal = true;
    }
    closeModal() {
        this.showErrorModal = false;
        this.errorMessage = "";
    }
    onFocus(event) {
        this.focusEvent.emit(event);
    }
    onBlur(event) {
        this.onTouchedCallback();
        this.blurEvent.emit(event);
    }
    writeValue(value) {
        this.value = value;
    }
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error("Permission error:", error.message);
            }
            else {
                console.error("Unknown error occurred during permission check");
            }
            return true;
        }
    }
    onButtonClick() {
        this.buttonClick.emit();
    }
    ngOnDestroy() {
        this.subscriptions.forEach((sub) => sub.unsubscribe());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: InputComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: InputComponent, selector: "argenta-custom-input", inputs: { label: "label", placeholder: "placeholder", id: "id", type: "type", disabled: "disabled", readonly: "readonly", maxlength: "maxlength", minlength: "minlength", required: "required", pattern: "pattern", autofocus: "autofocus", useCpfMask: "useCpfMask", useCnpjMask: "useCnpjMask", useCepMask: "useCepMask", onlyNumbers: "onlyNumbers", onlyNumbersAndDecimals: "onlyNumbersAndDecimals", validateInput: "validateInput", labelFontWeight: "labelFontWeight", permissions: "permissions", useMoneyMask: "useMoneyMask", currencyCode: "currencyCode", displayCurrencySymbol: "displayCurrencySymbol", prependText: "prependText", buttonText: "buttonText", useLatitudeMask: "useLatitudeMask", useLongitudeMask: "useLongitudeMask" }, outputs: { inputEvent: "inputEvent", changeEvent: "changeEvent", focusEvent: "focusEvent", blurEvent: "blurEvent", keyupEvent: "keyupEvent", keydownEvent: "keydownEvent", keypressEvent: "keypressEvent", buttonClick: "buttonClick" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => InputComponent),
                multi: true,
            },
        ], ngImport: i0, template: "<div *ngIf=\"hasPermission()\" class=\"form-group\">\n  <label [for]=\"id\" [ngClass]=\"'label-styles'\">{{ label }}</label>\n  <div class=\"input-group\">\n    <div *ngIf=\"prependText\" class=\"input-group-prepend\">\n      <span\n        class=\"input-group-text custom-input-group-text\"\n        id=\"basic-addon3\"\n        >{{ prependText }}</span\n      >\n    </div>\n    <input\n      [type]=\"getInputType()\"\n      class=\"form-control custom-input\"\n      [id]=\"id\"\n      [placeholder]=\"placeholder\"\n      [(ngModel)]=\"value\"\n      (input)=\"onInput($event)\"\n      (change)=\"onChange($event)\"\n      (focus)=\"onFocus($event)\"\n      (blur)=\"onBlur($event)\"\n      (keyup)=\"keyupEvent.emit($event)\"\n      (keydown)=\"onKeyDown($event)\"\n      (keypress)=\"keypressEvent.emit($event)\"\n      [disabled]=\"disabled\"\n      [readonly]=\"readonly\"\n      [attr.maxlength]=\"maxlength\"\n      [attr.minlength]=\"minlength\"\n      [required]=\"required\"\n      [attr.pattern]=\"pattern\"\n      [autofocus]=\"autofocus\"\n      [cpfMask]=\"useCpfMask\"\n      [cnpjMask]=\"useCnpjMask\"\n      [cepMask]=\"useCepMask\"\n    />\n\n    <div class=\"input-group-append\" *ngIf=\"buttonText\">\n      <button type=\"button\" class=\"btn-group-append\" (click)=\"onButtonClick()\">\n        {{ buttonText }}\n      </button>\n    </div>\n\n    <!-- Modal para exibir mensagens de erro -->\n    <div class=\"modal-overlay\" *ngIf=\"showErrorModal\">\n      <div class=\"modal-content\">\n        <span class=\"close\" (click)=\"closeModal()\">&times;</span>\n        <p>{{ errorMessage }}</p>\n        <button class=\"btn-ok\" (click)=\"closeModal()\">OK</button>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.form-check-input{font-family:var(--font-family);color:#333;font-size:.9rem}.form-check-label{width:623px;height:19px;top:1608px;left:133px;gap:0px;opacity:0px;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;height:46px}.custom-input::placeholder{font-size:14px;color:#d3d3d3}.form-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.modal-overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:#0009;display:flex;align-items:center;justify-content:center;z-index:1000}.modal-content{background:#fff;padding:25px 30px;border-radius:8px;width:360px;text-align:center;position:relative;box-shadow:0 4px 12px #0003}.close{position:absolute;top:10px;right:15px;cursor:pointer;font-size:20px;color:#555;transition:color .3s}.close:hover{color:#f44336}.btn-ok{margin-top:20px;padding:8px 20px;border:none;background-color:#00444c;color:#fff;border-radius:4px;cursor:pointer;font-size:14px;transition:background-color .3s,transform .2s}.btn-ok:hover{background-color:#00363d;transform:scale(1.05)}.btn-ok:active{transform:scale(.98)}.input-group-text{padding:.64rem .75rem;font-family:var(--font-family);color:#6e6e6e;font-size:14px}.btn-group-append{padding:.69rem;font-family:var(--font-family);background-color:var(--secondary-color);border:0rem solid;color:var(--text-color);transition:border-width .2s,transform .1s;font-size:1rem;border-top-right-radius:6px;border-bottom-right-radius:6px}.btn-group-append:hover{background-color:var(--primary-color)}.custom-input-group-text{border-top-right-radius:0;border-bottom-right-radius:0;padding:.71rem .75rem;background-color:#e7e7e7;border:1px solid #dbdbdb}.btn-group-append:active{animation:blink .3s}@keyframes blink{0%{background-color:var(--primary-color);border-color:var(--primary-color)}50%{background-color:var(--secondary-color);border-color:var(--secondary-color)}to{background-color:var(--primary-color);border-color:var(--primary-color)}}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: CepMaskDirective, selector: "[cepMask]", inputs: ["cepMask"] }, { kind: "directive", type: CnpjMaskDirective, selector: "[cnpjMask]", inputs: ["cnpjMask"] }, { kind: "directive", type: CpfMaskDirective, selector: "[cpfMask]", inputs: ["cpfMask"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: InputComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-custom-input", providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => InputComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div *ngIf=\"hasPermission()\" class=\"form-group\">\n  <label [for]=\"id\" [ngClass]=\"'label-styles'\">{{ label }}</label>\n  <div class=\"input-group\">\n    <div *ngIf=\"prependText\" class=\"input-group-prepend\">\n      <span\n        class=\"input-group-text custom-input-group-text\"\n        id=\"basic-addon3\"\n        >{{ prependText }}</span\n      >\n    </div>\n    <input\n      [type]=\"getInputType()\"\n      class=\"form-control custom-input\"\n      [id]=\"id\"\n      [placeholder]=\"placeholder\"\n      [(ngModel)]=\"value\"\n      (input)=\"onInput($event)\"\n      (change)=\"onChange($event)\"\n      (focus)=\"onFocus($event)\"\n      (blur)=\"onBlur($event)\"\n      (keyup)=\"keyupEvent.emit($event)\"\n      (keydown)=\"onKeyDown($event)\"\n      (keypress)=\"keypressEvent.emit($event)\"\n      [disabled]=\"disabled\"\n      [readonly]=\"readonly\"\n      [attr.maxlength]=\"maxlength\"\n      [attr.minlength]=\"minlength\"\n      [required]=\"required\"\n      [attr.pattern]=\"pattern\"\n      [autofocus]=\"autofocus\"\n      [cpfMask]=\"useCpfMask\"\n      [cnpjMask]=\"useCnpjMask\"\n      [cepMask]=\"useCepMask\"\n    />\n\n    <div class=\"input-group-append\" *ngIf=\"buttonText\">\n      <button type=\"button\" class=\"btn-group-append\" (click)=\"onButtonClick()\">\n        {{ buttonText }}\n      </button>\n    </div>\n\n    <!-- Modal para exibir mensagens de erro -->\n    <div class=\"modal-overlay\" *ngIf=\"showErrorModal\">\n      <div class=\"modal-content\">\n        <span class=\"close\" (click)=\"closeModal()\">&times;</span>\n        <p>{{ errorMessage }}</p>\n        <button class=\"btn-ok\" (click)=\"closeModal()\">OK</button>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.form-check-input{font-family:var(--font-family);color:#333;font-size:.9rem}.form-check-label{width:623px;height:19px;top:1608px;left:133px;gap:0px;opacity:0px;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;height:46px}.custom-input::placeholder{font-size:14px;color:#d3d3d3}.form-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.modal-overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:#0009;display:flex;align-items:center;justify-content:center;z-index:1000}.modal-content{background:#fff;padding:25px 30px;border-radius:8px;width:360px;text-align:center;position:relative;box-shadow:0 4px 12px #0003}.close{position:absolute;top:10px;right:15px;cursor:pointer;font-size:20px;color:#555;transition:color .3s}.close:hover{color:#f44336}.btn-ok{margin-top:20px;padding:8px 20px;border:none;background-color:#00444c;color:#fff;border-radius:4px;cursor:pointer;font-size:14px;transition:background-color .3s,transform .2s}.btn-ok:hover{background-color:#00363d;transform:scale(1.05)}.btn-ok:active{transform:scale(.98)}.input-group-text{padding:.64rem .75rem;font-family:var(--font-family);color:#6e6e6e;font-size:14px}.btn-group-append{padding:.69rem;font-family:var(--font-family);background-color:var(--secondary-color);border:0rem solid;color:var(--text-color);transition:border-width .2s,transform .1s;font-size:1rem;border-top-right-radius:6px;border-bottom-right-radius:6px}.btn-group-append:hover{background-color:var(--primary-color)}.custom-input-group-text{border-top-right-radius:0;border-bottom-right-radius:0;padding:.71rem .75rem;background-color:#e7e7e7;border:1px solid #dbdbdb}.btn-group-append:active{animation:blink .3s}@keyframes blink{0%{background-color:var(--primary-color);border-color:var(--primary-color)}50%{background-color:var(--secondary-color);border-color:var(--secondary-color)}to{background-color:var(--primary-color);border-color:var(--primary-color)}}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { label: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], id: [{
                type: Input
            }], type: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readonly: [{
                type: Input
            }], maxlength: [{
                type: Input
            }], minlength: [{
                type: Input
            }], required: [{
                type: Input
            }], pattern: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], useCpfMask: [{
                type: Input
            }], useCnpjMask: [{
                type: Input
            }], useCepMask: [{
                type: Input
            }], onlyNumbers: [{
                type: Input
            }], onlyNumbersAndDecimals: [{
                type: Input
            }], validateInput: [{
                type: Input
            }], labelFontWeight: [{
                type: Input
            }], permissions: [{
                type: Input
            }], useMoneyMask: [{
                type: Input
            }], currencyCode: [{
                type: Input
            }], displayCurrencySymbol: [{
                type: Input
            }], prependText: [{
                type: Input
            }], buttonText: [{
                type: Input
            }], useLatitudeMask: [{
                type: Input
            }], useLongitudeMask: [{
                type: Input
            }], inputEvent: [{
                type: Output
            }], changeEvent: [{
                type: Output
            }], focusEvent: [{
                type: Output
            }], blurEvent: [{
                type: Output
            }], keyupEvent: [{
                type: Output
            }], keydownEvent: [{
                type: Output
            }], keypressEvent: [{
                type: Output
            }], buttonClick: [{
                type: Output
            }] } });

class JsonEditorComponent {
    constructor() {
        this.readonly = false;
        this.jsonChange = new EventEmitter();
        this.isJsonValid = new EventEmitter();
        this.jsonText = '';
        this.isValidJson = true;
        this.copyFeedback = '';
        this.showExample = false;
        this.exampleJson = {
            nome: "João",
            idade: 30,
            ativo: true,
            notas: [9.5, 8.3, 7.8],
            endereco: {
                cidade: "São Paulo",
                estado: "SP"
            },
            email: null
        };
    }
    get formattedExample() {
        return JSON.stringify(this.exampleJson, null, 2);
    }
    toggleExample() {
        this.showExample = !this.showExample;
    }
    ngOnInit() {
        this.jsonText = this.formatJson(this.data);
        this.isValidJson = this.checkValidJson(this.jsonText);
    }
    ngOnChanges(changes) {
        if (changes['data'] && !changes['data'].firstChange) {
            this.jsonText = this.formatJson(this.data);
            this.isValidJson = this.checkValidJson(this.jsonText);
            this.isJsonValid.emit(this.isValidJson);
        }
    }
    onTextChange(text) {
        this.jsonText = text;
        this.isValidJson = this.checkValidJson(text);
        if (this.isValidJson) {
            try {
                const parsed = JSON.parse(text);
                this.jsonChange.emit(parsed);
            }
            catch {
                this.isValidJson = false;
            }
        }
        if (text.trim().length === 0) {
            this.jsonChange.emit('');
        }
        this.isJsonValid.emit(this.isValidJson);
    }
    format() {
        try {
            const fixed = this.tryFixInvalidJson(this.jsonText);
            const parsed = JSON.parse(fixed);
            this.jsonText = JSON.stringify(parsed, null, 2);
            this.isValidJson = true;
            this.jsonChange.emit(parsed);
        }
        catch {
            this.isValidJson = false;
        }
        this.isJsonValid.emit(this.isValidJson);
    }
    copyToClipboard() {
        navigator.clipboard.writeText(this.jsonText).then(() => {
            this.copyFeedback = 'Copiado!';
            setTimeout(() => this.copyFeedback = '', 2000);
        });
    }
    checkValidJson(text) {
        try {
            JSON.parse(text);
            return true;
        }
        catch {
            return false;
        }
    }
    formatJson(data) {
        try {
            return JSON.stringify(data, null, 2);
        }
        catch {
            return '';
        }
    }
    tryFixInvalidJson(text) {
        let fixed = text;
        // 1) Remove comentários de linha e de bloco
        fixed = fixed.replace(/\/\/.*|\/\*[\s\S]*?\*\//g, '');
        // 2) Aspas simples → duplas em strings
        fixed = fixed.replace(/'([^']*)'/g, '"$1"');
        // 3) Remove trailing commas antes de ] ou }
        fixed = fixed.replace(/,\s*(?=[}\]])/g, '');
        // 4) Chaves não-aspadas → entre aspas
        fixed = fixed.replace(/([{,]\s*)([A-Za-z0-9_\$]+)\s*:/g, '$1"$2":');
        // 5) Valores string soltos → entre aspas duplas
        fixed = fixed.replace(/:\s*([^\s"'`\{\}\[\],][^,\}\]]*)(?=[,\}\]])/g, (_match, p1) => {
            const v = p1.trim();
            // se for número ou literal JSON, deixa como está
            if (/^[-+]?\d+(\.\d+)?([eE][-+]?\d+)?$/.test(v) ||
                /^(true|false|null)$/.test(v.toLowerCase())) {
                return `: ${v}`;
            }
            // escapa eventuais aspas internas e envolve em duplas
            const escaped = v.replace(/"/g, '\\"');
            return `: "${escaped}"`;
        });
        return fixed;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: JsonEditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: JsonEditorComponent, selector: "argenta-json-editor", inputs: { data: "data", readonly: "readonly" }, outputs: { jsonChange: "jsonChange", isJsonValid: "isJsonValid" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"json-editor-container\">\n  <div\n    class=\"status-indicator\"\n    *ngIf=\"!readonly\"\n    [ngClass]=\"{ valid: isValidJson, invalid: !isValidJson }\"\n  >\n    {{ isValidJson ? \"\u2705\" : \"\u274C\" }}\n  </div>\n\n  <div class=\"actions\" *ngIf=\"!readonly\">\n    <button (click)=\"format()\">\n      <i-lucide name=\"file-json\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n    <button (click)=\"copyToClipboard()\">\n      <i-lucide name=\"copy\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n    <button class=\"info\" (click)=\"toggleExample()\">\n      <i-lucide name=\"info\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n\n    <span class=\"feedback\" *ngIf=\"copyFeedback\">{{ copyFeedback }}</span>\n  </div>\n\n  <div class=\"example-box\" *ngIf=\"showExample\">\n    <pre>{{ formattedExample }}</pre>\n  </div>\n\n  <textarea\n    [readonly]=\"readonly\"\n    [ngClass]=\"{ invalid: !isValidJson }\"\n    [(ngModel)]=\"jsonText\"\n    (ngModelChange)=\"onTextChange($event)\"\n    placeholder=\"Digite ou cole seu JSON aqui...\"\n  ></textarea>\n</div>\n", styles: [".json-editor-container{position:relative;width:100%}.json-editor-container textarea{width:100%;height:300px;padding:10px 12px;font-family:monospace;font-size:14px;border:1px solid #ccc;border-radius:8px;resize:vertical;box-sizing:border-box}.json-editor-container textarea.invalid{border-color:#ef4444}.json-editor-container .actions{display:flex;gap:8px;margin-bottom:10px}.json-editor-container .actions button{padding:6px 12px;border:none;border-radius:6px;background-color:var(--primary-color);color:#fff;cursor:pointer}.json-editor-container .actions .feedback{font-size:12px;color:#10b981;margin-left:8px;align-self:center}.json-editor-container .status-indicator{position:absolute;top:10px;right:12px;height:32px;width:32px;border-radius:6px;text-align:center;line-height:32px;font-size:16px;background-color:#f3f4f6;box-shadow:0 0 0 1px #ccc}.json-editor-container .status-indicator.valid{color:#10b981}.json-editor-container .status-indicator.invalid{color:#ef4444}.json-editor-container .info-button{position:absolute;top:10px;left:12px;height:32px;width:32px;border-radius:6px;background-color:#f3f4f6;text-align:center;line-height:32px;font-size:18px;cursor:pointer;box-shadow:0 0 0 1px #ccc}.json-editor-container .info-button:hover{background-color:#e5e7eb}.json-editor-container .example-box{background-color:#f9fafb;border:1px solid #ccc;border-radius:8px;padding:10px;margin-bottom:10px;font-family:monospace;font-size:14px;white-space:pre;overflow-x:auto}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: JsonEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-json-editor', template: "<div class=\"json-editor-container\">\n  <div\n    class=\"status-indicator\"\n    *ngIf=\"!readonly\"\n    [ngClass]=\"{ valid: isValidJson, invalid: !isValidJson }\"\n  >\n    {{ isValidJson ? \"\u2705\" : \"\u274C\" }}\n  </div>\n\n  <div class=\"actions\" *ngIf=\"!readonly\">\n    <button (click)=\"format()\">\n      <i-lucide name=\"file-json\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n    <button (click)=\"copyToClipboard()\">\n      <i-lucide name=\"copy\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n    <button class=\"info\" (click)=\"toggleExample()\">\n      <i-lucide name=\"info\" [size]=\"20\" color=\"white\"></i-lucide>\n    </button>\n\n    <span class=\"feedback\" *ngIf=\"copyFeedback\">{{ copyFeedback }}</span>\n  </div>\n\n  <div class=\"example-box\" *ngIf=\"showExample\">\n    <pre>{{ formattedExample }}</pre>\n  </div>\n\n  <textarea\n    [readonly]=\"readonly\"\n    [ngClass]=\"{ invalid: !isValidJson }\"\n    [(ngModel)]=\"jsonText\"\n    (ngModelChange)=\"onTextChange($event)\"\n    placeholder=\"Digite ou cole seu JSON aqui...\"\n  ></textarea>\n</div>\n", styles: [".json-editor-container{position:relative;width:100%}.json-editor-container textarea{width:100%;height:300px;padding:10px 12px;font-family:monospace;font-size:14px;border:1px solid #ccc;border-radius:8px;resize:vertical;box-sizing:border-box}.json-editor-container textarea.invalid{border-color:#ef4444}.json-editor-container .actions{display:flex;gap:8px;margin-bottom:10px}.json-editor-container .actions button{padding:6px 12px;border:none;border-radius:6px;background-color:var(--primary-color);color:#fff;cursor:pointer}.json-editor-container .actions .feedback{font-size:12px;color:#10b981;margin-left:8px;align-self:center}.json-editor-container .status-indicator{position:absolute;top:10px;right:12px;height:32px;width:32px;border-radius:6px;text-align:center;line-height:32px;font-size:16px;background-color:#f3f4f6;box-shadow:0 0 0 1px #ccc}.json-editor-container .status-indicator.valid{color:#10b981}.json-editor-container .status-indicator.invalid{color:#ef4444}.json-editor-container .info-button{position:absolute;top:10px;left:12px;height:32px;width:32px;border-radius:6px;background-color:#f3f4f6;text-align:center;line-height:32px;font-size:18px;cursor:pointer;box-shadow:0 0 0 1px #ccc}.json-editor-container .info-button:hover{background-color:#e5e7eb}.json-editor-container .example-box{background-color:#f9fafb;border:1px solid #ccc;border-radius:8px;padding:10px;margin-bottom:10px;font-family:monospace;font-size:14px;white-space:pre;overflow-x:auto}\n"] }]
        }], propDecorators: { data: [{
                type: Input
            }], readonly: [{
                type: Input
            }], jsonChange: [{
                type: Output
            }], isJsonValid: [{
                type: Output
            }] } });

class JsonViewerComponent {
    constructor() {
        this.isRoot = true;
        this.allExpanded = true;
        this.expandedMap = new Map();
    }
    toggleAll() {
        this.allExpanded = !this.allExpanded;
        this.expandedMap.clear();
    }
    toggleExpand(key) {
        const currentState = this.isExpanded(key);
        this.expandedMap.set(key, !currentState);
    }
    isObject(val) {
        return val !== null && typeof val === 'object';
    }
    objectKeys(obj) {
        return Object.keys(obj);
    }
    isExpanded(key) {
        return this.expandedMap.has(key) ? this.expandedMap.get(key) : this.allExpanded;
    }
    copyJson() {
        const jsonString = JSON.stringify(this.jsonData, null, 2);
        navigator.clipboard.writeText(jsonString).then(() => {
            alert('JSON copiado com sucesso!');
        }).catch(err => {
            console.error('Error copying JSON to clipboard:', err);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: JsonViewerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: JsonViewerComponent, selector: "argenta-json-viewer", inputs: { jsonData: "jsonData", isRoot: "isRoot", copyLabel: "copyLabel", showLabel: "showLabel", hideLabel: "hideLabel" }, ngImport: i0, template: "<div class=\"json-viewer-box\">\n  <div class=\"toolbar\">\n    <button\n      *ngIf=\"isRoot\"\n      class=\"action-button copy-button\"\n      (click)=\"copyJson()\"\n    >\n      {{ copyLabel }}\n    </button>\n    <button\n      *ngIf=\"isRoot\"\n      class=\"action-button toggle-button\"\n      (click)=\"toggleAll()\"\n    >\n      {{ allExpanded ? \"\u25BC \" + hideLabel : \"\u25BA \" + showLabel }}\n    </button>\n  </div>\n\n  <div class=\"json-content\">\n    <div *ngIf=\"isObject(jsonData)\">\n      <div class=\"json-pair\" *ngFor=\"let key of objectKeys(jsonData)\">\n        <span class=\"key\">\n          {{ key }}:\n          <button class=\"minimal-toggle-button\" (click)=\"toggleExpand(key)\">\n            {{ isExpanded(key) ? \"\u25BC\" : \"\u25BA\" }}\n          </button>\n        </span>\n\n        <div class=\"nested-json\" *ngIf=\"isExpanded(key)\">\n          <argenta-json-viewer\n            [jsonData]=\"jsonData[key]\"\n            [isRoot]=\"false\"\n          ></argenta-json-viewer>\n        </div>\n        <span *ngIf=\"!isExpanded(key) && isObject(jsonData[key])\">[...]</span>\n      </div>\n    </div>\n    <span *ngIf=\"!isObject(jsonData)\">\n      {{ jsonData }}\n    </span>\n  </div>\n</div>\n", styles: [".json-viewer-box{border:1px solid #ccc;padding:10px;border-radius:8px;font-family:Arial,sans-serif;background-color:#f9f9f9}.json-viewer-box .toolbar{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px;padding-bottom:5px;border-bottom:1px solid #ddd}.json-viewer-box .action-button{background-color:#4caf50;color:#fff;border:none;padding:8px 16px;font-size:14px;border-radius:4px;cursor:pointer;transition:background-color .3s ease}.json-viewer-box .action-button:hover{background-color:#45a049}.json-viewer-box .minimal-toggle-button{background:none;border:none;color:#007bff;cursor:pointer;font-size:12px;margin-left:5px;padding:0;line-height:1}.json-viewer-box .minimal-toggle-button:hover{color:#0056b3}.json-viewer-box .json-content{margin-top:10px}.json-viewer-box .json-content .json-pair{margin-bottom:5px}.json-viewer-box .json-content .json-pair .key{font-weight:700;margin-right:5px;display:flex;align-items:center}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: JsonViewerComponent, selector: "argenta-json-viewer", inputs: ["jsonData", "isRoot", "copyLabel", "showLabel", "hideLabel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: JsonViewerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-json-viewer', template: "<div class=\"json-viewer-box\">\n  <div class=\"toolbar\">\n    <button\n      *ngIf=\"isRoot\"\n      class=\"action-button copy-button\"\n      (click)=\"copyJson()\"\n    >\n      {{ copyLabel }}\n    </button>\n    <button\n      *ngIf=\"isRoot\"\n      class=\"action-button toggle-button\"\n      (click)=\"toggleAll()\"\n    >\n      {{ allExpanded ? \"\u25BC \" + hideLabel : \"\u25BA \" + showLabel }}\n    </button>\n  </div>\n\n  <div class=\"json-content\">\n    <div *ngIf=\"isObject(jsonData)\">\n      <div class=\"json-pair\" *ngFor=\"let key of objectKeys(jsonData)\">\n        <span class=\"key\">\n          {{ key }}:\n          <button class=\"minimal-toggle-button\" (click)=\"toggleExpand(key)\">\n            {{ isExpanded(key) ? \"\u25BC\" : \"\u25BA\" }}\n          </button>\n        </span>\n\n        <div class=\"nested-json\" *ngIf=\"isExpanded(key)\">\n          <argenta-json-viewer\n            [jsonData]=\"jsonData[key]\"\n            [isRoot]=\"false\"\n          ></argenta-json-viewer>\n        </div>\n        <span *ngIf=\"!isExpanded(key) && isObject(jsonData[key])\">[...]</span>\n      </div>\n    </div>\n    <span *ngIf=\"!isObject(jsonData)\">\n      {{ jsonData }}\n    </span>\n  </div>\n</div>\n", styles: [".json-viewer-box{border:1px solid #ccc;padding:10px;border-radius:8px;font-family:Arial,sans-serif;background-color:#f9f9f9}.json-viewer-box .toolbar{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px;padding-bottom:5px;border-bottom:1px solid #ddd}.json-viewer-box .action-button{background-color:#4caf50;color:#fff;border:none;padding:8px 16px;font-size:14px;border-radius:4px;cursor:pointer;transition:background-color .3s ease}.json-viewer-box .action-button:hover{background-color:#45a049}.json-viewer-box .minimal-toggle-button{background:none;border:none;color:#007bff;cursor:pointer;font-size:12px;margin-left:5px;padding:0;line-height:1}.json-viewer-box .minimal-toggle-button:hover{color:#0056b3}.json-viewer-box .json-content{margin-top:10px}.json-viewer-box .json-content .json-pair{margin-bottom:5px}.json-viewer-box .json-content .json-pair .key{font-weight:700;margin-right:5px;display:flex;align-items:center}\n"] }]
        }], propDecorators: { jsonData: [{
                type: Input
            }], isRoot: [{
                type: Input
            }], copyLabel: [{
                type: Input
            }], showLabel: [{
                type: Input
            }], hideLabel: [{
                type: Input
            }] } });

class ModalComponent {
    constructor(activeModal) {
        this.activeModal = activeModal;
        this.onButtonClick = new EventEmitter(); // Novo evento
    }
    ngOnInit() {
        const componentRef = this.dynamicComponent.createComponent(this.component);
        const instance = componentRef.instance;
        if (this.componentInputs) {
            Object.keys(this.componentInputs).forEach(inputName => {
                instance[inputName] = this.componentInputs[inputName];
            });
        }
    }
    closeModal() {
        this.activeModal.close();
    }
    buttonClicked() {
        this.onButtonClick.emit(); // Emitindo o evento
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ModalComponent, deps: [{ token: i1$1.NgbActiveModal }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ModalComponent, selector: "argenta-modal", inputs: { title: "title", component: "component", componentInputs: "componentInputs", closeButtonLabel: "closeButtonLabel", buttonLabel: "buttonLabel" }, outputs: { onButtonClick: "onButtonClick" }, viewQueries: [{ propertyName: "dynamicComponent", first: true, predicate: ["dynamicComponent"], descendants: true, read: ViewContainerRef, static: true }], ngImport: i0, template: "<div class=\"modal-header custom-modal-header\">\n  <h4 class=\"modal-title\">{{ title }}</h4>\n  <p class=\"float-right close-modal\" (click)=\"closeModal()\">X</p>\n</div>\n<div class=\"modal-body\">\n  <ng-container #dynamicComponent></ng-container>\n</div>\n<div class=\"modal-footer\">\n  <button class=\"btn btn-secondary\" (click)=\"closeModal()\">\n    {{ closeButtonLabel }}\n  </button>\n  <button *ngIf=\"buttonLabel\" class=\"btn btn-custom\" (click)=\"buttonClicked()\">\n    {{ buttonLabel }}\n  </button>\n</div>\n", styles: [".modal-content{border-radius:15px;overflow:hidden}.custom-modal-header{background-color:var(--primary-color);color:var(--text-color);border-bottom:none;font-family:var(--font-family);display:flex;justify-content:space-between;align-items:center;padding:1rem}.modal-title{color:var(--text-color);font-size:20px}.close-modal{margin:0;cursor:pointer;font-size:1.5rem;color:var(--text-color)}.close-modal:hover{color:#ccc}.modal-footer{border-top:none}.btn-custom{background-color:var(--primary-color);color:var(--text-color);border-bottom:none}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-modal', template: "<div class=\"modal-header custom-modal-header\">\n  <h4 class=\"modal-title\">{{ title }}</h4>\n  <p class=\"float-right close-modal\" (click)=\"closeModal()\">X</p>\n</div>\n<div class=\"modal-body\">\n  <ng-container #dynamicComponent></ng-container>\n</div>\n<div class=\"modal-footer\">\n  <button class=\"btn btn-secondary\" (click)=\"closeModal()\">\n    {{ closeButtonLabel }}\n  </button>\n  <button *ngIf=\"buttonLabel\" class=\"btn btn-custom\" (click)=\"buttonClicked()\">\n    {{ buttonLabel }}\n  </button>\n</div>\n", styles: [".modal-content{border-radius:15px;overflow:hidden}.custom-modal-header{background-color:var(--primary-color);color:var(--text-color);border-bottom:none;font-family:var(--font-family);display:flex;justify-content:space-between;align-items:center;padding:1rem}.modal-title{color:var(--text-color);font-size:20px}.close-modal{margin:0;cursor:pointer;font-size:1.5rem;color:var(--text-color)}.close-modal:hover{color:#ccc}.modal-footer{border-top:none}.btn-custom{background-color:var(--primary-color);color:var(--text-color);border-bottom:none}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$1.NgbActiveModal }]; }, propDecorators: { title: [{
                type: Input
            }], component: [{
                type: Input
            }], componentInputs: [{
                type: Input
            }], closeButtonLabel: [{
                type: Input
            }], buttonLabel: [{
                type: Input
            }], onButtonClick: [{
                type: Output
            }], dynamicComponent: [{
                type: ViewChild,
                args: ['dynamicComponent', { read: ViewContainerRef, static: true }]
            }] } });

class MultiSelectComponent {
    onClickOutside(event) {
        const target = event.target;
        if (!target.closest(".custom-select-container")) {
            this.closeDropdown();
        }
    }
    constructor(authService, http, cdr) {
        this.authService = authService;
        this.http = http;
        this.cdr = cdr;
        this.label = "Multi Select";
        this.data = [];
        this.placeholder = "";
        this.id = "multiSelectId";
        this.bindLabel = "";
        this.bindValue = "";
        this.closeOnSelect = false;
        this.searchUrl = "";
        this.multiple = true;
        this.searchParams = {};
        this.keyupEvent = new EventEmitter();
        this.lastSearchTerm = "";
        this.backupData = [];
        this.allItems = [];
        this.items = of([]);
        this.filteredItems = of([]);
        this.searchTerms = new Subject();
        this.isOpen = false;
        this.onChangeCallback = () => { };
        this.onTouchedCallback = () => { };
        this.isCourseEntered = false;
        this.compareFn = (item1, item2) => {
            return item1 && item2
                ? item1[this.bindValue] === item2[this.bindValue]
                : item1 === item2;
        };
    }
    ngOnInit() {
        this.filteredItems = this.searchTerms.pipe(debounceTime(700), // Reduz chamadas repetitivas
        distinctUntilChanged(), // Ignora termos repetidos consecutivos
        switchMap((term) => {
            // Sempre busca no back-end
            return this.search(term).pipe(tap((fetchedItems) => {
                this.updateData(fetchedItems);
            }), map((fetchedItems) => this.filterOutSelected(fetchedItems)));
        }));
        this.filteredItems.subscribe({
            next: (items) => { },
            error: (err) => console.error("Erro ao buscar no back-end:", err),
        });
        this.fetchInitialData().subscribe((data) => {
            this.updateData(data);
        });
    }
    onInputChange(event) {
        const input = event.target.value.trim();
        this.searchTerms.next(input);
        if (input === "") {
            this.fetchInitialData().subscribe((data) => {
                this.allItems = data;
                this.filteredItems = of(this.filterOutSelected(this.allItems));
            });
        }
    }
    search(term) {
        return this.http.get(`${this.searchUrl}`, { params: { term } }).pipe(map((response) => {
            const transformedItems = response.map((item) => ({
                [this.bindValue]: item[this.bindValue],
                [this.bindLabel]: item[this.bindLabel],
            }));
            this.allItems = transformedItems;
            this.filteredItems = of(this.filterOutSelected(this.allItems));
            this.cdr.markForCheck(); // Notifica o Angular sobre a alteração
            return transformedItems;
        }), catchError((error) => {
            console.error("Erro ao buscar no back-end:", error);
            this.filteredItems = of([]);
            return of([]);
        }));
    }
    fetchInitialData() {
        return this.http.get(this.searchUrl).pipe(map((response) => {
            const transformedItems = response.map((item) => ({
                [this.bindValue]: item[this.bindValue],
                [this.bindLabel]: item[this.bindLabel],
            }));
            this.allItems = transformedItems;
            return this.allItems;
        }), catchError((error) => {
            console.error("Erro ao carregar dados iniciais:", error);
            return of([]);
        }));
    }
    ngOnChanges(changes) {
        if (changes["selected"] && !changes["selected"].isFirstChange()) {
            this.addSelectedItemsToData();
        }
    }
    updateData(newData) {
        newData.forEach((item) => {
            const existsInList = this.allItems.some((listItem) => this.compareFn(listItem, item));
            if (!existsInList) {
                this.allItems = [...this.allItems, item]; // Cria uma nova referência
            }
        });
        this.filteredItems = of([...this.allItems]); // Garante nova referência
        this.cdr.markForCheck(); // Notifica o Angular sobre mudanças
    }
    addSelectedItemsToData() {
        if (this.selected) {
            const selectedItems = this.multiple ? this.selected : [this.selected];
            selectedItems.forEach((item) => {
                const existsInList = this.allItems.some((listItem) => this.compareFn(listItem, item));
                if (!existsInList) {
                    const newItem = {
                        [this.bindValue]: item[this.bindValue] || item,
                        [this.bindLabel]: item[this.bindLabel] || item,
                    };
                    this.data.push(newItem);
                    this.allItems.push(newItem);
                }
            });
            this.items = of(this.allItems);
        }
    }
    onFocus() {
        this.isCourseEntered = true;
    }
    onBlur() {
        this.isCourseEntered = false;
    }
    onKeyUp(event) {
        this.keyupEvent.emit(event);
    }
    onSelectedChange(event) {
        const previousSelected = this.selected;
        if (this.multiple) {
            this.selected = event;
        }
        else {
            this.selected = event ? event : null;
        }
        this.onChangeCallback(this.selected);
        if (previousSelected && Array.isArray(previousSelected)) {
            const removedItems = previousSelected.filter((item) => !event.includes(item));
            removedItems.forEach((item) => {
                const existsInAllItems = this.allItems.some((listItem) => this.compareFn(listItem, item));
                if (!existsInAllItems) {
                    this.allItems.push(item);
                }
            });
            this.items = of(this.allItems);
        }
    }
    writeValue(value) {
        if (this.multiple) {
            this.selected = value || [];
        }
        else {
            this.selected = value || null;
        }
        this.addSelectedItemsToData();
        this.cdr.detectChanges();
    }
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    setDisabledState(isDisabled) { }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error("Permission error:", error.message);
            }
            else {
                console.error("Unknown error occurred during permission check");
            }
            return true;
        }
    }
    toggleDropdown() {
        this.isOpen = !this.isOpen;
    }
    closeDropdown() {
        this.isOpen = false;
    }
    isSelected(item) {
        if (this.multiple) {
            return this.selected?.some((selectedItem) => this.compareFn(selectedItem, item));
        }
        else {
            return this.compareFn(this.selected, item);
        }
    }
    selectItem(item, event) {
        event.stopPropagation();
        if (!this.isSelected(item)) {
            if (this.multiple) {
                this.selected.push(item);
            }
            else {
                this.selected = [item];
            }
        }
        if (this.multiple) {
            this.allItems = this.allItems.filter((listItem) => !this.compareFn(listItem, item));
        }
        this.filteredItems = of(this.filterOutSelected(this.allItems));
        this.onSelectedChange(this.selected);
        if (this.closeOnSelect) {
            this.closeDropdown();
        }
    }
    filterByTerm(term) {
        return this.allItems.filter((item) => item[this.bindLabel]?.toLowerCase().includes(term.toLowerCase()));
    }
    filterOutSelected(items) {
        if (!this.multiple) {
            return items;
        }
        return items.filter((item) => !this.selected.some((selectedItem) => this.compareFn(selectedItem, item)));
    }
    removeSelectedItem(item, event) {
        event.stopPropagation();
        this.selected = this.selected.filter((selectedItem) => !this.compareFn(selectedItem, item));
        const existsInAllItems = this.allItems.some((listItem) => this.compareFn(listItem, item));
        if (!existsInAllItems) {
            this.allItems.push(item);
        }
        this.filteredItems = of(this.filterByTerm(this.lastSearchTerm || ""));
        this.onSelectedChange(this.selected);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MultiSelectComponent, deps: [{ token: AuthService }, { token: i1$2.HttpClient }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MultiSelectComponent, selector: "argenta-custom-multi-select", inputs: { label: "label", data: "data", placeholder: "placeholder", selected: "selected", id: "id", bindLabel: "bindLabel", bindValue: "bindValue", permissions: "permissions", closeOnSelect: "closeOnSelect", searchUrl: "searchUrl", multiple: "multiple", searchParams: "searchParams" }, outputs: { keyupEvent: "keyupEvent" }, host: { listeners: { "document:click": "onClickOutside($event)" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => MultiSelectComponent),
                multi: true,
            },
        ], usesOnChanges: true, ngImport: i0, template: "<div *ngIf=\"hasPermission()\" class=\"form-group\">\n  <label [for]=\"id\" class=\"form-label\" style=\"margin-top: 1rem\">\n    {{ label }}\n  </label>\n  <div class=\"custom-select-container\" tabindex=\"0\">\n    <!-- Input com itens selecionados -->\n    <div class=\"custom-input\">\n      <span class=\"selected-item\" *ngFor=\"let item of selected\">\n        {{ item[bindLabel] }}\n        <button\n          class=\"remove-item-btn\"\n          (click)=\"removeSelectedItem(item, $event)\"\n        >\n          \u00D7\n        </button>\n      </span>\n      <input\n        type=\"text\"\n        class=\"input-field\"\n        [id]=\"id\"\n        [placeholder]=\"placeholder\"\n        (focus)=\"toggleDropdown()\"\n        (keyup)=\"onKeyUp($event)\"\n        (input)=\"onInputChange($event)\"\n      />\n      <!-- \u00CDcone flutuante -->\n      <lucide-icon\n        [name]=\"isOpen ? 'align-justify' : 'chevron-down'\"\n        class=\"dropdown-icon\"\n      ></lucide-icon>\n    </div>\n\n    <!-- Dropdown suspenso -->\n    <div *ngIf=\"isOpen\" class=\"dropdown\">\n      <div\n        *ngFor=\"let item of filteredItems | async\"\n        class=\"dropdown-item\"\n        [class.selected]=\"isSelected(item)\"\n        (click)=\"selectItem(item, $event)\"\n      >\n        {{ item[bindLabel] }}\n      </div>\n      <div *ngIf=\"(filteredItems | async)?.length === 0\" class=\"empty-dropdown\">\n        Nenhum item dispon\u00EDvel\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.custom-select-container{position:relative;display:flex;flex-direction:column;border:1px solid #ccc;border-radius:4px;padding:.5rem;background-color:#fff;color:#333;font-family:var(--font-family)}.custom-select-container .custom-input{display:flex;flex-wrap:wrap;align-items:center;gap:.5rem;width:100%;min-height:20px;cursor:text;background:none;border:none;outline:none;position:relative}.custom-select-container .custom-input .selected-item{display:flex;align-items:center;background-color:#f8f8f8;color:#333;border:1px solid #e0e0e0;border-radius:4px;padding:.15rem .4rem;font-size:.85rem}.custom-select-container .custom-input .selected-item .remove-item-btn{display:flex;align-items:center;justify-content:center;background-color:#c7c7c7;border:none;color:#4b4b4b;font-weight:700;cursor:pointer;font-size:.6rem;line-height:1;border-radius:50%;width:14px;height:14px;margin-left:.3rem;padding:0;position:relative}.custom-select-container .custom-input .selected-item .remove-item-btn span{transition:transform .2s ease,color .2s ease}.custom-select-container .custom-input .selected-item .remove-item-btn:hover{background-color:#8f8a8b;color:#fff}.custom-select-container .custom-input .selected-item .remove-item-btn:hover span{transform:scale(1.2);color:#fff}.custom-select-container .custom-input .selected-item .remove-item-btn:active{background-color:#767072}.custom-select-container .custom-input .input-field{flex:1;border:none;outline:none;font-size:.85rem;padding:.1rem 3rem .1rem .2rem;background:transparent;min-width:80px}.custom-select-container .custom-input .dropdown-icon{position:absolute;right:.1rem;top:50%;transform:translateY(-50%);font-size:1.2rem;color:#888;pointer-events:none}.dropdown{position:absolute;top:100%;left:0;right:0;max-height:200px;overflow-y:auto;background-color:#fff;border:1px solid #ccc;border-radius:4px;z-index:1000}.dropdown::-webkit-scrollbar{width:8px}.dropdown::-webkit-scrollbar-thumb{background-color:#ccc;border-radius:4px}.dropdown::-webkit-scrollbar-thumb:hover{background-color:#aaa}.dropdown::-webkit-scrollbar-track{background-color:#f1f1f1;border-radius:4px}.dropdown .dropdown-item{padding:.5rem;cursor:pointer}.dropdown .dropdown-item:hover{background-color:#f1f1f1}.dropdown .dropdown-item.selected{font-weight:700;background-color:#e9e9e9}.empty-dropdown{padding:1rem;text-align:center;color:#999;font-size:.9rem}@media (max-width: 768px){.custom-input .input-field{padding-right:4rem}.custom-input .dropdown-icon{right:.75rem}}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MultiSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-custom-multi-select", encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => MultiSelectComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.Default, template: "<div *ngIf=\"hasPermission()\" class=\"form-group\">\n  <label [for]=\"id\" class=\"form-label\" style=\"margin-top: 1rem\">\n    {{ label }}\n  </label>\n  <div class=\"custom-select-container\" tabindex=\"0\">\n    <!-- Input com itens selecionados -->\n    <div class=\"custom-input\">\n      <span class=\"selected-item\" *ngFor=\"let item of selected\">\n        {{ item[bindLabel] }}\n        <button\n          class=\"remove-item-btn\"\n          (click)=\"removeSelectedItem(item, $event)\"\n        >\n          \u00D7\n        </button>\n      </span>\n      <input\n        type=\"text\"\n        class=\"input-field\"\n        [id]=\"id\"\n        [placeholder]=\"placeholder\"\n        (focus)=\"toggleDropdown()\"\n        (keyup)=\"onKeyUp($event)\"\n        (input)=\"onInputChange($event)\"\n      />\n      <!-- \u00CDcone flutuante -->\n      <lucide-icon\n        [name]=\"isOpen ? 'align-justify' : 'chevron-down'\"\n        class=\"dropdown-icon\"\n      ></lucide-icon>\n    </div>\n\n    <!-- Dropdown suspenso -->\n    <div *ngIf=\"isOpen\" class=\"dropdown\">\n      <div\n        *ngFor=\"let item of filteredItems | async\"\n        class=\"dropdown-item\"\n        [class.selected]=\"isSelected(item)\"\n        (click)=\"selectItem(item, $event)\"\n      >\n        {{ item[bindLabel] }}\n      </div>\n      <div *ngIf=\"(filteredItems | async)?.length === 0\" class=\"empty-dropdown\">\n        Nenhum item dispon\u00EDvel\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.custom-select-container{position:relative;display:flex;flex-direction:column;border:1px solid #ccc;border-radius:4px;padding:.5rem;background-color:#fff;color:#333;font-family:var(--font-family)}.custom-select-container .custom-input{display:flex;flex-wrap:wrap;align-items:center;gap:.5rem;width:100%;min-height:20px;cursor:text;background:none;border:none;outline:none;position:relative}.custom-select-container .custom-input .selected-item{display:flex;align-items:center;background-color:#f8f8f8;color:#333;border:1px solid #e0e0e0;border-radius:4px;padding:.15rem .4rem;font-size:.85rem}.custom-select-container .custom-input .selected-item .remove-item-btn{display:flex;align-items:center;justify-content:center;background-color:#c7c7c7;border:none;color:#4b4b4b;font-weight:700;cursor:pointer;font-size:.6rem;line-height:1;border-radius:50%;width:14px;height:14px;margin-left:.3rem;padding:0;position:relative}.custom-select-container .custom-input .selected-item .remove-item-btn span{transition:transform .2s ease,color .2s ease}.custom-select-container .custom-input .selected-item .remove-item-btn:hover{background-color:#8f8a8b;color:#fff}.custom-select-container .custom-input .selected-item .remove-item-btn:hover span{transform:scale(1.2);color:#fff}.custom-select-container .custom-input .selected-item .remove-item-btn:active{background-color:#767072}.custom-select-container .custom-input .input-field{flex:1;border:none;outline:none;font-size:.85rem;padding:.1rem 3rem .1rem .2rem;background:transparent;min-width:80px}.custom-select-container .custom-input .dropdown-icon{position:absolute;right:.1rem;top:50%;transform:translateY(-50%);font-size:1.2rem;color:#888;pointer-events:none}.dropdown{position:absolute;top:100%;left:0;right:0;max-height:200px;overflow-y:auto;background-color:#fff;border:1px solid #ccc;border-radius:4px;z-index:1000}.dropdown::-webkit-scrollbar{width:8px}.dropdown::-webkit-scrollbar-thumb{background-color:#ccc;border-radius:4px}.dropdown::-webkit-scrollbar-thumb:hover{background-color:#aaa}.dropdown::-webkit-scrollbar-track{background-color:#f1f1f1;border-radius:4px}.dropdown .dropdown-item{padding:.5rem;cursor:pointer}.dropdown .dropdown-item:hover{background-color:#f1f1f1}.dropdown .dropdown-item.selected{font-weight:700;background-color:#e9e9e9}.empty-dropdown{padding:1rem;text-align:center;color:#999;font-size:.9rem}@media (max-width: 768px){.custom-input .input-field{padding-right:4rem}.custom-input .dropdown-icon{right:.75rem}}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i1$2.HttpClient }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { onClickOutside: [{
                type: HostListener,
                args: ["document:click", ["$event"]]
            }], label: [{
                type: Input
            }], data: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], selected: [{
                type: Input
            }], id: [{
                type: Input
            }], bindLabel: [{
                type: Input
            }], bindValue: [{
                type: Input
            }], permissions: [{
                type: Input
            }], closeOnSelect: [{
                type: Input
            }], searchUrl: [{
                type: Input
            }], multiple: [{
                type: Input
            }], searchParams: [{
                type: Input
            }], keyupEvent: [{
                type: Output
            }] } });

class MultiSelectCategoryComponent {
    constructor() {
        // Inputs para receber dados dinâmicos de diferentes categorias
        this.unidadesOrganizacionais = [];
        this.clientes = [];
        this.empresas = [];
        this.usuarios = [];
        // Inputs para permissões específicas de cada categoria
        this.permissoesUnidades = [];
        this.permissoesClientes = [];
        this.permissoesEmpresas = [];
        this.permissoesUsuarios = [];
    }
    ngOnInit() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MultiSelectCategoryComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MultiSelectCategoryComponent, selector: "argenta-multi-select-category", inputs: { unidadesOrganizacionais: "unidadesOrganizacionais", clientes: "clientes", empresas: "empresas", usuarios: "usuarios", permissoesUnidades: "permissoesUnidades", permissoesClientes: "permissoesClientes", permissoesEmpresas: "permissoesEmpresas", permissoesUsuarios: "permissoesUsuarios" }, ngImport: i0, template: "<div class=\"multi-select-category\">\n  <div class=\"row\">\n    <!-- Primeira linha: Usu\u00E1rio e Cliente -->\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Usu\u00E1rios\"\n        [data]=\"usuarios\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesUsuarios\"\n        placeholder=\"Selecione Usu\u00E1rios\">\n      </argenta-custom-multi-select>\n    </div>\n\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Clientes\"\n        [data]=\"clientes\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesClientes\"\n        placeholder=\"Selecione Clientes\">\n      </argenta-custom-multi-select>\n    </div>\n  </div>\n\n  <div class=\"row\">\n    <!-- Segunda linha: Empresa e Unidade Organizacional -->\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Empresas\"\n        [data]=\"empresas\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesEmpresas\"\n        placeholder=\"Selecione Empresas\">\n      </argenta-custom-multi-select>\n    </div>\n\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Unidades Organizacionais\"\n        [data]=\"unidadesOrganizacionais\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesUnidades\"\n        placeholder=\"Selecione Unidades Organizacionais\">\n      </argenta-custom-multi-select>\n    </div>\n  </div>\n</div>\n", styles: [".multi-select-category{display:flex;flex-direction:column;gap:1rem}.multi-select-category .row{display:flex;gap:1rem}.multi-select-category .col{flex:1}\n"], dependencies: [{ kind: "component", type: MultiSelectComponent, selector: "argenta-custom-multi-select", inputs: ["label", "data", "placeholder", "selected", "id", "bindLabel", "bindValue", "permissions", "closeOnSelect", "searchUrl", "multiple", "searchParams"], outputs: ["keyupEvent"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MultiSelectCategoryComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-multi-select-category', template: "<div class=\"multi-select-category\">\n  <div class=\"row\">\n    <!-- Primeira linha: Usu\u00E1rio e Cliente -->\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Usu\u00E1rios\"\n        [data]=\"usuarios\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesUsuarios\"\n        placeholder=\"Selecione Usu\u00E1rios\">\n      </argenta-custom-multi-select>\n    </div>\n\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Clientes\"\n        [data]=\"clientes\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesClientes\"\n        placeholder=\"Selecione Clientes\">\n      </argenta-custom-multi-select>\n    </div>\n  </div>\n\n  <div class=\"row\">\n    <!-- Segunda linha: Empresa e Unidade Organizacional -->\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Empresas\"\n        [data]=\"empresas\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesEmpresas\"\n        placeholder=\"Selecione Empresas\">\n      </argenta-custom-multi-select>\n    </div>\n\n    <div class=\"col\">\n      <argenta-custom-multi-select\n        label=\"Unidades Organizacionais\"\n        [data]=\"unidadesOrganizacionais\"\n        bindLabel=\"nome\"\n        bindValue=\"id\"\n        [permissions]=\"permissoesUnidades\"\n        placeholder=\"Selecione Unidades Organizacionais\">\n      </argenta-custom-multi-select>\n    </div>\n  </div>\n</div>\n", styles: [".multi-select-category{display:flex;flex-direction:column;gap:1rem}.multi-select-category .row{display:flex;gap:1rem}.multi-select-category .col{flex:1}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { unidadesOrganizacionais: [{
                type: Input
            }], clientes: [{
                type: Input
            }], empresas: [{
                type: Input
            }], usuarios: [{
                type: Input
            }], permissoesUnidades: [{
                type: Input
            }], permissoesClientes: [{
                type: Input
            }], permissoesEmpresas: [{
                type: Input
            }], permissoesUsuarios: [{
                type: Input
            }] } });

function formatToBrazilianNumber(value) {
    return value.toLocaleString("pt-BR", {
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    });
}

class ArgentaPdfDataHandlerComponent {
    constructor() {
        this.data = [];
    }
    isNumericColumn(key) {
        // Se 'numericColumns' estiver definido no pdfConfig, use-o como referência
        return this.config?.numericColumns?.includes(key) ?? false;
    }
    processData(data) {
        if (!data || !this.config?.tableKeys?.length) {
            console.warn("Dados ou chaves de tabela ausentes!");
            return [];
        }
        // Identificar colunas numéricas
        const numericColumns = this.config.numericColumns || [];
        return data.map((item) => {
            const processedItem = {};
            this.config.tableKeys.forEach((key) => {
                if (numericColumns.includes(key)) {
                    const value = item[key];
                    if (typeof value === "string") {
                        // Converte o valor no formato brasileiro para número
                        processedItem[key] = parseFloat(value.replace(".", "").replace(",", "."));
                    }
                    else if (typeof value === "number") {
                        processedItem[key] = value;
                    }
                    else {
                        processedItem[key] = 0; // Valor padrão para entradas inválidas
                    }
                }
                else {
                    // Mantém o valor original para colunas não numéricas
                    processedItem[key] = item[key];
                }
            });
            return processedItem;
        });
    }
    exportToPdf() {
        if (!this.config || !this.data.length) {
            console.warn("Configuração ou dados ausentes para exportação de PDF!");
            return;
        }
        const doc = new jsPDF();
        // Configuração do título
        const titleStyle = this.styles?.titleStyle || {};
        doc.setFont(titleStyle.fontFamily || "helvetica", "normal");
        doc.setFontSize(titleStyle.fontSize || 14);
        doc.setTextColor(titleStyle.fontColor || "#000");
        doc.text(this.config.pdfTitle || "Relatório", titleStyle.align === "center" ? 105 : 10, 10, { align: titleStyle.align || "left" });
        // Processar os dados
        const processedData = this.processData(this.data);
        // Calcular totais por linha
        const calculatedData = processedData.map((row) => {
            const newRow = { ...row };
            this.config.rowCalculations?.forEach((calc) => {
                const result = calc.formula(row);
                newRow[calc.label] = isNaN(result)
                    ? "-"
                    : formatToBrazilianNumber(result); // Formata os totais por linha
            });
            return newRow;
        });
        // Calcular o total geral
        let totalRow = {};
        if (this.config.totalizer?.include) {
            this.config.totalizer.columns.forEach((column) => {
                const values = calculatedData
                    .map((item) => {
                    const value = item[column.field];
                    if (typeof value === "string") {
                        return parseFloat(value.replace(".", "").replace(",", "."));
                    }
                    return typeof value === "number" ? value : 0; // Valores inválidos tratados como 0
                })
                    .filter((value) => !isNaN(value)); // Filtra valores válidos
                const total = column.formula(values);
                totalRow[column.field] = formatToBrazilianNumber(total); // Formata o total geral
            });
        }
        // Preparar os dados para a tabela
        const tableHeaders = [...this.config.tableHeaders];
        const tableKeys = [...this.config.tableKeys];
        const tableData = calculatedData.map((item) => tableKeys.map((key) => {
            const value = item[key];
            if (typeof value === "number") {
                return formatToBrazilianNumber(value); // Formata números
            }
            return value || "-"; // Retorna o valor original
        }));
        // Adicionar a linha totalizadora ao final da tabela
        if (this.config.totalizer?.include) {
            const totalizerRow = tableKeys.map((key, index) => {
                if (index === 0) {
                    return this.config.totalizer?.columns[0].label || "-"; // Adiciona o label na primeira coluna
                }
                return totalRow[key] || "-";
            });
            tableData.push(totalizerRow);
        }
        // Configurar estilos e gerar a tabela
        const tableStyle = this.styles?.tableStyle || {};
        const headerStyle = this.styles?.headerStyle || {};
        const dataStyle = this.styles?.dataStyle || {};
        doc.autoTable({
            head: [tableHeaders],
            body: tableData,
            startY: 20,
            headStyles: {
                fontSize: headerStyle.fontSize || 12,
                textColor: headerStyle.fontColor || "#fff",
                fillColor: headerStyle.backgroundColor || "#007bff",
            },
            bodyStyles: {
                fontSize: dataStyle.fontSize || 10,
                textColor: dataStyle.fontColor || "#555",
            },
            styles: {
                fontSize: tableStyle.fontSize || 10,
                textColor: tableStyle.fontColor || "#000",
                fillColor: tableStyle.backgroundColor || "#fff",
            },
            theme: "grid",
        });
        // Salvar o PDF
        doc.save(this.config.fileName || "relatorio.pdf");
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ArgentaPdfDataHandlerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ArgentaPdfDataHandlerComponent, selector: "argenta-pdf-data-handler", inputs: { config: "config", data: "data", styles: "styles" }, ngImport: i0, template: "<div class=\"pdf-data-handler-container\">\n  <button class=\"pdf-button\" (click)=\"exportToPdf()\">\n    {{ config.buttonLabel || \"Export PDF\" }}\n  </button>\n</div>\n", styles: [".pdf-data-handler-container{display:flex;justify-content:center;align-items:center;padding:1rem}.pdf-data-handler-container .pdf-button{font-family:var(--font-family, Arial, sans-serif);font-size:16px;font-weight:600;padding:.5rem 1rem;border-radius:.25rem;color:var(--text-color, #fff);background-color:var(--primary-color);border:none;cursor:pointer;transition:background-color .3s,box-shadow .3s}.pdf-data-handler-container .pdf-button:hover{background-color:var(--secondary-color)}.pdf-data-handler-container .pdf-button:active{transform:scale(.98)}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ArgentaPdfDataHandlerComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-pdf-data-handler", template: "<div class=\"pdf-data-handler-container\">\n  <button class=\"pdf-button\" (click)=\"exportToPdf()\">\n    {{ config.buttonLabel || \"Export PDF\" }}\n  </button>\n</div>\n", styles: [".pdf-data-handler-container{display:flex;justify-content:center;align-items:center;padding:1rem}.pdf-data-handler-container .pdf-button{font-family:var(--font-family, Arial, sans-serif);font-size:16px;font-weight:600;padding:.5rem 1rem;border-radius:.25rem;color:var(--text-color, #fff);background-color:var(--primary-color);border:none;cursor:pointer;transition:background-color .3s,box-shadow .3s}.pdf-data-handler-container .pdf-button:hover{background-color:var(--secondary-color)}.pdf-data-handler-container .pdf-button:active{transform:scale(.98)}\n"] }]
        }], propDecorators: { config: [{
                type: Input
            }], data: [{
                type: Input
            }], styles: [{
                type: Input
            }] } });

class ArgentaPdfDownloadComponent {
    constructor(http) {
        this.http = http;
        this.apiEndpoint = ""; // Endpoint do back-end ou URL pública
        this.buttonText = "Baixar PDF"; // Texto do botão
        this.loadingText = "Baixando..."; // Texto durante o carregamento
        this.isLoading = false;
    }
    downloadPdf() {
        if (!this.apiEndpoint) {
            console.error("O endpoint da API não foi fornecido.");
            return;
        }
        // Verifica se a URL é pública (HTTPS ou HTTP)
        if (this.apiEndpoint.startsWith("http://") ||
            this.apiEndpoint.startsWith("https://")) {
            window.open(this.apiEndpoint, "_blank"); // Abre a URL diretamente
            return;
        }
        this.isLoading = true;
        // Requisição para obter o arquivo como blob
        this.http.get(this.apiEndpoint, { responseType: "blob" }).subscribe({
            next: (blob) => {
                const fileURL = window.URL.createObjectURL(blob);
                window.open(fileURL, "_blank"); // Abre o arquivo como blob
                this.isLoading = false;
            },
            error: (err) => {
                console.error("Erro ao baixar o PDF:", err);
                this.isLoading = false;
            },
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ArgentaPdfDownloadComponent, deps: [{ token: i1$2.HttpClient }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ArgentaPdfDownloadComponent, selector: "argenta-pdf-download", inputs: { apiEndpoint: "apiEndpoint", buttonText: "buttonText", loadingText: "loadingText" }, ngImport: i0, template: "<button (click)=\"downloadPdf()\" [disabled]=\"isLoading\">\n  <span *ngIf=\"!isLoading\">{{ buttonText }}</span>\n  <span *ngIf=\"isLoading\">{{ loadingText }}</span>\n</button>\n", styles: ["button{font-family:var(--font-family);font-size:16px;font-weight:600;padding:.5rem 1rem;border-radius:.25rem;color:var(--text-color);background-color:var(--primary-color);border:none;cursor:pointer;transition:background-color .3s ease-in-out,box-shadow .3s ease-in-out,transform .2s ease;box-shadow:0 4px 6px #0000001a}button:hover{background-color:var(--secondary-color);box-shadow:0 6px 8px #00000026}button:active{transform:scale(.96);box-shadow:0 2px 4px #0000001a}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ArgentaPdfDownloadComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-pdf-download", template: "<button (click)=\"downloadPdf()\" [disabled]=\"isLoading\">\n  <span *ngIf=\"!isLoading\">{{ buttonText }}</span>\n  <span *ngIf=\"isLoading\">{{ loadingText }}</span>\n</button>\n", styles: ["button{font-family:var(--font-family);font-size:16px;font-weight:600;padding:.5rem 1rem;border-radius:.25rem;color:var(--text-color);background-color:var(--primary-color);border:none;cursor:pointer;transition:background-color .3s ease-in-out,box-shadow .3s ease-in-out,transform .2s ease;box-shadow:0 4px 6px #0000001a}button:hover{background-color:var(--secondary-color);box-shadow:0 6px 8px #00000026}button:active{transform:scale(.96);box-shadow:0 2px 4px #0000001a}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.HttpClient }]; }, propDecorators: { apiEndpoint: [{
                type: Input
            }], buttonText: [{
                type: Input
            }], loadingText: [{
                type: Input
            }] } });

class RadioComponent {
    constructor() {
        this.name = "defaultRadio";
        this.id = "radioId";
        this.value = "default";
        this.checked = false;
        this.disabled = false;
        this.label = "Radio label";
        this.marginTop = 0;
        this.marginBottom = 0;
        this.marginLeft = 0;
        this.marginRight = 0;
        this.changeEvent = new EventEmitter();
        this.onChangeCallback = () => { };
        this.onTouchedCallback = () => { };
    }
    handleRadioChange(event) {
        const inputElement = event.target;
        this.checked = inputElement.checked;
        this.onChangeCallback(this.checked);
        this.changeEvent.emit(event);
    }
    writeValue(value) {
        this.checked = value;
    }
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RadioComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: RadioComponent, selector: "sim-app-radio", inputs: { name: "name", id: "id", value: "value", checked: "checked", disabled: "disabled", label: "label", marginTop: "marginTop", marginBottom: "marginBottom", marginLeft: "marginLeft", marginRight: "marginRight" }, outputs: { changeEvent: "changeEvent" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => RadioComponent),
                multi: true,
            },
        ], ngImport: i0, template: "<div\n  class=\"form-check\"\n  [ngStyle]=\"{\n    'margin-top': marginTop + 'rem',\n    'margin-bottom': marginBottom + 'rem',\n    'margin-left': marginLeft + 'rem',\n    'margin-right': marginRight + 'rem'\n  }\"\n>\n  <input\n    class=\"form-check-input\"\n    type=\"radio\"\n    [name]=\"name\"\n    [id]=\"id\"\n    [value]=\"value\"\n    [checked]=\"checked\"\n    (change)=\"handleRadioChange($event)\"\n    [disabled]=\"disabled\"\n  />\n  <label class=\"form-check-label\" [for]=\"id\">{{ label }}</label>\n</div>\n", styles: ["@charset \"UTF-8\";.form-check{font-family:var(--font-family);font-size:1rem}.form-check-input{font-family:var(--font-family);color:#333;font-size:1rem;margin-right:.5rem}.form-check-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RadioComponent, decorators: [{
            type: Component,
            args: [{ selector: "sim-app-radio", providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => RadioComponent),
                            multi: true,
                        },
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div\n  class=\"form-check\"\n  [ngStyle]=\"{\n    'margin-top': marginTop + 'rem',\n    'margin-bottom': marginBottom + 'rem',\n    'margin-left': marginLeft + 'rem',\n    'margin-right': marginRight + 'rem'\n  }\"\n>\n  <input\n    class=\"form-check-input\"\n    type=\"radio\"\n    [name]=\"name\"\n    [id]=\"id\"\n    [value]=\"value\"\n    [checked]=\"checked\"\n    (change)=\"handleRadioChange($event)\"\n    [disabled]=\"disabled\"\n  />\n  <label class=\"form-check-label\" [for]=\"id\">{{ label }}</label>\n</div>\n", styles: ["@charset \"UTF-8\";.form-check{font-family:var(--font-family);font-size:1rem}.form-check-input{font-family:var(--font-family);color:#333;font-size:1rem;margin-right:.5rem}.form-check-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}\n"] }]
        }], propDecorators: { name: [{
                type: Input
            }], id: [{
                type: Input
            }], value: [{
                type: Input
            }], checked: [{
                type: Input
            }], disabled: [{
                type: Input
            }], label: [{
                type: Input
            }], marginTop: [{
                type: Input
            }], marginBottom: [{
                type: Input
            }], marginLeft: [{
                type: Input
            }], marginRight: [{
                type: Input
            }], changeEvent: [{
                type: Output
            }] } });

class SearchCustomerComponent {
    constructor() {
        // Inputs
        this.placeholder = 'Search';
        this.id = '';
        this.disabled = false;
        this.readonly = false;
        this.autofocus = false;
        // Output
        this.searchTerm = new EventEmitter();
    }
    onSearch(event) {
        const inputElement = event.target;
        this.searchTerm.emit(inputElement.value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SearchCustomerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SearchCustomerComponent, selector: "argenta-search-customer", inputs: { placeholder: "placeholder", id: "id", disabled: "disabled", readonly: "readonly", autofocus: "autofocus" }, outputs: { searchTerm: "searchTerm" }, ngImport: i0, template: "<div class=\"search-container\">\n  <span class=\"search-icon\" [ngClass]=\"'search-icon-green'\">\n    <lucide-icon name=\"search\" [size]=\"16\"></lucide-icon>\n  </span>\n  <input\n    [id]=\"id\"\n    [placeholder]=\"placeholder\"\n    [disabled]=\"disabled\"\n    [readonly]=\"readonly\"\n    [autofocus]=\"autofocus\"\n    (input)=\"onSearch($event)\"\n    class=\"search-input custom-input\"\n  />\n</div>\n", styles: [".search-container{display:flex;align-items:center;border:1px solid var(--primary-color);border-radius:8px;padding:5px;background-color:#f7f9fc}.search-icon{padding:0 10px;color:#b0b0b0}.search-input{border:none;outline:none;padding:8px;flex:1;background-color:transparent;font-family:var(--font-family);color:#333;font-size:.9rem;height:35px}.search-input::placeholder{color:#b0b0b0}.search-icon-green{color:var(--primary-color)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SearchCustomerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-search-customer', template: "<div class=\"search-container\">\n  <span class=\"search-icon\" [ngClass]=\"'search-icon-green'\">\n    <lucide-icon name=\"search\" [size]=\"16\"></lucide-icon>\n  </span>\n  <input\n    [id]=\"id\"\n    [placeholder]=\"placeholder\"\n    [disabled]=\"disabled\"\n    [readonly]=\"readonly\"\n    [autofocus]=\"autofocus\"\n    (input)=\"onSearch($event)\"\n    class=\"search-input custom-input\"\n  />\n</div>\n", styles: [".search-container{display:flex;align-items:center;border:1px solid var(--primary-color);border-radius:8px;padding:5px;background-color:#f7f9fc}.search-icon{padding:0 10px;color:#b0b0b0}.search-input{border:none;outline:none;padding:8px;flex:1;background-color:transparent;font-family:var(--font-family);color:#333;font-size:.9rem;height:35px}.search-input::placeholder{color:#b0b0b0}.search-icon-green{color:var(--primary-color)}\n"] }]
        }], propDecorators: { placeholder: [{
                type: Input
            }], id: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readonly: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], searchTerm: [{
                type: Output
            }] } });

class SearchInputComponent {
    constructor() {
        this.id = '';
        this.label = 'Search';
        this.type = 'text';
        this.placeholder = 'Type to search...';
        this.value = '';
        this.disabled = false;
        this.readonly = false;
        this.autofocus = false;
        this.maxlength = null;
        this.minlength = null;
        this.required = false;
        this.pattern = null;
        this.debounceTime = 700; // Valor padrão
        this.search = new EventEmitter();
        this.inputChange = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.blur = new EventEmitter();
        this.keyup = new EventEmitter();
        this.keydown = new EventEmitter();
        this.keypress = new EventEmitter();
        this.searchSubject = new Subject();
        this.searchSubscription = new Subscription();
        // ControlValueAccessor interface implementation
        this.onChangeFn = () => { };
        this.onTouchedFn = () => { };
    }
    ngOnInit() {
        this.searchSubscription = this.searchSubject.pipe(debounceTime(this.debounceTime)).subscribe((searchText) => {
            this.search.emit(searchText);
        });
    }
    onInput(event) {
        const inputElement = event.target;
        const value = inputElement.value;
        this.value = value;
        this.inputChange.emit(value); // Emite o valor de input imediatamente
        this.searchSubject.next(value);
        this.onChangeFn(value); // Chame onChangeFn para notificar o Angular Forms sobre a mudança
    }
    onChange(event) {
        this.change.emit(event);
    }
    onFocus(event) {
        this.focus.emit(event);
    }
    onBlur(event) {
        this.blur.emit(event);
        this.onTouchedFn(); // Chame onTouchedFn para notificar o Angular Forms sobre o blur
    }
    onKeyup(event) {
        this.keyup.emit(event);
    }
    onKeydown(event) {
        this.keydown.emit(event);
    }
    onKeypress(event) {
        this.keypress.emit(event);
    }
    ngOnDestroy() {
        this.searchSubscription.unsubscribe();
    }
    getLabelStyles() {
        return {
            fontFamily: 'Inter',
            fontSize: '16px',
            lineHeight: '19.36px',
        };
    }
    writeValue(value) {
        this.value = value;
    }
    registerOnChange(fn) {
        this.onChangeFn = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedFn = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SearchInputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SearchInputComponent, selector: "argenta-search-input", inputs: { id: "id", label: "label", type: "type", placeholder: "placeholder", value: "value", disabled: "disabled", readonly: "readonly", autofocus: "autofocus", maxlength: "maxlength", minlength: "minlength", required: "required", pattern: "pattern", debounceTime: "debounceTime" }, outputs: { search: "search", inputChange: "inputChange", change: "change", focus: "focus", blur: "blur", keyup: "keyup", keydown: "keydown", keypress: "keypress" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => SearchInputComponent),
                multi: true
            }
        ], ngImport: i0, template: "<div class=\"form-group\">\n  <label [for]=\"id\" [ngStyle]=\"getLabelStyles()\">{{ label }}</label>\n  <input [type]=\"type\"\n         class=\"form-control custom-input\"\n         [id]=\"id\"\n         [placeholder]=\"placeholder\"\n         [(ngModel)]=\"value\"\n         (input)=\"onInput($event)\"\n         (change)=\"onChange($event)\"\n         (focus)=\"onFocus($event)\"\n         (blur)=\"onBlur($event)\"\n         (keyup)=\"onKeyup($event)\"\n         (keydown)=\"onKeydown($event)\"\n         (keypress)=\"onKeypress($event)\"\n         [disabled]=\"disabled\"\n         [readonly]=\"readonly\"\n         [attr.maxlength]=\"maxlength\"\n         [attr.minlength]=\"minlength\"\n         [required]=\"required\"\n         [attr.pattern]=\"pattern\"\n         [autofocus]=\"autofocus\">\n</div>\n", styles: [".form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;width:227px;height:46px}.custom-input::placeholder{font-size:14px;color:#d3d3d3}label{font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SearchInputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-search-input', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => SearchInputComponent),
                            multi: true
                        }
                    ], template: "<div class=\"form-group\">\n  <label [for]=\"id\" [ngStyle]=\"getLabelStyles()\">{{ label }}</label>\n  <input [type]=\"type\"\n         class=\"form-control custom-input\"\n         [id]=\"id\"\n         [placeholder]=\"placeholder\"\n         [(ngModel)]=\"value\"\n         (input)=\"onInput($event)\"\n         (change)=\"onChange($event)\"\n         (focus)=\"onFocus($event)\"\n         (blur)=\"onBlur($event)\"\n         (keyup)=\"onKeyup($event)\"\n         (keydown)=\"onKeydown($event)\"\n         (keypress)=\"onKeypress($event)\"\n         [disabled]=\"disabled\"\n         [readonly]=\"readonly\"\n         [attr.maxlength]=\"maxlength\"\n         [attr.minlength]=\"minlength\"\n         [required]=\"required\"\n         [attr.pattern]=\"pattern\"\n         [autofocus]=\"autofocus\">\n</div>\n", styles: [".form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.custom-input{font-family:var(--font-family);color:#333;font-size:.9rem;width:227px;height:46px}.custom-input::placeholder{font-size:14px;color:#d3d3d3}label{font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { id: [{
                type: Input
            }], label: [{
                type: Input
            }], type: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], value: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readonly: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], maxlength: [{
                type: Input
            }], minlength: [{
                type: Input
            }], required: [{
                type: Input
            }], pattern: [{
                type: Input
            }], debounceTime: [{
                type: Input
            }], search: [{
                type: Output
            }], inputChange: [{
                type: Output
            }], change: [{
                type: Output
            }], focus: [{
                type: Output
            }], blur: [{
                type: Output
            }], keyup: [{
                type: Output
            }], keydown: [{
                type: Output
            }], keypress: [{
                type: Output
            }] } });

class SelectComponent {
    constructor(authService) {
        this.authService = authService;
        this.label = 'Default Label';
        this.id = 'selectId';
        this.disabled = false;
        this.options = [];
        this.changeEvent = new EventEmitter();
        this.onChangeCallback = () => { };
        this.onTouchedCallback = () => { };
        this.destroy$ = new Subject();
    }
    onSelectChange(event) {
        const selectElement = event.target;
        this.value = selectElement.value;
        this.onChangeCallback(this.value);
        this.changeEvent.emit(this.value);
    }
    writeValue(value) {
        this.value = value;
    }
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    ngOnChanges(changes) {
        if (changes['options'] && changes['options'].currentValue !== changes['options'].previousValue) {
            this.updateOptions(changes['options'].currentValue);
        }
    }
    updateOptions(newOptions) {
        this.options = newOptions;
    }
    hasPermission() {
        if (!this.permissions || this.permissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(this.permissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error('Permission error:', error.message);
            }
            else {
                console.error('Unknown error occurred during permission check');
            }
            return true;
        }
    }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SelectComponent, deps: [{ token: AuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SelectComponent, selector: "argenta-custom-select", inputs: { label: "label", id: "id", disabled: "disabled", options: "options", permissions: "permissions" }, outputs: { changeEvent: "changeEvent" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => SelectComponent),
                multi: true
            }
        ], usesOnChanges: true, ngImport: i0, template: `
    <div *ngIf="hasPermission()" class="form-group">
      <label [for]="id" [ngClass]="'label-styles'">{{ label }}</label>
      <div class="select-container">
        <select class="form-control custom-select"
                [id]="id"
                [value]="value"
                (change)="onSelectChange($event)"
                [disabled]="disabled">
          <option *ngFor="let option of options" [value]="option.value">{{ option.label }}</option>
        </select>
        <lucide-icon name="chevron-down" [size]="16" color="#5E6366" [strokeWidth]="1.75"></lucide-icon>
      </div>
    </div>
  `, isInline: true, styles: ["@charset \"UTF-8\";.form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.form-check-input{font-family:var(--font-family);color:#333;font-size:.9rem}.form-check-label{width:623px;height:19px;top:1608px;left:133px;gap:0px;opacity:0px;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}.custom-select{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:400;border:1px solid #ccc;border-radius:4px;padding:.5rem 2rem .5rem .5rem;appearance:none;-webkit-appearance:none;-moz-appearance:none;background-image:none;background-repeat:no-repeat;background-position:right .5rem center}.custom-input{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:400;border:1px solid #ccc;border-radius:4px;padding:.5rem}.form-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.select-container{position:relative;display:inline-block;width:100%}.select-container lucide-icon{position:absolute;right:.75rem;top:50%;transform:translateY(-50%);pointer-events:none;color:#5e6366}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-custom-select', template: `
    <div *ngIf="hasPermission()" class="form-group">
      <label [for]="id" [ngClass]="'label-styles'">{{ label }}</label>
      <div class="select-container">
        <select class="form-control custom-select"
                [id]="id"
                [value]="value"
                (change)="onSelectChange($event)"
                [disabled]="disabled">
          <option *ngFor="let option of options" [value]="option.value">{{ option.label }}</option>
        </select>
        <lucide-icon name="chevron-down" [size]="16" color="#5E6366" [strokeWidth]="1.75"></lucide-icon>
      </div>
    </div>
  `, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => SelectComponent),
                            multi: true
                        }
                    ], changeDetection: ChangeDetectionStrategy.OnPush, styles: ["@charset \"UTF-8\";.form-group{font-family:var(--font-family);font-size:1rem;font-weight:700}.form-check-input{font-family:var(--font-family);color:#333;font-size:.9rem}.form-check-label{width:623px;height:19px;top:1608px;left:133px;gap:0px;opacity:0px;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left}.custom-select{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:400;border:1px solid #ccc;border-radius:4px;padding:.5rem 2rem .5rem .5rem;appearance:none;-webkit-appearance:none;-moz-appearance:none;background-image:none;background-repeat:no-repeat;background-position:right .5rem center}.custom-input{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:400;border:1px solid #ccc;border-radius:4px;padding:.5rem}.form-label{font-family:var(--font-family);color:#333;font-size:1rem;font-weight:700}.label-styles{font-weight:400;font-family:var(--font-family);font-size:16px;line-height:19.36px;text-align:left;margin-top:1rem;margin-bottom:.5rem}.select-container{position:relative;display:inline-block;width:100%}.select-container lucide-icon{position:absolute;right:.75rem;top:50%;transform:translateY(-50%);pointer-events:none;color:#5e6366}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }]; }, propDecorators: { label: [{
                type: Input
            }], id: [{
                type: Input
            }], disabled: [{
                type: Input
            }], options: [{
                type: Input
            }], permissions: [{
                type: Input
            }], changeEvent: [{
                type: Output
            }] } });

class TabComponent {
    constructor(authService, cdr) {
        this.authService = authService;
        this.cdr = cdr;
        this.tabs = [];
        this.activeTabIndex = 0;
        this.tabChanged = new EventEmitter();
        this.showTabs = true; // Controla a exibição do componente
    }
    ngOnInit() {
        if (this.hasComponentPermission() && this.tabs.length > 0) {
            this.selectTab(this.activeTabIndex);
        }
    }
    ngOnChanges(changes) {
        if (changes['tabs'] && !changes['tabs'].firstChange) {
            this.tabs = [...this.tabs]; // Gera uma nova referência
            this.activeTabIndex = 0;
            this.cdr.markForCheck(); // Força a atualização
        }
    }
    selectTab(index, event) {
        if (event) {
            event.preventDefault();
        }
        if (this.hasPermission(this.tabs[index]?.permissions)) {
            this.activeTabIndex = index;
            this.tabChanged.emit(this.activeTabIndex);
        }
    }
    hasPermission(requiredPermissions) {
        if (!requiredPermissions || requiredPermissions.length === 0) {
            return true;
        }
        return this.authService.hasPermission(requiredPermissions);
    }
    hasComponentPermission() {
        if (!this.componentPermissions || this.componentPermissions.length === 0) {
            return true;
        }
        return this.authService.hasPermission(this.componentPermissions);
    }
    trackByIndex(index) {
        return index;
    }
    // 🔹 Método para reiniciar o componente
    refreshTabs() {
        this.showTabs = false; // Remove o componente do DOM
        setTimeout(() => {
            this.showTabs = true; // Adiciona novamente
            this.cdr.detectChanges(); // Força a atualização do template
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TabComponent, deps: [{ token: AuthService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: TabComponent, selector: "argenta-tab", inputs: { tabs: "tabs", activeTabIndex: "activeTabIndex", componentPermissions: "componentPermissions" }, outputs: { tabChanged: "tabChanged" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngIf=\"showTabs\">\n  <ng-container *ngIf=\"hasComponentPermission()\">\n    <ul class=\"nav nav-tabs\">\n      <ng-container *ngFor=\"let tab of tabs; let i = index; trackBy: trackByIndex\">\n        <li class=\"nav-item\" *ngIf=\"hasPermission(tab.permissions)\">\n          <a\n            class=\"nav-link\"\n            [class.active]=\"i === activeTabIndex\"\n            (click)=\"selectTab(i, $event)\"\n            href=\"#\"\n            >{{ tab.label }}</a\n          >\n        </li>\n      </ng-container>\n    </ul>\n    <div class=\"tab-content\">\n      <div\n        *ngFor=\"let tab of tabs; let i = index; trackBy: trackByIndex\"\n        class=\"tab-pane fade\"\n        [ngClass]=\"{ 'show active': i === activeTabIndex }\"\n      >\n        <ng-container *ngTemplateOutlet=\"tab.content\"></ng-container>\n      </div>\n    </div>\n  </ng-container>\n</ng-container>\n", styles: [".nav-tabs .nav-item .nav-link{cursor:pointer;font-family:var(--font-family);border-top-left-radius:.3rem;border-top-right-radius:.3rem;font-size:14px;color:var(--primary-color);border:1px solid #ddd;transition:background-color .3s ease,color .3s ease}.nav-tabs .nav-item .nav-link.active{background-color:var(--primary-color);color:var(--background-color);border-color:transparent}.nav-tabs .nav-item .nav-link:hover{background-color:var(--secondary-color);color:var(--background-color)}.tab-content .tab-pane{padding:1rem;border:1px solid #ddd;border-top:none}.nav-tabs .nav-item .nav-link{color:var(--primary-color)}.nav-tabs .nav-item .nav-link.active{background-color:var(--primary-color);color:var(--text-color)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TabComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-tab', template: "<ng-container *ngIf=\"showTabs\">\n  <ng-container *ngIf=\"hasComponentPermission()\">\n    <ul class=\"nav nav-tabs\">\n      <ng-container *ngFor=\"let tab of tabs; let i = index; trackBy: trackByIndex\">\n        <li class=\"nav-item\" *ngIf=\"hasPermission(tab.permissions)\">\n          <a\n            class=\"nav-link\"\n            [class.active]=\"i === activeTabIndex\"\n            (click)=\"selectTab(i, $event)\"\n            href=\"#\"\n            >{{ tab.label }}</a\n          >\n        </li>\n      </ng-container>\n    </ul>\n    <div class=\"tab-content\">\n      <div\n        *ngFor=\"let tab of tabs; let i = index; trackBy: trackByIndex\"\n        class=\"tab-pane fade\"\n        [ngClass]=\"{ 'show active': i === activeTabIndex }\"\n      >\n        <ng-container *ngTemplateOutlet=\"tab.content\"></ng-container>\n      </div>\n    </div>\n  </ng-container>\n</ng-container>\n", styles: [".nav-tabs .nav-item .nav-link{cursor:pointer;font-family:var(--font-family);border-top-left-radius:.3rem;border-top-right-radius:.3rem;font-size:14px;color:var(--primary-color);border:1px solid #ddd;transition:background-color .3s ease,color .3s ease}.nav-tabs .nav-item .nav-link.active{background-color:var(--primary-color);color:var(--background-color);border-color:transparent}.nav-tabs .nav-item .nav-link:hover{background-color:var(--secondary-color);color:var(--background-color)}.tab-content .tab-pane{padding:1rem;border:1px solid #ddd;border-top:none}.nav-tabs .nav-item .nav-link{color:var(--primary-color)}.nav-tabs .nav-item .nav-link.active{background-color:var(--primary-color);color:var(--text-color)}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { tabs: [{
                type: Input
            }], activeTabIndex: [{
                type: Input
            }], componentPermissions: [{
                type: Input
            }], tabChanged: [{
                type: Output
            }] } });

class RefreshService {
    constructor() {
        this.refreshSubject = new Subject();
    }
    get refresh$() {
        return this.refreshSubject.asObservable();
    }
    refresh() {
        this.refreshSubject.next();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RefreshService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RefreshService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RefreshService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class ConfirmationService {
    constructor(modalService) {
        this.modalService = modalService;
        this.modalRef = null;
    }
    confirm(title, message, confirmButtonText = 'Sim', cancelButtonText = 'Não') {
        this.modalRef = this.modalService.open(ConfirmationComponent, { backdrop: 'static', keyboard: false });
        this.modalRef.componentInstance.title = title;
        this.modalRef.componentInstance.message = message;
        this.modalRef.componentInstance.confirmButtonText = confirmButtonText;
        this.modalRef.componentInstance.cancelButtonText = cancelButtonText;
        return this.modalRef.result.then((result) => {
            return result === 'confirm';
        }, () => {
            return false;
        }).finally(() => {
            this.modalRef = null; // Clear the reference after the modal is closed
        });
    }
    ngOnDestroy() {
        if (this.modalRef) {
            this.modalRef.dismiss();
            this.modalRef = null;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConfirmationService, deps: [{ token: i1$1.NgbModal }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConfirmationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConfirmationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.NgbModal }]; } });

class DataTableComponent {
    constructor(cdr, authService, refreshService, confirmationService) {
        this.cdr = cdr;
        this.authService = authService;
        this.refreshService = refreshService;
        this.confirmationService = confirmationService;
        this.columns = [];
        this.hiddenColumns = [];
        this.defaultItemsPerPage = 10;
        this.itemsPerPageLabel = "Items per page:";
        this.showActionColumn = false;
        this.actionColumnLabel = "Actions";
        this.totalItems = 0;
        this.fetchDataFunction = () => {
            return new Observable((subscriber) => subscriber.error("Implement the fetchDataFunction to fetch paginated data from the back-end."));
        };
        this.editPermissions = [];
        this.deletePermissions = [];
        this.inativoPermissions = [];
        this.viewPermissions = [];
        this.inativoTexts = {
            inactivate: "Desativar",
            activate: "Ativar",
            modalTitle: "Alterar status",
            modalText: "Você deseja realmente alterar o status?",
        };
        this.showPageInfo = true;
        this.pageText = "Page";
        this.ofText = "of";
        this.filterDescription = "";
        this.buttonLabel = "";
        this.pagedData = [];
        this.initialFilterField = null;
        this.buttonList = [];
        this.statusField = 'indInativo';
        this.statusChange = new EventEmitter();
        this.sortChange = new EventEmitter();
        this.pageChange = new EventEmitter();
        this.itemsPerPageChange = new EventEmitter();
        this.onEditTable = new EventEmitter();
        this.onDeleteTable = new EventEmitter();
        this.onViewTable = new EventEmitter();
        this.onButtonClick = new EventEmitter();
        this.filterFieldChange = new EventEmitter();
        this.itemsPerPageOptions = [5, 10, 15, 25];
        this.currentPage = 1;
        this.sortColumn = "";
        this.sortDirection = "asc";
        this.selectedSearchField = "";
        this.isLoading = false;
        this.destroy$ = new Subject();
        this.isInitialized = false; // Flag para evitar chamadas duplas
        this.ButtonClasses = ButtonClasses;
        this.labelStyle = {
            "font-family": "Inter, Arial, sans-serif",
            "font-size": "14px",
            color: "#000",
        };
    }
    ngOnInit() {
        if (this.initialFilterField) {
            // Se o usuário definir o initialFilterField, ele será usado como o campo inicial
            this.selectedSearchField = this.initialFilterField;
            this.sortColumn = this.initialFilterField;
            this.sortDirection = "asc";
            this.columns = this.columns.map((column) => ({
                ...column,
                isSearchSelected: column.prop === this.initialFilterField,
            }));
        }
        else if (this.columns.length > 0) {
            // Caso contrário, usa a primeira coluna como padrão
            this.selectedSearchField = this.columns[0].prop;
            this.sortColumn = this.columns[0].prop;
            this.sortDirection = "asc";
            this.columns = this.columns.map((column) => ({
                ...column,
                isSearchSelected: column.prop === this.selectedSearchField,
            }));
        }
        //this.fetchData();
        this.refreshService.refresh$
            .pipe(takeUntil(this.destroy$))
            .subscribe(() => {
            if (this.isInitialized) {
                this.refreshData();
            }
        });
        this.isInitialized = true;
    }
    // ngOnChanges(changes: SimpleChanges) {
    //   if (
    //     changes["totalItems"] ||
    //     changes["defaultItemsPerPage"] ||
    //     changes["currentPage"] ||
    //     changes["fetchDataFunction"] ||
    //     changes["filterDescription"]
    //   ) {
    //     this.fetchData();
    //   }
    // }
    ngOnDestroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    getNestedProperty(obj, path) {
        return path.split(".").reduce((acc, part) => acc && acc[part], obj);
    }
    fetchData() {
        if (this.fetchDataFunction) {
            this.isLoading = true;
            const params = {
                filterDescription: this.filterDescription,
                filterField: this.selectedSearchField,
                pageNumber: this.currentPage ?? 1,
                pageSize: this.defaultItemsPerPage ?? 10,
                sortColumn: this.sortColumn,
                sortDirection: this.sortDirection,
            };
            this.fetchDataFunction(params)
                .pipe(takeUntil(this.destroy$))
                .subscribe({
                next: (result) => {
                    this.pagedData = result.items;
                    this.totalItems = result.totalItems;
                    this.isLoading = false;
                    this.cdr.markForCheck();
                },
                error: (error) => {
                    console.error("Error fetching data:", error);
                    this.isLoading = false;
                },
            });
        }
    }
    refreshData() {
        this.fetchData();
    }
    onPageChange(page) {
        this.currentPage = page;
        this.pageChange.emit(page);
        this.fetchData();
    }
    onItemsPerPageChange() {
        this.currentPage = 1;
        this.itemsPerPageChange.emit(this.defaultItemsPerPage);
        this.fetchData();
    }
    onSelectSearchField(columnProp) {
        if (this.sortColumn === columnProp) {
            this.sortDirection = this.sortDirection === "asc" ? "desc" : "asc";
        }
        else {
            this.sortDirection = "asc";
        }
        this.selectedSearchField = columnProp;
        this.sortColumn = columnProp;
        this.columns = this.columns.map((column) => ({
            ...column,
            isSearchSelected: column.prop === columnProp,
        }));
        this.filterFieldChange.emit(this.selectedSearchField);
        if (this.fetchDataFunction) {
            this.fetchDataFunction({
                filterDescription: this.filterDescription,
                filterField: this.selectedSearchField,
                pageNumber: this.currentPage,
                pageSize: this.defaultItemsPerPage,
                sortColumn: this.sortColumn,
                sortDirection: this.sortDirection,
            }).subscribe({
                next: (result) => {
                    this.pagedData = result.items;
                    this.totalItems = result.totalItems;
                    this.cdr.markForCheck();
                },
                error: (error) => {
                    console.error("Erro ao buscar dados:", error);
                },
            });
        }
    }
    handleAction(action, item, index) {
        switch (action) {
            case "edit":
                if (this.hasPermission(this.editPermissions)) {
                    this.onEditTable.emit({ item, index });
                }
                break;
            case "delete":
                if (this.hasPermission(this.deletePermissions)) {
                    this.onDeleteTable.emit({ item, index });
                }
                break;
            case "view":
                if (this.hasPermission(this.viewPermissions)) {
                    this.onViewTable.emit({ item, index });
                }
                break;
            case "inativar":
                if (this.hasPermission(this.inativoPermissions)) {
                    this.confirmationService
                        .confirm(this.inativoTexts.modalTitle, this.inativoTexts.modalText)
                        .then((confirmed) => {
                        if (confirmed) {
                            let value = !item[this.statusField];
                            item[this.statusField] = value;
                            this.statusChange.emit({ status: value, item: item });
                        }
                        else {
                            return;
                        }
                    });
                }
                break;
        }
    }
    hasPermission(requiredPermissions) {
        if (!requiredPermissions || requiredPermissions.length === 0) {
            return true;
        }
        try {
            return this.authService.hasPermission(requiredPermissions);
        }
        catch (error) {
            if (error instanceof Error) {
                console.error("Permission error:", error.message);
            }
            else {
                console.error("Unknown error occurred during permission check");
            }
            return true;
        }
    }
    isColumnHidden(columnProp) {
        return this.hiddenColumns.includes(columnProp);
    }
    isBoolean(value) {
        return typeof value === 'boolean';
    }
    onSearch(searchText) {
        this.filterDescription = searchText;
        this.currentPage = 1; // Resetar para a primeira página
        this.fetchData();
    }
    onNewButtonClick() {
        this.onButtonClick.emit(); // Emitindo o evento
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataTableComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: AuthService }, { token: RefreshService }, { token: ConfirmationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DataTableComponent, selector: "argenta-list-data-table", inputs: { columns: "columns", hiddenColumns: "hiddenColumns", defaultItemsPerPage: "defaultItemsPerPage", itemsPerPageLabel: "itemsPerPageLabel", showActionColumn: "showActionColumn", actionColumnLabel: "actionColumnLabel", totalItems: "totalItems", fetchDataFunction: "fetchDataFunction", editPermissions: "editPermissions", deletePermissions: "deletePermissions", inativoPermissions: "inativoPermissions", viewPermissions: "viewPermissions", inativoTexts: "inativoTexts", showPageInfo: "showPageInfo", pageText: "pageText", ofText: "ofText", filterDescription: "filterDescription", buttonLabel: "buttonLabel", pagedData: "pagedData", initialFilterField: "initialFilterField", buttonList: "buttonList", statusField: "statusField" }, outputs: { statusChange: "statusChange", sortChange: "sortChange", pageChange: "pageChange", itemsPerPageChange: "itemsPerPageChange", onEditTable: "onEditTable", onDeleteTable: "onDeleteTable", onViewTable: "onViewTable", onButtonClick: "onButtonClick", filterFieldChange: "filterFieldChange" }, ngImport: i0, template: "<div class=\"data-table-header\" style=\"margin-top: 2.5rem\">\n  <div class=\"left-section\">\n    <div class=\"form-group\">\n      <label for=\"itemsPerPageSelect\" class=\"items-per-page-label\">{{\n        itemsPerPageLabel\n      }}</label>\n      <select\n        id=\"itemsPerPageSelect\"\n        class=\"form-control form-control-sm d-inline-block w-auto custom-select\"\n        [(ngModel)]=\"defaultItemsPerPage\"\n        (ngModelChange)=\"onItemsPerPageChange()\"\n      >\n        <option *ngFor=\"let option of itemsPerPageOptions\" [value]=\"option\">\n          {{ option }}\n        </option>\n      </select>\n    </div>\n  </div>\n  <div class=\"right-section\">\n    <div *ngIf=\"buttonList && buttonList.length > 0\" class=\"ng-button-row\">\n      <ng-container *ngFor=\"let buttonTemplate of buttonList\">\n        <ng-container\n          *ngTemplateOutlet=\"buttonTemplate\"\n          class=\"ng-button\"\n        ></ng-container>\n      </ng-container>\n    </div>\n    <button\n      *ngIf=\"buttonLabel && buttonLabel.length > 0\"\n      class=\"custom-button\"\n      (click)=\"onNewButtonClick()\"\n    >\n      <lucide-icon name=\"plus\" [size]=\"28\" [strokeWidth]=\"1.75\"></lucide-icon>\n      {{ buttonLabel }}\n    </button>\n  </div>\n</div>\n\n<div class=\"search-input-container\">\n  <argenta-search-input\n    id=\"search\"\n    label=\"\"\n    placeholder=\"Buscar\"\n    [(ngModel)]=\"filterDescription\"\n    (search)=\"onSearch($event)\"\n  ></argenta-search-input>\n</div>\n\n<div class=\"table-responsive\" style=\"margin-top: 1rem\">\n  <table class=\"table table-hover\">\n    <thead>\n      <tr>\n        <ng-container *ngFor=\"let column of columns\">\n          <th\n            *ngIf=\"!isColumnHidden(column.prop)\"\n            (click)=\"onSelectSearchField(column.prop)\"\n          >\n            {{ column.label }}\n            <span>\n              <i-lucide\n                name=\"arrow-up\"\n                [size]=\"14\"\n                [class.selected]=\"\n                  column.isSearchSelected && sortDirection === 'asc'\n                \"\n              ></i-lucide>\n              <i-lucide\n                name=\"arrow-down\"\n                [size]=\"14\"\n                [class.selected]=\"\n                  column.isSearchSelected && sortDirection === 'desc'\n                \"\n              ></i-lucide>\n            </span>\n          </th>\n        </ng-container>\n        <th\n          *ngIf=\"showActionColumn\"\n          class=\"text-end\"\n          style=\"padding-right: 6.3rem\"\n        >\n          {{ actionColumnLabel }}\n        </th>\n      </tr>\n    </thead>\n    <tbody>\n      <tr *ngFor=\"let item of pagedData; let i = index\">\n        <ng-container *ngFor=\"let column of columns\">\n          <td *ngIf=\"!isColumnHidden(column.prop)\" [ngSwitch]=\"column.type\">\n            <!-- Default case (when type is undefined or not matched) -->\n            <span *ngSwitchDefault>\n              {{ getNestedProperty(item, column.prop) }}\n            </span>\n\n            <!-- String case -->\n            <span *ngSwitchCase=\"'string'\">\n              {{ getNestedProperty(item, column.prop) }}\n            </span>\n\n            <!-- Image case -->\n            <img\n              *ngSwitchCase=\"'image'\"\n              [src]=\"getNestedProperty(item, column.prop)\"\n              alt=\"Image\"\n              width=\"50\"\n              height=\"50\"\n            />\n          </td>\n        </ng-container>\n        <td *ngIf=\"showActionColumn\" class=\"text-end\">\n          <div class=\"d-flex justify-content-end\">\n            <div\n              *ngIf=\"\n                hasPermission(editPermissions) &&\n                onEditTable.observers.length > 0\n              \"\n              (click)=\"handleAction('edit', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <lucide-icon\n                name=\"square-pen\"\n                [size]=\"20\"\n                color=\"#2CA58D\"\n                [strokeWidth]=\"1.75\"\n              ></lucide-icon>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(inativoPermissions) &&\n                statusChange.observers.length > 0 &&\n                statusField.length > 0 &&\n                isBoolean(item[statusField])\n              \"\n              (click)=\"handleAction('inativar', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <button\n                [ngClass]=\"\n                  item[statusField]\n                    ? 'btn btn-success small-rounded-btn'\n                    : 'btn btn-danger small-rounded-btn'\n                \"\n              >\n                {{\n                  item[statusField] ? inativoTexts.activate : inativoTexts.inactivate\n                }}\n              </button>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(viewPermissions) &&\n                onViewTable.observers.length > 0\n              \"\n              (click)=\"handleAction('view', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <lucide-icon\n                name=\"user-round\"\n                [size]=\"20\"\n                color=\"#2CA58D\"\n                [strokeWidth]=\"1.75\"\n              ></lucide-icon>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(deletePermissions) &&\n                onDeleteTable.observers.length > 0\n              \"\n              (click)=\"handleAction('delete', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <i-lucide\n                name=\"trash-2\"\n                [size]=\"20\"\n                color=\"#F26E6E\"\n                [strokeWidth]=\"1.75\"\n              ></i-lucide>\n            </div>\n          </div>\n        </td>\n      </tr>\n    </tbody>\n  </table>\n</div>\n\n<div class=\"text-center pagination-controls\">\n  <custom-pagination\n    [totalItems]=\"totalItems\"\n    [itemsPerPage]=\"defaultItemsPerPage\"\n    [currentPage]=\"currentPage\"\n    [showPageInfo]=\"showPageInfo\"\n    (pageChange)=\"onPageChange($event)\"\n  >\n  </custom-pagination>\n</div>\n", styles: ["@charset \"UTF-8\";.clickable-icon{cursor:pointer}:host{font-family:var(--font-family)}.data-table-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:-.2rem}.left-section,.right-section{display:flex;align-items:center}.search-input-container{display:flex;justify-content:flex-start}.left-section .form-group{display:flex;align-items:center}.items-per-page-label{font-family:var(--font-family);font-size:14px;color:#666;margin-right:.2rem}.custom-select{font-family:var(--font-family);font-size:14px;color:#666;background:#fff url('data:image/svg+xml;charset=US-ASCII,<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 5\"><path fill=\"#666\" d=\"M2 0L0 2h4L2 0zM2 5l2-2H0l2 2z\"/></svg>') no-repeat right .75rem center/8px 10px;border:1px solid #ccc;border-radius:.25rem;padding:.375rem 1.75rem .375rem .75rem;appearance:none;-webkit-appearance:none;-moz-appearance:none}.custom-select:focus{border-color:#80bdff;outline:0;box-shadow:0 0 0 .2rem #007bff40}.table{font-family:var(--font-family);font-size:var(--table-font-size, 14px);color:var(--table-font-color, #737b7b);border-collapse:separate;border-spacing:0;border-radius:8px;overflow:hidden}.table thead tr{height:60px}.table thead th{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);font-size:14px;font-weight:600;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center;line-height:2.5}.table thead th:first-child{text-align:left;padding-left:1.4rem}.table tbody td{font-family:var(--font-family);font-size:14px;color:#737b7b;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center}.table tbody td:first-child{text-align:left;padding-left:1.4rem}.table tbody tr:last-child td{border-bottom:.1rem solid #dcdcdc}.table tbody td{border-right:none;border-left:none}.table thead th:first-child{border-top-left-radius:0}.table thead th:last-child{border-top-right-radius:0}.table tbody tr:last-child td:first-child{border-bottom-left-radius:0}.table tbody tr:last-child td:last-child{border-bottom-right-radius:0}.btn-icon{width:24px;height:24px;background-size:cover;display:inline-block;cursor:pointer;margin-right:16px}.pagination-controls{display:flex;justify-content:center;align-items:center;margin-top:1rem}.custom-button{display:flex;align-items:center;padding:.5rem 1rem .5rem .5rem;border-radius:.25rem;transition:background-color .3s,border-color .3s,filter .3s;font-family:var(--font-family);font-size:16px;font-weight:600;height:40px;letter-spacing:.005em;text-align:left;color:#fff;background-color:var(--secondary-color);border:none;cursor:pointer}.custom-button lucide-icon{margin-right:.5rem}.custom-button:hover{box-shadow:0 0 0 .15rem var(--secondary-color)}.custom-button:active{background-color:var(--secondary-color)}.custom-button:focus{outline:none;box-shadow:0 0 0 .15rem var(--secondary-color)}.selected{color:var(--secondary-color);stroke-width:8}.ng-button-row{display:flex;gap:10px;margin-right:10px;margin-left:10px}.small-rounded-btn{padding:6px 12px;font-size:14px;border-radius:20px;height:32px;min-width:80px;border:none;transition:all .3s ease-in-out}.small-rounded-btn:hover{opacity:.8;transform:scale(1.05)}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i1.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.LucideAngularComponent, selector: "lucide-angular, lucide-icon, i-lucide, span-lucide", inputs: ["class", "name", "img", "color", "absoluteStrokeWidth", "size", "strokeWidth"] }, { kind: "component", type: CustomPaginationComponent, selector: "custom-pagination", inputs: ["totalItems", "itemsPerPage", "currentPage", "showPageInfo"], outputs: ["pageChange"] }, { kind: "component", type: SearchInputComponent, selector: "argenta-search-input", inputs: ["id", "label", "type", "placeholder", "value", "disabled", "readonly", "autofocus", "maxlength", "minlength", "required", "pattern", "debounceTime"], outputs: ["search", "inputChange", "change", "focus", "blur", "keyup", "keydown", "keypress"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataTableComponent, decorators: [{
            type: Component,
            args: [{ selector: "argenta-list-data-table", changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"data-table-header\" style=\"margin-top: 2.5rem\">\n  <div class=\"left-section\">\n    <div class=\"form-group\">\n      <label for=\"itemsPerPageSelect\" class=\"items-per-page-label\">{{\n        itemsPerPageLabel\n      }}</label>\n      <select\n        id=\"itemsPerPageSelect\"\n        class=\"form-control form-control-sm d-inline-block w-auto custom-select\"\n        [(ngModel)]=\"defaultItemsPerPage\"\n        (ngModelChange)=\"onItemsPerPageChange()\"\n      >\n        <option *ngFor=\"let option of itemsPerPageOptions\" [value]=\"option\">\n          {{ option }}\n        </option>\n      </select>\n    </div>\n  </div>\n  <div class=\"right-section\">\n    <div *ngIf=\"buttonList && buttonList.length > 0\" class=\"ng-button-row\">\n      <ng-container *ngFor=\"let buttonTemplate of buttonList\">\n        <ng-container\n          *ngTemplateOutlet=\"buttonTemplate\"\n          class=\"ng-button\"\n        ></ng-container>\n      </ng-container>\n    </div>\n    <button\n      *ngIf=\"buttonLabel && buttonLabel.length > 0\"\n      class=\"custom-button\"\n      (click)=\"onNewButtonClick()\"\n    >\n      <lucide-icon name=\"plus\" [size]=\"28\" [strokeWidth]=\"1.75\"></lucide-icon>\n      {{ buttonLabel }}\n    </button>\n  </div>\n</div>\n\n<div class=\"search-input-container\">\n  <argenta-search-input\n    id=\"search\"\n    label=\"\"\n    placeholder=\"Buscar\"\n    [(ngModel)]=\"filterDescription\"\n    (search)=\"onSearch($event)\"\n  ></argenta-search-input>\n</div>\n\n<div class=\"table-responsive\" style=\"margin-top: 1rem\">\n  <table class=\"table table-hover\">\n    <thead>\n      <tr>\n        <ng-container *ngFor=\"let column of columns\">\n          <th\n            *ngIf=\"!isColumnHidden(column.prop)\"\n            (click)=\"onSelectSearchField(column.prop)\"\n          >\n            {{ column.label }}\n            <span>\n              <i-lucide\n                name=\"arrow-up\"\n                [size]=\"14\"\n                [class.selected]=\"\n                  column.isSearchSelected && sortDirection === 'asc'\n                \"\n              ></i-lucide>\n              <i-lucide\n                name=\"arrow-down\"\n                [size]=\"14\"\n                [class.selected]=\"\n                  column.isSearchSelected && sortDirection === 'desc'\n                \"\n              ></i-lucide>\n            </span>\n          </th>\n        </ng-container>\n        <th\n          *ngIf=\"showActionColumn\"\n          class=\"text-end\"\n          style=\"padding-right: 6.3rem\"\n        >\n          {{ actionColumnLabel }}\n        </th>\n      </tr>\n    </thead>\n    <tbody>\n      <tr *ngFor=\"let item of pagedData; let i = index\">\n        <ng-container *ngFor=\"let column of columns\">\n          <td *ngIf=\"!isColumnHidden(column.prop)\" [ngSwitch]=\"column.type\">\n            <!-- Default case (when type is undefined or not matched) -->\n            <span *ngSwitchDefault>\n              {{ getNestedProperty(item, column.prop) }}\n            </span>\n\n            <!-- String case -->\n            <span *ngSwitchCase=\"'string'\">\n              {{ getNestedProperty(item, column.prop) }}\n            </span>\n\n            <!-- Image case -->\n            <img\n              *ngSwitchCase=\"'image'\"\n              [src]=\"getNestedProperty(item, column.prop)\"\n              alt=\"Image\"\n              width=\"50\"\n              height=\"50\"\n            />\n          </td>\n        </ng-container>\n        <td *ngIf=\"showActionColumn\" class=\"text-end\">\n          <div class=\"d-flex justify-content-end\">\n            <div\n              *ngIf=\"\n                hasPermission(editPermissions) &&\n                onEditTable.observers.length > 0\n              \"\n              (click)=\"handleAction('edit', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <lucide-icon\n                name=\"square-pen\"\n                [size]=\"20\"\n                color=\"#2CA58D\"\n                [strokeWidth]=\"1.75\"\n              ></lucide-icon>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(inativoPermissions) &&\n                statusChange.observers.length > 0 &&\n                statusField.length > 0 &&\n                isBoolean(item[statusField])\n              \"\n              (click)=\"handleAction('inativar', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <button\n                [ngClass]=\"\n                  item[statusField]\n                    ? 'btn btn-success small-rounded-btn'\n                    : 'btn btn-danger small-rounded-btn'\n                \"\n              >\n                {{\n                  item[statusField] ? inativoTexts.activate : inativoTexts.inactivate\n                }}\n              </button>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(viewPermissions) &&\n                onViewTable.observers.length > 0\n              \"\n              (click)=\"handleAction('view', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <lucide-icon\n                name=\"user-round\"\n                [size]=\"20\"\n                color=\"#2CA58D\"\n                [strokeWidth]=\"1.75\"\n              ></lucide-icon>\n            </div>\n            <div\n              *ngIf=\"\n                hasPermission(deletePermissions) &&\n                onDeleteTable.observers.length > 0\n              \"\n              (click)=\"handleAction('delete', item, i)\"\n              class=\"clickable-icon\"\n              style=\"margin-right: 1.5rem\"\n            >\n              <i-lucide\n                name=\"trash-2\"\n                [size]=\"20\"\n                color=\"#F26E6E\"\n                [strokeWidth]=\"1.75\"\n              ></i-lucide>\n            </div>\n          </div>\n        </td>\n      </tr>\n    </tbody>\n  </table>\n</div>\n\n<div class=\"text-center pagination-controls\">\n  <custom-pagination\n    [totalItems]=\"totalItems\"\n    [itemsPerPage]=\"defaultItemsPerPage\"\n    [currentPage]=\"currentPage\"\n    [showPageInfo]=\"showPageInfo\"\n    (pageChange)=\"onPageChange($event)\"\n  >\n  </custom-pagination>\n</div>\n", styles: ["@charset \"UTF-8\";.clickable-icon{cursor:pointer}:host{font-family:var(--font-family)}.data-table-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:-.2rem}.left-section,.right-section{display:flex;align-items:center}.search-input-container{display:flex;justify-content:flex-start}.left-section .form-group{display:flex;align-items:center}.items-per-page-label{font-family:var(--font-family);font-size:14px;color:#666;margin-right:.2rem}.custom-select{font-family:var(--font-family);font-size:14px;color:#666;background:#fff url('data:image/svg+xml;charset=US-ASCII,<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 5\"><path fill=\"#666\" d=\"M2 0L0 2h4L2 0zM2 5l2-2H0l2 2z\"/></svg>') no-repeat right .75rem center/8px 10px;border:1px solid #ccc;border-radius:.25rem;padding:.375rem 1.75rem .375rem .75rem;appearance:none;-webkit-appearance:none;-moz-appearance:none}.custom-select:focus{border-color:#80bdff;outline:0;box-shadow:0 0 0 .2rem #007bff40}.table{font-family:var(--font-family);font-size:var(--table-font-size, 14px);color:var(--table-font-color, #737b7b);border-collapse:separate;border-spacing:0;border-radius:8px;overflow:hidden}.table thead tr{height:60px}.table thead th{background-color:var(--primary-color);color:var(--text-color);font-family:var(--font-family);font-size:14px;font-weight:600;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center;line-height:2.5}.table thead th:first-child{text-align:left;padding-left:1.4rem}.table tbody td{font-family:var(--font-family);font-size:14px;color:#737b7b;padding:10px;border-bottom:.1rem solid #dcdcdc;text-align:center}.table tbody td:first-child{text-align:left;padding-left:1.4rem}.table tbody tr:last-child td{border-bottom:.1rem solid #dcdcdc}.table tbody td{border-right:none;border-left:none}.table thead th:first-child{border-top-left-radius:0}.table thead th:last-child{border-top-right-radius:0}.table tbody tr:last-child td:first-child{border-bottom-left-radius:0}.table tbody tr:last-child td:last-child{border-bottom-right-radius:0}.btn-icon{width:24px;height:24px;background-size:cover;display:inline-block;cursor:pointer;margin-right:16px}.pagination-controls{display:flex;justify-content:center;align-items:center;margin-top:1rem}.custom-button{display:flex;align-items:center;padding:.5rem 1rem .5rem .5rem;border-radius:.25rem;transition:background-color .3s,border-color .3s,filter .3s;font-family:var(--font-family);font-size:16px;font-weight:600;height:40px;letter-spacing:.005em;text-align:left;color:#fff;background-color:var(--secondary-color);border:none;cursor:pointer}.custom-button lucide-icon{margin-right:.5rem}.custom-button:hover{box-shadow:0 0 0 .15rem var(--secondary-color)}.custom-button:active{background-color:var(--secondary-color)}.custom-button:focus{outline:none;box-shadow:0 0 0 .15rem var(--secondary-color)}.selected{color:var(--secondary-color);stroke-width:8}.ng-button-row{display:flex;gap:10px;margin-right:10px;margin-left:10px}.small-rounded-btn{padding:6px 12px;font-size:14px;border-radius:20px;height:32px;min-width:80px;border:none;transition:all .3s ease-in-out}.small-rounded-btn:hover{opacity:.8;transform:scale(1.05)}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: AuthService }, { type: RefreshService }, { type: ConfirmationService }]; }, propDecorators: { columns: [{
                type: Input
            }], hiddenColumns: [{
                type: Input
            }], defaultItemsPerPage: [{
                type: Input
            }], itemsPerPageLabel: [{
                type: Input
            }], showActionColumn: [{
                type: Input
            }], actionColumnLabel: [{
                type: Input
            }], totalItems: [{
                type: Input
            }], fetchDataFunction: [{
                type: Input
            }], editPermissions: [{
                type: Input
            }], deletePermissions: [{
                type: Input
            }], inativoPermissions: [{
                type: Input
            }], viewPermissions: [{
                type: Input
            }], inativoTexts: [{
                type: Input
            }], showPageInfo: [{
                type: Input
            }], pageText: [{
                type: Input
            }], ofText: [{
                type: Input
            }], filterDescription: [{
                type: Input
            }], buttonLabel: [{
                type: Input
            }], pagedData: [{
                type: Input
            }], initialFilterField: [{
                type: Input
            }], buttonList: [{
                type: Input
            }], statusField: [{
                type: Input
            }], statusChange: [{
                type: Output
            }], sortChange: [{
                type: Output
            }], pageChange: [{
                type: Output
            }], itemsPerPageChange: [{
                type: Output
            }], onEditTable: [{
                type: Output
            }], onDeleteTable: [{
                type: Output
            }], onViewTable: [{
                type: Output
            }], onButtonClick: [{
                type: Output
            }], filterFieldChange: [{
                type: Output
            }] } });

class TextareaComponent {
    constructor() {
        this.label = 'Default Label';
        this.placeholder = 'Default Placeholder';
        this.id = 'textareaId';
        this.rows = 3;
        this.disabled = false;
        this.readonly = false;
        this.maxlength = null;
        this.minlength = null;
        this.required = false;
        this.autofocus = false;
        this.marginTop = 0;
        this.marginBottom = 0;
        this.marginLeft = 0;
        this.marginRight = 0;
        this.inputEvent = new EventEmitter();
        this.changeEvent = new EventEmitter();
        this.focusEvent = new EventEmitter();
        this.blurEvent = new EventEmitter();
        this.keyupEvent = new EventEmitter();
        this.keydownEvent = new EventEmitter();
        this.keypressEvent = new EventEmitter();
        this.onChangeCallback = () => { };
        this.onTouchedCallback = () => { };
        this.value = '';
    }
    onInput(event) {
        const inputElement = event.target;
        this.value = inputElement.value;
        this.onChangeCallback(this.value);
        this.inputEvent.emit(event);
    }
    onChange(event) {
        this.changeEvent.emit(event);
    }
    onFocus(event) {
        this.focusEvent.emit(event);
    }
    onBlur(event) {
        this.onTouchedCallback();
        this.blurEvent.emit(event);
    }
    onKeyup(event) {
        this.keyupEvent.emit(event);
    }
    onKeydown(event) {
        this.keydownEvent.emit(event);
    }
    onKeypress(event) {
        this.keypressEvent.emit(event);
    }
    writeValue(value) {
        this.value = value;
    }
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TextareaComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: TextareaComponent, selector: "sim-app-textarea", inputs: { label: "label", placeholder: "placeholder", id: "id", rows: "rows", disabled: "disabled", readonly: "readonly", maxlength: "maxlength", minlength: "minlength", required: "required", autofocus: "autofocus", marginTop: "marginTop", marginBottom: "marginBottom", marginLeft: "marginLeft", marginRight: "marginRight" }, outputs: { inputEvent: "inputEvent", changeEvent: "changeEvent", focusEvent: "focusEvent", blurEvent: "blurEvent", keyupEvent: "keyupEvent", keydownEvent: "keydownEvent", keypressEvent: "keypressEvent" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => TextareaComponent),
                multi: true
            }
        ], ngImport: i0, template: `
    <div class="form-group" [ngStyle]="{
      'margin-top': marginTop + 'rem',
      'margin-bottom': marginBottom + 'rem',
      'margin-left': marginLeft + 'rem',
      'margin-right': marginRight + 'rem'
    }">
      <label [for]="id" class="form-label">{{ label }}</label>
      <textarea class="form-control custom-textarea"
                [id]="id"
                [rows]="rows"
                [placeholder]="placeholder"
                [value]="value"
                (input)="onInput($event)"
                (change)="onChange($event)"
                (focus)="onFocus($event)"
                (blur)="onBlur($event)"
                (keyup)="onKeyup($event)"
                (keydown)="onKeydown($event)"
                (keypress)="onKeypress($event)"
                [attr.maxlength]="maxlength"
                [attr.minlength]="minlength"
                [required]="required"
                [disabled]="disabled"
                [readonly]="readonly"
                [autofocus]="autofocus"></textarea>
    </div>
  `, isInline: true, styles: [".form-group{margin-bottom:1rem}.form-label{font-family:Arial,sans-serif;color:#333;font-size:1rem;font-weight:700}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TextareaComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sim-app-textarea', template: `
    <div class="form-group" [ngStyle]="{
      'margin-top': marginTop + 'rem',
      'margin-bottom': marginBottom + 'rem',
      'margin-left': marginLeft + 'rem',
      'margin-right': marginRight + 'rem'
    }">
      <label [for]="id" class="form-label">{{ label }}</label>
      <textarea class="form-control custom-textarea"
                [id]="id"
                [rows]="rows"
                [placeholder]="placeholder"
                [value]="value"
                (input)="onInput($event)"
                (change)="onChange($event)"
                (focus)="onFocus($event)"
                (blur)="onBlur($event)"
                (keyup)="onKeyup($event)"
                (keydown)="onKeydown($event)"
                (keypress)="onKeypress($event)"
                [attr.maxlength]="maxlength"
                [attr.minlength]="minlength"
                [required]="required"
                [disabled]="disabled"
                [readonly]="readonly"
                [autofocus]="autofocus"></textarea>
    </div>
  `, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => TextareaComponent),
                            multi: true
                        }
                    ], changeDetection: ChangeDetectionStrategy.OnPush, styles: [".form-group{margin-bottom:1rem}.form-label{font-family:Arial,sans-serif;color:#333;font-size:1rem;font-weight:700}\n"] }]
        }], propDecorators: { label: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], id: [{
                type: Input
            }], rows: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readonly: [{
                type: Input
            }], maxlength: [{
                type: Input
            }], minlength: [{
                type: Input
            }], required: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], marginTop: [{
                type: Input
            }], marginBottom: [{
                type: Input
            }], marginLeft: [{
                type: Input
            }], marginRight: [{
                type: Input
            }], inputEvent: [{
                type: Output
            }], changeEvent: [{
                type: Output
            }], focusEvent: [{
                type: Output
            }], blurEvent: [{
                type: Output
            }], keyupEvent: [{
                type: Output
            }], keydownEvent: [{
                type: Output
            }], keypressEvent: [{
                type: Output
            }] } });

class TreeNodeComponent {
    constructor() {
        this.title = '';
        this.nodes = [];
        this.isRoot = true;
        this.nodeSelected = new EventEmitter();
    }
    ngOnInit() {
        if (this.isRoot && !this.title) {
            this.title = 'Tree Node';
        }
    }
    onNodeSelected(node, event) {
        node.selected = event.target.checked;
        if (node.children) {
            this.toggleChildren(node.children, node.selected);
        }
        this.updateParentSelection(this.nodes);
        this.nodeSelected.emit(node);
    }
    toggleChildren(children, selected) {
        children.forEach(child => {
            child.selected = selected;
            if (child.children) {
                this.toggleChildren(child.children, selected);
            }
        });
    }
    onChildNodeSelected(node) {
        this.updateParentSelection(this.nodes);
        this.nodeSelected.emit(node);
    }
    updateParentSelection(nodes) {
        nodes.forEach(node => {
            if (node.children) {
                const anyChildSelected = node.children.some(child => child.selected);
                if (anyChildSelected) {
                    node.selected = true;
                }
                // Recursive call for nested parents
                this.updateParentSelection(node.children);
            }
        });
    }
    toggleCollapse(node) {
        node.collapsed = !node.collapsed;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreeNodeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: TreeNodeComponent, selector: "argenta-custom-tree-node", inputs: { title: "title", nodes: "nodes", isRoot: "isRoot" }, outputs: { nodeSelected: "nodeSelected" }, ngImport: i0, template: "<div *ngIf=\"isRoot\" class=\"tree-title\">{{ title || 'Tree Node' }}</div>\n<ul class=\"tree\">\n  <li *ngFor=\"let node of nodes\">\n    <div class=\"node-content\">\n      <!-- Exibir a seta apenas se o n\u00F3 tiver filhos n\u00E3o vazios -->\n      <span *ngIf=\"node.children && node.children.length > 0\" class=\"toggle-icon\" (click)=\"toggleCollapse(node)\"\n        [ngClass]=\"{'collapsed-icon': node.collapsed, 'expanded-icon': !node.collapsed}\">\n        {{ node.collapsed ? '\u25B6' : '\u25BC' }}\n      </span>\n      <!-- Exibir a bolinha cinza se o n\u00F3 n\u00E3o tiver filhos -->\n      <span *ngIf=\"!node.children || node.children.length === 0\" class=\"dot\"></span>\n      <label class=\"custom-checkbox\">\n        <input type=\"checkbox\" [checked]=\"node.selected\" (change)=\"onNodeSelected(node, $event)\" />\n        <span class=\"checkmark\"></span>\n      </label>\n      <label class=\"node-label\">{{ node.name }}</label>\n    </div>\n    <!-- Renderizar recursivamente apenas se o n\u00F3 tiver filhos n\u00E3o vazios e n\u00E3o estiver colapsado -->\n    <argenta-custom-tree-node *ngIf=\"node.children && node.children.length > 0 && !node.collapsed\" [nodes]=\"node.children\" [isRoot]=\"false\" (nodeSelected)=\"onChildNodeSelected(node)\"></argenta-custom-tree-node>\n  </li>\n</ul>\n", styles: ["@charset \"UTF-8\";.tree{list-style-type:none;margin:0;padding:0;position:relative;font-family:var(--font-family)}.tree li{margin:0;padding:0 0 0 2em;line-height:2em;position:relative;font-size:14px;transition:all .3s ease}.tree li:before{content:\"\";position:absolute;top:0;left:0;border-left:1px solid #ccc;bottom:.75em;transition:border-color .3s ease}.tree li:after{content:\"\";position:absolute;top:1em;left:0;border-top:1px solid #ccc;width:1em;transition:border-color .3s ease}.tree li:last-child:before{height:1em}.node-content{display:flex;align-items:center;color:#333;transition:color .3s ease}.node-content:hover .node-label{color:var(--primary-color);box-shadow:0 4px 8px #0000001a}.toggle-icon{cursor:pointer;margin-right:.5em;font-size:1em;transition:transform .3s ease,color .3s ease}.collapsed-icon{color:orange}.expanded-icon{color:green}.node-content input[type=checkbox]{display:none}.custom-checkbox{position:relative;display:inline-flex;align-items:center;cursor:pointer;-webkit-user-select:none;user-select:none}.checkmark{position:relative;height:14px;width:14px;background-color:var(--text-color);border:2px solid var(--primary-color);border-radius:3px;transition:background-color .3s ease,border-color .3s ease}.custom-checkbox input:checked+.checkmark{background-color:var(--primary-color);border-color:var(--primary-color);transition:background-color .3s ease,border-color .3s ease}.custom-checkbox .checkmark:after{content:\"\";position:absolute;display:none;left:4px;top:1px;width:3px;height:8px;border:solid white;border-width:0 2px 2px 0;transform:rotate(45deg);transition:transform .3s ease}.custom-checkbox input:checked+.checkmark:after{display:block}.node-label{margin-left:.5em;transition:color .3s ease,box-shadow .3s ease}.node-content input{margin-right:.5em;transition:transform .3s ease}.tree-title{font-weight:600;margin-bottom:10px;font-size:18px;color:var(--primary-color);transition:color .3s ease}.dot{width:8px;height:8px;background-color:#828282;border-radius:50%;margin-right:8px;opacity:1}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: TreeNodeComponent, selector: "argenta-custom-tree-node", inputs: ["title", "nodes", "isRoot"], outputs: ["nodeSelected"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreeNodeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'argenta-custom-tree-node', template: "<div *ngIf=\"isRoot\" class=\"tree-title\">{{ title || 'Tree Node' }}</div>\n<ul class=\"tree\">\n  <li *ngFor=\"let node of nodes\">\n    <div class=\"node-content\">\n      <!-- Exibir a seta apenas se o n\u00F3 tiver filhos n\u00E3o vazios -->\n      <span *ngIf=\"node.children && node.children.length > 0\" class=\"toggle-icon\" (click)=\"toggleCollapse(node)\"\n        [ngClass]=\"{'collapsed-icon': node.collapsed, 'expanded-icon': !node.collapsed}\">\n        {{ node.collapsed ? '\u25B6' : '\u25BC' }}\n      </span>\n      <!-- Exibir a bolinha cinza se o n\u00F3 n\u00E3o tiver filhos -->\n      <span *ngIf=\"!node.children || node.children.length === 0\" class=\"dot\"></span>\n      <label class=\"custom-checkbox\">\n        <input type=\"checkbox\" [checked]=\"node.selected\" (change)=\"onNodeSelected(node, $event)\" />\n        <span class=\"checkmark\"></span>\n      </label>\n      <label class=\"node-label\">{{ node.name }}</label>\n    </div>\n    <!-- Renderizar recursivamente apenas se o n\u00F3 tiver filhos n\u00E3o vazios e n\u00E3o estiver colapsado -->\n    <argenta-custom-tree-node *ngIf=\"node.children && node.children.length > 0 && !node.collapsed\" [nodes]=\"node.children\" [isRoot]=\"false\" (nodeSelected)=\"onChildNodeSelected(node)\"></argenta-custom-tree-node>\n  </li>\n</ul>\n", styles: ["@charset \"UTF-8\";.tree{list-style-type:none;margin:0;padding:0;position:relative;font-family:var(--font-family)}.tree li{margin:0;padding:0 0 0 2em;line-height:2em;position:relative;font-size:14px;transition:all .3s ease}.tree li:before{content:\"\";position:absolute;top:0;left:0;border-left:1px solid #ccc;bottom:.75em;transition:border-color .3s ease}.tree li:after{content:\"\";position:absolute;top:1em;left:0;border-top:1px solid #ccc;width:1em;transition:border-color .3s ease}.tree li:last-child:before{height:1em}.node-content{display:flex;align-items:center;color:#333;transition:color .3s ease}.node-content:hover .node-label{color:var(--primary-color);box-shadow:0 4px 8px #0000001a}.toggle-icon{cursor:pointer;margin-right:.5em;font-size:1em;transition:transform .3s ease,color .3s ease}.collapsed-icon{color:orange}.expanded-icon{color:green}.node-content input[type=checkbox]{display:none}.custom-checkbox{position:relative;display:inline-flex;align-items:center;cursor:pointer;-webkit-user-select:none;user-select:none}.checkmark{position:relative;height:14px;width:14px;background-color:var(--text-color);border:2px solid var(--primary-color);border-radius:3px;transition:background-color .3s ease,border-color .3s ease}.custom-checkbox input:checked+.checkmark{background-color:var(--primary-color);border-color:var(--primary-color);transition:background-color .3s ease,border-color .3s ease}.custom-checkbox .checkmark:after{content:\"\";position:absolute;display:none;left:4px;top:1px;width:3px;height:8px;border:solid white;border-width:0 2px 2px 0;transform:rotate(45deg);transition:transform .3s ease}.custom-checkbox input:checked+.checkmark:after{display:block}.node-label{margin-left:.5em;transition:color .3s ease,box-shadow .3s ease}.node-content input{margin-right:.5em;transition:transform .3s ease}.tree-title{font-weight:600;margin-bottom:10px;font-size:18px;color:var(--primary-color);transition:color .3s ease}.dot{width:8px;height:8px;background-color:#828282;border-radius:50%;margin-right:8px;opacity:1}\n"] }]
        }], propDecorators: { title: [{
                type: Input
            }], nodes: [{
                type: Input
            }], isRoot: [{
                type: Input
            }], nodeSelected: [{
                type: Output
            }] } });

// Select some icons (use an object, not an array)
class LucideIconsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LucideIconsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: LucideIconsModule, imports: [i3.LucideAngularModule], exports: [LucideAngularModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LucideIconsModule, imports: [LucideAngularModule.pick(icons), LucideAngularModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LucideIconsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [LucideAngularModule.pick(icons)],
                    exports: [LucideAngularModule],
                }]
        }] });

class ComponentsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ComponentsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ComponentsModule, declarations: [ButtonComponent,
            CardComponent,
            InputComponent,
            CheckboxComponent,
            TextareaComponent,
            SelectComponent,
            RadioComponent,
            MultiSelectComponent,
            DataTableComponent,
            CodeHighlightComponent,
            BadgeComponent,
            AlertComponent,
            CardInfoComponent,
            ConfirmationComponent,
            AutofocusDirective,
            CepMaskDirective,
            CnpjMaskDirective,
            CpfMaskDirective,
            CustomPaginationComponent,
            TreeNodeComponent,
            SearchInputComponent,
            AppBackgroundComponent,
            BasicRegistrationComponent,
            CustomSwitchComponent,
            SearchCustomerComponent,
            TabComponent,
            FileUploadComponent,
            ImageUploadComponent,
            MultiSelectCategoryComponent,
            CalendarArgentaComponent,
            AccordionArgentaComponent,
            JsonViewerComponent,
            JsonEditorComponent,
            ModalComponent,
            DragDropListComponent,
            DynamicModalComponent,
            DynamicTableComponent,
            ArgentaPdfDataHandlerComponent,
            ArgentaPdfDownloadComponent,
            DataExcelExporterComponent,
            DataExcelImporterComponent,
            CsvImporterComponent], imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            NgSelectModule,
            LucideIconsModule], exports: [ButtonComponent,
            CardComponent,
            InputComponent,
            CheckboxComponent,
            TextareaComponent,
            SelectComponent,
            RadioComponent,
            MultiSelectComponent,
            FormsModule,
            ReactiveFormsModule,
            NgSelectModule,
            DataTableComponent,
            CodeHighlightComponent,
            BadgeComponent,
            AlertComponent,
            CardInfoComponent,
            ConfirmationComponent,
            AutofocusDirective,
            CepMaskDirective,
            CnpjMaskDirective,
            CpfMaskDirective,
            CustomPaginationComponent,
            TreeNodeComponent,
            SearchInputComponent,
            LucideIconsModule,
            AppBackgroundComponent,
            BasicRegistrationComponent,
            CustomSwitchComponent,
            SearchCustomerComponent,
            TabComponent,
            FileUploadComponent,
            ImageUploadComponent,
            MultiSelectCategoryComponent,
            CalendarArgentaComponent,
            AccordionArgentaComponent,
            JsonViewerComponent,
            JsonEditorComponent,
            ModalComponent,
            DragDropListComponent,
            DynamicModalComponent,
            DynamicTableComponent,
            ArgentaPdfDataHandlerComponent,
            ArgentaPdfDownloadComponent,
            DataExcelExporterComponent,
            DataExcelImporterComponent,
            CsvImporterComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ComponentsModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            NgSelectModule,
            LucideIconsModule, FormsModule,
            ReactiveFormsModule,
            NgSelectModule,
            LucideIconsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ComponentsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ButtonComponent,
                        CardComponent,
                        InputComponent,
                        CheckboxComponent,
                        TextareaComponent,
                        SelectComponent,
                        RadioComponent,
                        MultiSelectComponent,
                        DataTableComponent,
                        CodeHighlightComponent,
                        BadgeComponent,
                        AlertComponent,
                        CardInfoComponent,
                        ConfirmationComponent,
                        AutofocusDirective,
                        CepMaskDirective,
                        CnpjMaskDirective,
                        CpfMaskDirective,
                        CustomPaginationComponent,
                        TreeNodeComponent,
                        SearchInputComponent,
                        AppBackgroundComponent,
                        BasicRegistrationComponent,
                        CustomSwitchComponent,
                        SearchCustomerComponent,
                        TabComponent,
                        FileUploadComponent,
                        ImageUploadComponent,
                        MultiSelectCategoryComponent,
                        CalendarArgentaComponent,
                        AccordionArgentaComponent,
                        JsonViewerComponent,
                        JsonEditorComponent,
                        ModalComponent,
                        DragDropListComponent,
                        DynamicModalComponent,
                        DynamicTableComponent,
                        ArgentaPdfDataHandlerComponent,
                        ArgentaPdfDownloadComponent,
                        DataExcelExporterComponent,
                        DataExcelImporterComponent,
                        CsvImporterComponent,
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        NgSelectModule,
                        LucideIconsModule,
                    ],
                    exports: [
                        ButtonComponent,
                        CardComponent,
                        InputComponent,
                        CheckboxComponent,
                        TextareaComponent,
                        SelectComponent,
                        RadioComponent,
                        MultiSelectComponent,
                        FormsModule,
                        ReactiveFormsModule,
                        NgSelectModule,
                        DataTableComponent,
                        CodeHighlightComponent,
                        BadgeComponent,
                        AlertComponent,
                        CardInfoComponent,
                        ConfirmationComponent,
                        AutofocusDirective,
                        CepMaskDirective,
                        CnpjMaskDirective,
                        CpfMaskDirective,
                        CustomPaginationComponent,
                        TreeNodeComponent,
                        SearchInputComponent,
                        LucideIconsModule,
                        AppBackgroundComponent,
                        BasicRegistrationComponent,
                        CustomSwitchComponent,
                        SearchCustomerComponent,
                        TabComponent,
                        FileUploadComponent,
                        ImageUploadComponent,
                        MultiSelectCategoryComponent,
                        CalendarArgentaComponent,
                        AccordionArgentaComponent,
                        JsonViewerComponent,
                        JsonEditorComponent,
                        ModalComponent,
                        DragDropListComponent,
                        DynamicModalComponent,
                        DynamicTableComponent,
                        ArgentaPdfDataHandlerComponent,
                        ArgentaPdfDownloadComponent,
                        DataExcelExporterComponent,
                        DataExcelImporterComponent,
                        CsvImporterComponent,
                    ],
                }]
        }] });

class NotificationService {
    constructor(appRef, injector) {
        this.appRef = appRef;
        this.injector = injector;
        this.alertsSubject = new Subject();
        this.alerts$ = this.alertsSubject.asObservable();
    }
    showAlert(type, title, message) {
        const alert = { type, title, message };
        this.alertsSubject.next(alert);
        // Create the alert component dynamically
        const componentRef = createComponent(AlertComponent, { environmentInjector: this.appRef.injector });
        componentRef.instance.alerts = [alert];
        this.appRef.attachView(componentRef.hostView);
        const domElem = componentRef.hostView.rootNodes[0];
        document.body.appendChild(domElem);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, deps: [{ token: i0.ApplicationRef }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NotificationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i0.ApplicationRef }, { type: i0.Injector }]; } });

class DataPaginateService {
    constructor(http) {
        this.http = http;
    }
    fetchData(url, params) {
        let httpParams = new HttpParams()
            .set("page", params.pageNumber.toString())
            .set("limit", params.pageSize.toString())
            .set("sort", params.sortColumn)
            .set("order", params.sortDirection);
        if (params.filterDescription) {
            httpParams = httpParams.set("description", params.filterDescription);
        }
        if (params.filterField) {
            httpParams = httpParams.set("filterField", params.filterField);
        }
        return this.http
            .get(url, { params: httpParams })
            .pipe(map((response) => {
            const items = response.data || [];
            const totalItems = response.meta?.total || 0;
            return {
                items,
                totalItems,
            };
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataPaginateService, deps: [{ token: i1$2.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataPaginateService, providedIn: "root" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataPaginateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: "root",
                }]
        }], ctorParameters: function () { return [{ type: i1$2.HttpClient }]; } });

class RouterParameterService {
    constructor() {
        this.secretKey = '9db3589f$h86115&@b457bdff422c232e0e04c!ibe14374970aef0fe0ba054618f!=';
    }
    setParameter(data) {
        return CryptoJS.AES.encrypt(data, this.secretKey).toString();
    }
    getParameter(data) {
        const bytes = CryptoJS.AES.decrypt(data, this.secretKey);
        return bytes.toString(CryptoJS.enc.Utf8);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RouterParameterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RouterParameterService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RouterParameterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class LibPortalAngularModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LibPortalAngularModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: LibPortalAngularModule, imports: [ComponentsModule], exports: [ComponentsModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LibPortalAngularModule, providers: [
            NotificationService,
            ConfirmationService,
            DataPaginateService,
            RefreshService,
            RouterParameterService,
            // ExcelService,
        ], imports: [ComponentsModule, ComponentsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LibPortalAngularModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        ComponentsModule,
                    ],
                    exports: [
                        ComponentsModule,
                    ],
                    providers: [
                        NotificationService,
                        ConfirmationService,
                        DataPaginateService,
                        RefreshService,
                        RouterParameterService,
                        // ExcelService,
                    ],
                }]
        }] });

class ExcelService {
    constructor() { }
    async createExcel(data) {
        let mainSheetData = data;
        const workbook = XLSX.utils.book_new();
        // Verifica se múltiplas planilhas estão configuradas
        if (mainSheetData.multipleSheets) {
            mainSheetData.multipleSheets.forEach((sheetConfig) => {
                const worksheet = XLSX.utils.aoa_to_sheet([]);
                // Adiciona o título, se houver
                let startRow = 0;
                if (sheetConfig.title) {
                    XLSX.utils.sheet_add_aoa(worksheet, [[sheetConfig.title]], {
                        origin: "A1",
                    });
                    // Define larguras personalizadas do título
                    if (sheetConfig.titleWidths) {
                        worksheet["!cols"] = sheetConfig.titleWidths.map((width) => ({
                            wch: width,
                        }));
                    }
                    // Mescla o título
                    if (sheetConfig.tableHeaders) {
                        worksheet["!merges"] = worksheet["!merges"] || [];
                        worksheet["!merges"].push({
                            s: { r: 0, c: 0 },
                            e: { r: 0, c: sheetConfig.tableHeaders.length - 1 },
                        });
                    }
                    startRow = 1;
                }
                // Adiciona cabeçalhos
                if (sheetConfig.tableHeaders) {
                    XLSX.utils.sheet_add_aoa(worksheet, [sheetConfig.tableHeaders], {
                        origin: `A${startRow + 1}`,
                    });
                }
                // Adiciona dados
                if (sheetConfig.data) {
                    XLSX.utils.sheet_add_json(worksheet, sheetConfig.data, {
                        origin: `A${startRow + 2}`,
                        skipHeader: true,
                    });
                }
                // Define larguras das colunas
                if (sheetConfig.columnWidths) {
                    worksheet["!cols"] = sheetConfig.columnWidths.map((width) => ({
                        wch: width,
                    }));
                }
                // Adiciona a planilha ao workbook
                XLSX.utils.book_append_sheet(workbook, worksheet, sheetConfig.sheetName);
            });
        }
        else {
            // Caso não haja múltiplas planilhas, processa a planilha única
            const worksheet = XLSX.utils.aoa_to_sheet([]);
            // Adiciona título, se houver
            let startRow = 0;
            if (mainSheetData.title) {
                XLSX.utils.sheet_add_aoa(worksheet, [[mainSheetData.title]], {
                    origin: "A1",
                });
                // Define larguras do título
                if (mainSheetData.titleWidths) {
                    worksheet["!cols"] = mainSheetData.titleWidths.map((width) => ({
                        wch: width,
                    }));
                }
                // Mescla o título
                if (mainSheetData.tableHeaders) {
                    worksheet["!merges"] = worksheet["!merges"] || [];
                    worksheet["!merges"].push({
                        s: { r: 0, c: 0 },
                        e: { r: 0, c: mainSheetData.tableHeaders.length - 1 },
                    });
                }
                startRow = 1;
            }
            // Adiciona cabeçalhos
            if (mainSheetData.tableHeaders) {
                XLSX.utils.sheet_add_aoa(worksheet, [mainSheetData.tableHeaders], {
                    origin: `A${startRow + 1}`,
                });
            }
            // Adiciona dados
            XLSX.utils.sheet_add_json(worksheet, mainSheetData.multipleSheets[0].data, {
                origin: `A${startRow + 2}`,
                skipHeader: true,
            });
            // Define larguras das colunas
            if (mainSheetData.columnWidths) {
                worksheet["!cols"] = mainSheetData.columnWidths.map((width) => ({
                    wch: width,
                }));
            }
            // Adiciona a planilha ao workbook
            XLSX.utils.book_append_sheet(workbook, worksheet, mainSheetData.sheetName);
        }
        // Salva o arquivo Excel
        XLSX.writeFile(workbook, mainSheetData.fileName);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ExcelService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ExcelService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ExcelService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return []; } });

function convertToSnakeCase(input) {
    return input.replace(/([A-Z])/g, "_$1").toLowerCase();
}

function setThemeColors(config) {
    if (config.primary) {
        document.documentElement.style.setProperty("--primary-color", config.primary);
    }
    if (config.secondary) {
        document.documentElement.style.setProperty("--secondary-color", config.secondary);
    }
    if (config.success) {
        document.documentElement.style.setProperty("--success-color", config.success);
    }
    if (config.danger) {
        document.documentElement.style.setProperty("--danger-color", config.danger);
    }
    if (config.warning) {
        document.documentElement.style.setProperty("--warning-color", config.warning);
    }
    if (config.info) {
        document.documentElement.style.setProperty("--info-color", config.info);
    }
    if (config.light) {
        document.documentElement.style.setProperty("--light-color", config.light);
    }
    if (config.dark) {
        document.documentElement.style.setProperty("--dark-color", config.dark);
    }
    if (config.linkBorder) {
        document.documentElement.style.setProperty("--link-border-color", config.linkBorder);
    }
    if (config.background) {
        document.documentElement.style.setProperty("--background-color", config.background);
    }
    if (config.text) {
        document.documentElement.style.setProperty("--text-color", config.text);
    }
    if (config.font) {
        document.documentElement.style.setProperty("--font-family", config.font);
    }
}

/*
 * Public API Surface of lib-atriun-angular
 *
 * Este arquivo exporta todos os componentes, enums e módulos necessários
 * para que os consumidores da biblioteca possam utilizá-los em suas aplicações.
 */
// Componentes

/**
 * Generated bundle index. Do not edit.
 */

export { AccordionArgentaComponent, AlertComponent, AppBackgroundComponent, ArgentaPdfDataHandlerComponent, ArgentaPdfDownloadComponent, AutofocusDirective, BadgeComponent, BasicRegistrationComponent, ButtonClasses, ButtonComponent, CalendarArgentaComponent, CardComponent, CardInfoComponent, CepMaskDirective, CheckboxComponent, CnpjMaskDirective, CodeHighlightComponent, ComponentsModule, ConfirmationComponent, ConfirmationService, CpfMaskDirective, CsvImporterComponent, CustomPaginationComponent, CustomSwitchComponent, DataExcelExporterComponent, DataExcelImporterComponent, DataPaginateService, DataTableComponent, DragDropListComponent, DynamicModalComponent, DynamicTableComponent, ExcelService, FileUploadComponent, ImageUploadComponent, InputComponent, JsonEditorComponent, JsonViewerComponent, LibPortalAngularModule, LucideIconsModule, ModalComponent, MultiSelectCategoryComponent, MultiSelectComponent, NotificationService, RadioComponent, RefreshService, RouterParameterService, SearchCustomerComponent, SearchInputComponent, SelectComponent, TabComponent, TextareaComponent, TreeNodeComponent, convertToSnakeCase, setThemeColors };
//# sourceMappingURL=lib-portal-angular.mjs.map
